@@ -14,18 +14,16 @@ INSERT INTO tiki_preferences VALUES ('art_list_type','y');
 INSERT INTO tiki_preferences VALUES ('art_list_visible','y');
 INSERT INTO tiki_preferences VALUES ('auth_create_user_auth','n');
 INSERT INTO tiki_preferences VALUES ('auth_create_user_tiki','n');
-INSERT INTO tiki_preferences VALUES ('auth_type','LDAP');
-INSERT INTO tiki_preferences VALUES ('auth_pear_host','localhost');
-INSERT INTO tiki_preferences VALUES ('auth_pear_port','389');
-INSERT INTO tiki_preferences VALUES ('auth_imap_pop3_basedsn','');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_adminpass','');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_adminuser','');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_basedn','');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_groupattr','cn');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_groupdn','');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_groupoc','groupOfUniqueNames');
+INSERT INTO tiki_preferences VALUES ('auth_pear_host','localhost');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_memberattr','uniqueMember');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_memberisdn','n');
+INSERT INTO tiki_preferences VALUES ('auth_pear_port','389');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_scope','sub');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_userattr','uid');
 INSERT INTO tiki_preferences VALUES ('auth_ldap_userdn','');
@@ -76,7 +74,6 @@ INSERT INTO tiki_preferences VALUES ('feature_banners','n');
 INSERT INTO tiki_preferences VALUES ('feature_banning','n');
 INSERT INTO tiki_preferences VALUES ('feature_blog_comments','n');
 INSERT INTO tiki_preferences VALUES ('feature_blogposts_comments','n');
-INSERT INTO tiki_preferences VALUES ('feature_blog_rankings','y');
 INSERT INTO tiki_preferences VALUES ('feature_blogs','n');
 INSERT INTO tiki_preferences VALUES ('feature_bot_bar','y');
 INSERT INTO tiki_preferences VALUES ('feature_calendar','n');
@@ -85,9 +82,7 @@ INSERT INTO tiki_preferences VALUES ('feature_categoryobjects','n');
 INSERT INTO tiki_preferences VALUES ('feature_categorypath','n');
 INSERT INTO tiki_preferences VALUES ('feature_challenge','n');
 INSERT INTO tiki_preferences VALUES ('feature_charts','n');
-INSERT INTO tiki_preferences VALUES ('feature_chat','n');
 INSERT INTO tiki_preferences VALUES ('feature_clear_passwords','n');
-INSERT INTO tiki_preferences VALUES ('feature_cms_rankings','y');
 INSERT INTO tiki_preferences VALUES ('feature_cms_templates','n');
 INSERT INTO tiki_preferences VALUES ('feature_comm','n');
 INSERT INTO tiki_preferences VALUES ('feature_contact','n');
@@ -106,28 +101,26 @@ INSERT INTO tiki_preferences VALUES ('feature_faqs','n');
 INSERT INTO tiki_preferences VALUES ('feature_featuredLinks','y');
 INSERT INTO tiki_preferences VALUES ('feature_file_galleries_comments','n');
 INSERT INTO tiki_preferences VALUES ('feature_file_galleries','n');
-INSERT INTO tiki_preferences VALUES ('feature_file_galleries_rankings','n');
-INSERT INTO tiki_preferences VALUES ('feature_forum_parse','y');
+INSERT INTO tiki_preferences VALUES ('feature_forum_parse','n');
+INSERT INTO tiki_preferences VALUES ('feature_forum_replyempty','n');
 INSERT INTO tiki_preferences VALUES ('feature_forum_quickjump','n');
-INSERT INTO tiki_preferences VALUES ('feature_forum_rankings','y');
 INSERT INTO tiki_preferences VALUES ('feature_forums','n');
 INSERT INTO tiki_preferences VALUES ('feature_forum_topicd','n');
 INSERT INTO tiki_preferences VALUES ('feature_galleries','y');
-INSERT INTO tiki_preferences VALUES ('feature_gal_rankings','y');
 INSERT INTO tiki_preferences VALUES ('feature_games','n');
 INSERT INTO tiki_preferences VALUES ('feature_history','y');
 INSERT INTO tiki_preferences VALUES ('feature_hotwords_nw','n');
-INSERT INTO tiki_preferences VALUES ('feature_hotwords','y');
+INSERT INTO tiki_preferences VALUES ('feature_hotwords','n');
 INSERT INTO tiki_preferences VALUES ('feature_html_pages','n');
 INSERT INTO tiki_preferences VALUES ('feature_image_galleries_comments','n');
 INSERT INTO tiki_preferences VALUES ('feature_integrator','n');
 INSERT INTO tiki_preferences VALUES ('feature_lastChanges','y');
 INSERT INTO tiki_preferences VALUES ('feature_left_column','y');
-INSERT INTO tiki_preferences VALUES ('feature_likePages','y');
+INSERT INTO tiki_preferences VALUES ('feature_likePages','n');
 INSERT INTO tiki_preferences VALUES ('feature_listPages','y');
 INSERT INTO tiki_preferences VALUES ('feature_live_support','n');
 INSERT INTO tiki_preferences VALUES ('feature_maps','n');
-INSERT INTO tiki_preferences VALUES ('feature_menusfolderstyle','y');
+INSERT INTO tiki_preferences VALUES ('feature_menusfolderstyle','n');
 INSERT INTO tiki_preferences VALUES ('feature_messages','n');
 INSERT INTO tiki_preferences VALUES ('feature_minical','n');
 INSERT INTO tiki_preferences VALUES ('feature_modulecontrols','y');
@@ -142,7 +135,7 @@ INSERT INTO tiki_preferences VALUES ('feature_quizzes','n');
 INSERT INTO tiki_preferences VALUES ('feature_ranking','n');
 INSERT INTO tiki_preferences VALUES ('feature_referer_stats','n');
 INSERT INTO tiki_preferences VALUES ('feature_right_column','y');
-INSERT INTO tiki_preferences VALUES ('feature_sandbox','y');
+INSERT INTO tiki_preferences VALUES ('feature_sandbox','n');
 INSERT INTO tiki_preferences VALUES ('feature_search_fulltext','y');
 INSERT INTO tiki_preferences VALUES ('feature_search_stats','n');
 INSERT INTO tiki_preferences VALUES ('feature_search','y');
@@ -159,11 +152,10 @@ INSERT INTO tiki_preferences VALUES ('feature_user_bookmarks','n');
 INSERT INTO tiki_preferences VALUES ('feature_userfiles','n');
 INSERT INTO tiki_preferences VALUES ('feature_usermenu','n');
 INSERT INTO tiki_preferences VALUES ('feature_userPreferences','n');
-INSERT INTO tiki_preferences VALUES ('feature_userVersions','n');
 INSERT INTO tiki_preferences VALUES ('feature_user_watches','n');
 INSERT INTO tiki_preferences VALUES ('feature_user_watches_translations','y');
 INSERT INTO tiki_preferences VALUES ('feature_view_tpl','n');
-INSERT INTO tiki_preferences VALUES ('feature_warn_on_edit','n');
+INSERT INTO tiki_preferences VALUES ('feature_warn_on_edit','y');
 INSERT INTO tiki_preferences VALUES ('feature_webmail','n');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_attachments','n');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_comments','n');
@@ -175,7 +167,6 @@ INSERT INTO tiki_preferences VALUES ('feature_wiki_multiprint','n');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_notepad','n');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_pdf','n');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_pictures','n');
-INSERT INTO tiki_preferences VALUES ('feature_wiki_rankings','y');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_tables','old');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_templates','n');
 INSERT INTO tiki_preferences VALUES ('feature_wiki_undo','n');
@@ -201,8 +192,8 @@ INSERT INTO tiki_preferences VALUES ('forgotPass','n');
 INSERT INTO tiki_preferences VALUES ('forum_list_desc','y');
 INSERT INTO tiki_preferences VALUES ('forum_list_lastpost','y');
 INSERT INTO tiki_preferences VALUES ('forum_list_posts','y');
-INSERT INTO tiki_preferences VALUES ('forum_list_ppd','n');
-INSERT INTO tiki_preferences VALUES ('forum_list_topics','n');
+INSERT INTO tiki_preferences VALUES ('forum_list_ppd','y');
+INSERT INTO tiki_preferences VALUES ('forum_list_topics','y');
 INSERT INTO tiki_preferences VALUES ('forum_list_visits','y');
 INSERT INTO tiki_preferences VALUES ('forums_ordering','created_desc');
 INSERT INTO tiki_preferences VALUES ('gal_list_created','y');
@@ -218,14 +209,11 @@ INSERT INTO tiki_preferences VALUES ('gal_use_db','y');
 INSERT INTO tiki_preferences VALUES ('gal_use_dir','');
 INSERT INTO tiki_preferences VALUES ('gal_use_lib','gd');
 INSERT INTO tiki_preferences VALUES ('home_file_gallery','');
-INSERT INTO tiki_preferences VALUES ('http_domain','');
 INSERT INTO tiki_preferences VALUES ('http_port','80');
-INSERT INTO tiki_preferences VALUES ('http_prefix','/');
-INSERT INTO tiki_preferences VALUES ('https_domain','');
-INSERT INTO tiki_preferences VALUES ('https_login','n');
-INSERT INTO tiki_preferences VALUES ('https_login_required','n');
+INSERT INTO tiki_preferences VALUES ('https_login','allowed');
+INSERT INTO tiki_preferences VALUES ('feature_show_stay_in_ssl_mode','y');
+INSERT INTO tiki_preferences VALUES ('feature_switch_ssl_mode','y');
 INSERT INTO tiki_preferences VALUES ('https_port','443');
-INSERT INTO tiki_preferences VALUES ('https_prefix','/');
 INSERT INTO tiki_preferences VALUES ('image_galleries_comments_default_orderin','points_desc');
 INSERT INTO tiki_preferences VALUES ('image_galleries_comments_per_page','10');
 INSERT INTO tiki_preferences VALUES ('keep_versions','1');
@@ -236,7 +224,7 @@ INSERT INTO tiki_preferences VALUES ('long_date_format','%A %d of %B, %Y');
 INSERT INTO tiki_preferences VALUES ('long_time_format','%H:%M:%S %Z');
 INSERT INTO tiki_preferences VALUES ('map_path','/var/www/html/map/');
 INSERT INTO tiki_preferences VALUES ('maxArticles','10');
-INSERT INTO tiki_preferences VALUES ('maxRecords','25');
+INSERT INTO tiki_preferences VALUES ('maxRecords','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_directories','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_articles','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_blog','10');
@@ -251,12 +239,11 @@ INSERT INTO tiki_preferences VALUES ('max_rss_mapfiles','10');
 INSERT INTO tiki_preferences VALUES ('max_rss_wiki','10');
 INSERT INTO tiki_preferences VALUES ('maxVersions','0');
 INSERT INTO tiki_preferences VALUES ('min_pass_length','1');
-INSERT INTO tiki_preferences VALUES ('modallgroups','n');
 INSERT INTO tiki_preferences VALUES ('pass_chr_num','n');
 INSERT INTO tiki_preferences VALUES ('pass_due','999');
 INSERT INTO tiki_preferences VALUES ('poll_comments_default_ordering','points_desc');
 INSERT INTO tiki_preferences VALUES ('poll_comments_per_page','10');
-INSERT INTO tiki_preferences VALUES ('popupLinks','n');
+INSERT INTO tiki_preferences VALUES ('popupLinks','y');
 INSERT INTO tiki_preferences VALUES ('proxy_host','');
 INSERT INTO tiki_preferences VALUES ('proxy_port','');
 INSERT INTO tiki_preferences VALUES ('record_untranslated','n');
@@ -338,6 +325,7 @@ INSERT INTO tiki_preferences VALUES ('wikiSubmitNotice','');
 INSERT INTO tiki_preferences VALUES ('wiki_top_bar','n');
 INSERT INTO tiki_preferences VALUES ('w_use_db','y');
 INSERT INTO tiki_preferences VALUES ('w_use_dir','');
+INSERT INTO tiki_preferences VALUES ('user_tracker_infos','');
 INSERT INTO users_groups VALUES ('Anonymous','Public users not logged',NULL);
 INSERT INTO users_groups VALUES ('Registered','Users logged into the system',NULL);
 INSERT INTO users_permissions VALUES ('tiki_p_abort_instance','Can abort a process instance','editors','workflow');
