@@ -1,24 +1,40 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/get_strings.php,v 1.37.2.16 2007/07/31 18:52:38 sylvieg Exp $
+// $Id: /cvsroot/tikiwiki/tiki/get_strings.php,v 1.49.2.1 2007-12-26 17:27:37 pkdille Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 /** \file
- * $Header: /cvsroot/tikiwiki/tiki/get_strings.php
+ * $Id: /cvsroot/tikiwiki/tiki/get_strings.php
  * \brief Update the language.php files
  * call example: get_strings.php?lang=fr&close
- * \param lang=xx    : only translate lang 'xx' - if the parameter is not given all languages are translated
- * \param comments   : generate all comments (equal to close&module)
- * \param close      : look for similar strings that are already translated and generate a comment if a 'match' is made
- * \param module     : generate comments that describe in which .php and/or .tpl\n module(s) a certain string was found (useful for checking translations in context)
- * \param patch      : looks for the file 'language.patch' in the same directory as the corresponding language.php and overrides any strings in language.php - good if a user does not agree with some translations or if only changes are sent to the maintainer
- * \param spelling   : generate a file spellcheck_me.txt in the applicable languages directory that contains all the words used in the translated text. This makes it simple to use a spellchecker on the resulting file
+
+ * \param lang=xx    : Only translate lang 'xx' - if the parameter is not given all languages are translated
+
+ * \param comments   : Generate all comments (equal to close&module)
+
+ * \param close      : Looks for similar strings that are already translated and generate a comment if a 'match' is made
+
+ * \param module     : Generate comments that describe in which .php and/or .tpl\n module(s) a certain string was found (useful for checking translations in context)
+
+ * \param patch      : Looks for the file 'language.patch' in the same directory as the corresponding language.php and overrides any strings in language.php - good if a user does not agree with some translations or if only changes are sent to the maintainer
+
+ * \param spelling   : Generate a file spellcheck_me.txt in the applicable languages directory that contains all the words used in the translated text. This makes it simple to use a spellchecker on the resulting file
+
  * \param groupwrite : Sets the generated files permissions to allow the generated language.php also be group writable. This is good for translators if they do not have root access to tiki but are in the same group as the webserver. Please remember to have write access removed when translation is finished for security reasons. (Run script again whithout this parameter)
- * \param sort ='n' don't sort the filenames 
- * \param completion=y produce only the completion status
+
+ * \param sort ='n'  : Don't sort the filenames 
+
+ * \param completion=y: Produce only the completion status
+
+ * \param nosections : Don't print sections delimiters
+
+ * \param nohelp     : Don't print help section
+
+ * \param tagunused  : Tags the unused strings with "// ## UNUSED".
+
  */
 
 
@@ -33,6 +49,33 @@ $addPHPslashes = Array ("\n" => '\n',
 			'$'  => '\$',
 			'"'  => '\"');
 
+
+/**
+  * Reads all the permission descriptions in tikiwiki database and writes
+  *   it to the file $file. All the strings will be surrounded by smarty translate tags
+  *     ex: {tr}perm description{/tr}
+  *
+  * @param $file string: target file for the perms
+  * @returns: nothing but creates the file with the perms (take care about the acl's in the target directory !)
+  */
+function collect_perms_desc($file)
+{
+  global $tikilib;
+
+  $result = $tikilib->query("SELECT DISTINCT(permDesc) FROM users_permissions ORDER BY permDesc");
+
+  $perm_strings = array();
+  while( $row = $result->fetchRow() )
+    $perm_strings[] = $row['permDesc'];
+
+  $pstr = fopen($file,'w');
+  foreach ($perm_strings as $strg)
+  {
+    fwrite ($pstr,  "{tr}" . $strg . "{/tr}" . "\n");
+  }
+  fclose($pstr);
+}
+
 function addphpslashes ($string) {
   // Translate as in "Table 7-1 Escaped characters" in the PHP manual
   // $string = str_replace ("\n", '\n',   $string);
@@ -79,7 +122,7 @@ function removephpslashes ($string) {
 
 function hardwire_file ($file)
 {
-	global $files, $completion;
+  global $files, $completion;
   $files[] = $file;
   if (!$completion)
 	  print "File (hardwired): $file<br />";
@@ -87,7 +130,8 @@ function hardwire_file ($file)
 
 function collect_files ($dir)
 {
-	global $files, $completion;
+  global $files, $completion;
+ 
   $handle = opendir ($dir);
   while (false !== ($file = readdir ($handle))) {
     // Skip current and parent directory
@@ -144,6 +188,7 @@ function writeTranslationPair (&$fd, &$key, &$val) {
 		      '"' . addphpslashes ($key) . '"' . " => " .
 		      '"' . addphpslashes ($val) . '",');
 }
+
 /* \brief: give the closest translation
  * \return the closest translated string
  * \param closeEnglish: the English string of the return string
@@ -184,6 +229,7 @@ $module   = isset ($_REQUEST['module']) || $comments;
 $patch    = isset ($_REQUEST['patch']);
 $spelling = isset ($_REQUEST['spelling']);
 $group_w  = isset ($_REQUEST['groupwrite']);
+$tagunused= isset ($_REQUEST['tagunused']);
 
 $nohelp     = isset ($_REQUEST['nohelp']);
 $nosections = isset ($_REQUEST['nosections']);
@@ -225,6 +271,14 @@ collect_files ('.');
 hardwire_file ('./lang/langmapping.php');
 hardwire_file ('./img/flags/flagnames.php');
 
+## Adding a file in ./temp which contains all the perms descriptions
+## This file is called permstrings.tpl. The extension has to be .tpl in order to be
+##   taken in charge by the scipt (tpl or php)
+## This file is, of course, temporary and will be deleted during the next cache clear !
+
+$permsfile = "./temp/permstrings.tpl";
+$permsstrgs = collect_perms_desc($permsfile);
+hardwire_file ($permsfile);
 
 // Sort files to make generated strings appear in language.php in the same 
 // order across different systems
@@ -237,6 +291,16 @@ if ((!isset($_REQUEST["sort"]) || $_REQUEST["sort"] != 'n') && !$completion) {
 }
 $tiki_timer->start("processing");
 
+if ( $completion) {
+    echo "<table border='1'>";
+      echo "<tr>";
+        echo "<td><b>Language</b></td>";
+        echo "<td><b>Completion</b></td>";
+        echo "<td><b>Translated</b></td>";
+        echo "<td><b>To Translate</b></td>";
+        echo "<td><b>Unused</b></td>";
+      echo "</tr>";
+  }
 
 $oldEndMarker = '##end###';
 $endMarker = '###end###';
@@ -276,46 +340,54 @@ foreach ($languages as $sel) {
 
   if ($group_w) {
     // We set umask to zero value to allow proper chmod later
-    // (Is this really nesserary? Does not chmod work independently of umask?)
+    // (Is this really necessary? Does not chmod work independently of umask?)
     $old_umask = umask (0); 
   }
 
   if (!$completion) {
-	$fw = fopen("lang/$sel/new_language.php",'w');
+    $fw = fopen("lang/$sel/new_language.php",'w');
   
-	print("&lt;");
-	fwrite($fw,"<");
-	writeFile_and_User ($fw, "?php");
-  // The comment coding:utf-8 is for the benefit of emacs
-  // and must be on the very first line in the file
-  // we leave this comment in even if comments are off since
-  // editing files with the wrong encoding causes commical effects at best.
-	writeFile_and_User ($fw, " // -*- coding:utf-8 -*-\n");
+    print("&lt;");
+    fwrite($fw,"<");
+    writeFile_and_User ($fw, "?php");
+    // The comment coding:utf-8 is for the benefit of emacs
+    // and must be on the very first line in the file
+    // we leave this comment in even if comments are off since
+    // editing files with the wrong encoding causes commical effects at best.
+    writeFile_and_User ($fw, " // -*- coding:utf-8 -*-\n");
   }
 
   if (!$nohelp && !$completion) {
     // Good to have instructions for translators in the release file.
     // The comments get filtered away by Smarty anyway
-    writeFile_and_User ($fw, "// parameters:\n");
+    writeFile_and_User ($fw, "// Parameters:\n\n");
     writeFile_and_User ($fw, "// lang=xx    : only tranlates language 'xx',\n");
     writeFile_and_User ($fw, "//              if not given all languages are translated\n");
+    writeFile_and_User ($fw, "\n");
+
     writeFile_and_User ($fw, "// comments   : generate all comments (equal to close&module)\n");
+    writeFile_and_User ($fw, "\n");
+
     writeFile_and_User ($fw, "// close      : look for similar strings that are already translated and\n");
     writeFile_and_User ($fw, "//              generate a comment if a 'match' is made\n");
+    writeFile_and_User ($fw, "\n");
+
     writeFile_and_User ($fw, "// module     : generate comments that describe in which .php and/or .tpl\n");
     writeFile_and_User ($fw, "//              module(s) a certain string was found (useful for checking\n");
     writeFile_and_User ($fw, "//              translations in context)\n");
+    writeFile_and_User ($fw, "\n");
 
     writeFile_and_User ($fw, "// patch      : looks for the file 'language.patch' in the same directory\n");
     writeFile_and_User ($fw, "//              as the corresponding language.php and overrides any strings\n");
     writeFile_and_User ($fw, "//              in language.php - good if a user does not agree with\n");
     writeFile_and_User ($fw, "//              some translations or if only changes are sent to the maintainer\n");
+    writeFile_and_User ($fw, "\n");
 
     writeFile_and_User ($fw, "// spelling   : generates a file 'spellcheck_me.txt' that contains the\n");
     writeFile_and_User ($fw, "//              words used in the translation. It is then easy to check this\n");
     writeFile_and_User ($fw, "//              file for spelling errors (corrections must be done in\n");
     writeFile_and_User ($fw, "//              'language.php, however)\n");
-
+    writeFile_and_User ($fw, "\n");
 
     writeFile_and_User ($fw, "// groupwrite : Sets the generated files permissions to allow the generated\n");
     writeFile_and_User ($fw, "//              language.php also be group writable. This is good for\n");
@@ -324,16 +396,14 @@ foreach ($languages as $sel) {
     writeFile_and_User ($fw, "//              to have write access removed when translation is finished\n");
     writeFile_and_User ($fw, "//              for security reasons. (Run script again without this\n");
     writeFile_and_User ($fw, "//              parameter)\n");
-
-
-
+    writeFile_and_User ($fw, "\n");
 
     writeFile_and_User ($fw, "// Examples:\n");
     writeFile_and_User ($fw, "// http://www.neonchart.com/get_strings.php?lang=sv\n");
-    writeFile_and_User ($fw, "// Will translate langauage 'sv' and (almost) avoiding comment generation\n\n");
+    writeFile_and_User ($fw, "// Will translate language 'sv' and (almost) avoiding comment generation\n\n");
 
     writeFile_and_User ($fw, "// http://www.neonchart.com/get_strings.php?lang=sv&comments\n");
-    writeFile_and_User ($fw, "// Will translate langauage 'sv' and generate all possible comments.\n");
+    writeFile_and_User ($fw, "// Will translate language 'sv' and generate all possible comments.\n");
     writeFile_and_User ($fw, "// This is the most usefull mode when working on a translation.\n\n");
     writeFile_and_User ($fw, "// http://www.neonchart.com/get_strings.php?lang=sv&nohelp&nosections\n");
     writeFile_and_User ($fw, "// These options will only provide the minimal amout of comments.\n");
@@ -342,8 +412,8 @@ foreach ($languages as $sel) {
     writeFile_and_User ($fw, "// Prepare all languages for release \n\n");
 
 
-	// Start generating the lang array
-	writeFile_and_User ($fw, "\n\$lang=Array(\n");  
+    // Start generating the lang array
+    writeFile_and_User ($fw, "\n\$lang=Array(\n");  
   }
   foreach ($files as $file) {
     $data = file_get_contents($file);
@@ -393,13 +463,13 @@ foreach ($languages as $sel) {
       preg_match_all ('/(?s)\{tr\}(.+?)\{\/tr\}/', $data, $uqwords);
     }
 
-    // Transfer UNqouted words (if any) to the words array
+    // Transfer unquoted words (if any) to the words array
     // counting recursive, because we have two empty subarrays after failed match
     if (count($uqwords, COUNT_RECURSIVE) > 2) {
         $words = $uqwords[1];
     }
 
-    // Transfer SINGLEqouted words (if any) to the words array
+    // Transfer SINGLE quoted words (if any) to the words array
     if (count ($sqwords, COUNT_RECURSIVE) > 2) {
       foreach (array_unique ($sqwords[1]) as $sqword) {
 	// Strip the extracted strings from escapes
@@ -410,7 +480,7 @@ foreach ($languages as $sel) {
       }
     }
 
-    // Transfer DOUBLEqouted words (if any) to the words array
+    // Transfer DOUBLE quoted words (if any) to the words array
     if (count ($dqwords, COUNT_RECURSIVE) > 2) {
       foreach (array_unique ($dqwords[1]) as $dqword) {
 	// Strip the extracted strings from escapes
@@ -446,7 +516,6 @@ foreach ($languages as $sel) {
     }
   } // foreach ($files as $file)
 
-
   //////////////////////////////////////////////
   if ($patch) {
     foreach ($unused as $key => $val) {
@@ -470,24 +539,42 @@ foreach ($languages as $sel) {
       }
     }
   }
+
   if ($completion) {
-	  echo "Completion: ".round((count($translated)*100)/(count($translated)+count($to_translate))). '%';
-	  continue;
+    echo "<tr>";
+      echo "<td style='text-align:center;'>$sel</td>";
+      echo "<td style='text-align:center;'>" . round((count($translated)*100)/(count($translated)+count($to_translate))) . '%' . "</td>";
+      echo "<td style='text-align:right;'>" . count($translated)    . "</td>";
+      echo "<td style='text-align:right;'>" . count($to_translate)  . "</td>";
+      echo "<td style='text-align:right;'>" . count ($unused)       . "</td>";
+    echo "</tr>";
+    continue;
   }
 
   unset ($unused['']);
   if (count ($unused) > 0) {
-    writeFile_and_User ($fw, "// ### Start of unused words\n");
-    writeFile_and_User ($fw, "// ### Please remove manually!\n");
-    writeFile_and_User ($fw, "// ### N.B. Legitimate strings may be marked");
-    writeFile_and_User ($fw, "// ### as unused!\n");
-    writeFile_and_User ($fw, "// ### Please see http://tikiwiki.org/tiki-index.php?page=UnusedWords for further info\n");
+    if ('en' != $sel && !$nosections) {
+      writeFile_and_User ($fw, "// ### Start of unused words\n");
+      writeFile_and_User ($fw, "// ### Please remove manually!\n");
+      writeFile_and_User ($fw, "// ### N.B. Legitimate strings may be marked");
+      writeFile_and_User ($fw, "// ### as unused!\n");
+      writeFile_and_User ($fw, "// ### Please see http://tikiwiki.org/tiki-index.php?page=UnusedWords for further info\n");
+    }
     foreach ($unused as $key => $val) {
       writeTranslationPair ($fw, $key, $val);
       addToWordlist ($wordlist, $val);
-      writeFile_and_User ($fw, "\n");
+      if ($tagunused || $tagunused == "y") {
+        writeFile_and_User ($fw, " // ## UNUSED \n");
+      }
+      else
+      {
+        writeFile_and_User ($fw, "\n");
+      }
+
+    }
+    if ('en' != $sel && !$nosections) {
+      writeFile_and_User ($fw, "// ### end of unused words\n\n");
     }
-    writeFile_and_User ($fw, "// ### end of unused words\n\n");
     unset($unused); // free memory
   }
 
@@ -599,4 +686,8 @@ if (!$completion) {
 	echo "Processing time: ", $tiki_timer->stop("processing"), " seconds<br />\n";
 	echo "Total time spent: ", $tiki_timer->elapsed(), " seconds<br />\n";
  }
+ else
+ {
+   echo "</table>";
+ }
 ?>
