@@ -1,6 +1,6 @@
 <?php
 /* 
-V4.61 24 Feb 2005  (c) 2000-2005 John Lim (jlim#natsoft.com.my). All rights reserved.
+V4.98 13 Feb 2008  (c) 2000-2008 John Lim (jlim#natsoft.com.my). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence. 
@@ -473,7 +473,8 @@ See http://msdn.microsoft.com/library/default.asp?url=/library/en-us/odbc/htm/od
 		}
 		$rs->Close(); //-- crashes 4.03pl1 -- why?
 		
-		return empty($retarr) ? $false : $retarr;
+		if (empty($retarr)) $retarr = false;
+		return $retarr;
 	}
 	
 	function Prepare($sql)
@@ -711,9 +712,9 @@ class ADORecordSet_odbc extends ADORecordSet {
 	
 	function _fetch()
 	{
-		
+
 		if ($this->_has_stupid_odbc_fetch_api_change)
-			$rez = @odbc_fetch_into($this->_queryID,$this->fields,$row);
+			$rez = @odbc_fetch_into($this->_queryID,$this->fields);
 		else {
 			$row = 0;
 			$rez = @odbc_fetch_into($this->_queryID,$row,$this->fields);
@@ -734,5 +735,4 @@ class ADORecordSet_odbc extends ADORecordSet {
 	}
 
 }
-
 ?>
\ No newline at end of file
