@@ -1,19 +1,12 @@
 <?php
 /** \file
- * $Header: /cvsroot/tikiwiki/tiki/lib/debug/debug-command_test.php,v 1.3.12.1 2008/02/21 19:10:04 marclaporte Exp $
+ * $Id: /cvsroot/tikiwiki/tiki/lib/debug/debug-command_test.php,v 1.3 2003-08-07 04:34:03 rossta Exp $
  *
  * \brief Skeleton to quick startup of making new debugger command
  *
  * \author zaufi <zaufi@sendmail.ru>
  *
  */
-
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 require_once ('lib/debug/debugger-ext.php');
 
 /**
