@@ -1,9 +1,3 @@
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 <?php
 require_once 'graph-engine/core.php';
 
@@ -13,12 +7,12 @@ class GridBasedGraphic extends Graphic // {{{1
 	var $independant;
 	var $vertical;
 	var $horizontal;
-
+	
 	function GridBasedGraphic() // {{{2
 	{
 		Graphic::Graphic();
 	}
-
+	
 	function _getMinValue( $type ) // {{{2
 	{
 		// Type is 'dependant' or 'independant'
@@ -45,7 +39,7 @@ class GridBasedGraphic extends Graphic // {{{1
 		$right = 1;
 
 		$layout = $this->_layout();
-
+		
 		$this->_initScales( $renderer, $layout, 'dependant' );
 		$this->_initScales( $renderer, $layout, 'independant' );
 		$this->_drawScales( $renderer, $layout, $left, $top, $right, $bottom );
@@ -178,12 +172,12 @@ class GridScale // {{{1
 	var $orientation;
 	var $type;
 	var $layout;
-
+	
 	function GridScale( $type, $layout ) // {{{2
 	{
 		$this->type = $type;
 		$this->layout = $layout;
-
+		
 		if( $type == 'independant' )
 			$this->orientation = $layout['grid-independant-location'];
 		else
@@ -232,7 +226,7 @@ class LinearGridScale extends GridScale // {{{1
 
 	var $skip;
 	var $count;
-
+	
 	function LinearGridScale( $type, $layout, $min, $max ) // {{{2
 	{
 		parent::GridScale( $type, $layout );
@@ -248,7 +242,7 @@ class LinearGridScale extends GridScale // {{{1
 	{
 		$max = $this->max;
 		$min = $this->min;
-
+		
 		$base = "grid-{$this->type}";
 		$default = $this->layout["$base-linear-count"];
 
@@ -277,17 +271,17 @@ class LinearGridScale extends GridScale // {{{1
 				break;
 			else
 				--$this->minorScaleCount;
-
+			
 		$this->minorScaleRound = 0;
 
 		$this->zero = $this->_getZeroLocation();
 		$this->value = $maj / (1 / $this->majorScaleCount);
 	}
-
+	
 	function drawGrid( &$renderer ) // {{{2
 	{
 		$base = "grid-{$this->type}";
-
+		
 		$major = null;
 		$minor = null;
 		if( $this->layout["$base-major-guide"] !== false )
@@ -322,10 +316,10 @@ class LinearGridScale extends GridScale // {{{1
 		}
 	}
 
-	function drawScale( &$renderer ) // {{{2
+	function drawScale( &$renderer ) // {{{2 
 	{
 		$base = "grid-{$this->type}";
-
+		
 		$major_font = null;
 		$minor_font = null;
 		$major_style = null;
@@ -387,7 +381,7 @@ class LinearGridScale extends GridScale // {{{1
 			if( $this->layout['grid-vertical-position'] == 'left' )
 			{
 				if( !is_null( $style ) ) $renderer->drawLine( 1 - $size, $pos, 1, $pos, $style );
-				if( !is_null( $font ) && $this->count++ % $this->skip == 0 )
+				if( !is_null( $font ) && $this->count++ % $this->skip == 0 ) 
 				{
 					$height = $renderer->getTextHeight( $font );
 					$value = $this->_getValue( $pos, $round );
@@ -475,7 +469,7 @@ class LinearGridScale extends GridScale // {{{1
 	{
 		return 1 / $this->majorScaleCount / $this->minorScaleCount;
 	}
-
+	
 	function _getZeroLocation() // {{{2
 	{
 		$loc = $this->max / ($this->max - $this->min);
@@ -533,7 +527,7 @@ class StaticGridScale extends GridScale // {{{1
 	var $width;
 	var $layers;
 	var $count;
-
+	
 	function StaticGridScale( $type, $layout, $labels ) // {{{2
 	{
 		parent::GridScale( $type, $layout );
@@ -545,7 +539,7 @@ class StaticGridScale extends GridScale // {{{1
 	function drawGrid( &$renderer ) // {{{2
 	{
 		$base = "grid-{$this->type}";
-
+		
 		$major = null;
 		if( $this->layout["$base-major-guide"] !== false )
 			$major = $renderer->getStyle( $this->layout["$base-major-guide"] );
@@ -555,10 +549,10 @@ class StaticGridScale extends GridScale // {{{1
 				$this->_drawGridLine( $renderer, $i, $major );
 	}
 
-	function drawScale( &$renderer ) // {{{2
+	function drawScale( &$renderer ) // {{{2 
 	{
 		$base = "grid-{$this->type}";
-
+		
 		$major_font = null;
 		$major_style = null;
 		if( $this->layout["$base-major-font"] !== false )
@@ -576,7 +570,10 @@ class StaticGridScale extends GridScale // {{{1
 
 	function _calculateSkip( $size, $space ) // {{{2
 	{
+		$space = abs($space);
 		$skip = 0;
+		if (empty($space))
+			return $skip;
 		while( $size > $space * ++$skip );
 
 		return $skip;
@@ -600,7 +597,7 @@ class StaticGridScale extends GridScale // {{{1
 			if( $this->layout['grid-vertical-position'] == 'left' )
 			{
 				if( !is_null( $style ) ) $renderer->drawLine( 1 - $size, $pos, 1, $pos, $style );
-				if( !is_null( $font ) )
+				if( !is_null( $font ) ) 
 				{
 					$height = $renderer->getTextHeight( $font );
 					$offset = ++$this->count % $this->layers * $width;
