@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/newsletters/nllib.php,v 1.33.2.24 2007/07/09 21:43:19 sylvieg Exp $
+// $Id: /cvsroot/tikiwiki/tiki/lib/newsletters/nllib.php,v 1.63.2.2 2008-01-17 15:47:10 sylvieg Exp $
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
@@ -13,25 +13,47 @@ class NlLib extends TikiLib {
 		parent::TikiLib($db);
 	}
 
-	function replace_newsletter($nlId, $name, $description, $allowUserSub, $allowAnySub, $unsubMsg, $validateAddr) {
+	function replace_newsletter($nlId, $name, $description, $allowUserSub, $allowAnySub, $unsubMsg, $validateAddr,$allowTxt, $frequency , $author) {
 		if ($nlId) {
-			$query = "update `tiki_newsletters` set `name`=?, `description`=?, `allowUserSub`=?, `allowAnySub`=?, `unsubMsg`=?, `validateAddr`=?  where `nlId`=?";
-			$result = $this->query($query, array($name,$description,$allowUserSub,$allowAnySub,$unsubMsg,$validateAddr,(int)$nlId));
+			$query = "update `tiki_newsletters` set `name`=?, `description`=?, `allowUserSub`=?, `allowAnySub`=?, `unsubMsg`=?, `validateAddr`=?, `frequency`=? where `nlId`=?";
+			$result = $this->query($query, array($name,$description,$allowUserSub,$allowAnySub,$unsubMsg,$frequency,$validateAddr,(int)$nlId));
 		} else {
-			$now = date("U");
-			$query = "insert into `tiki_newsletters`(`name`,`description`,`allowUserSub`,`allowAnySub`,`unsubMsg`,`validateAddr`,`lastSent`,`editions`,`users`,`created`) ";
-      $query.= " values(?,?,?,?,?,?,?,?,?,?)";
-			$result = $this->query($query, array($name,$description,$allowUserSub,$allowAnySub,$unsubMsg,$validateAddr,(int)$now,0,0,(int)$now));
+			$query = "insert into `tiki_newsletters`(`name`,
+								`description`,
+								`created`,
+								`lastSent`,
+								`editions`,
+								`users`,
+								`allowUserSub`,
+								`allowTxt`,
+								`allowAnySub`,
+								`unsubMsg`,
+								`validateAddr`,
+								`frequency`,
+								`author`) ";
+      $query.= " values(?,?,?,?,?,?,?,?,?,?,?,?,?)";
+			$result = $this->query($query, array($name,
+							$description,
+							(int)$this->now,
+							0,
+							0,
+							0,
+							$allowUserSub,
+							$allowTxt,
+							$allowAnySub,
+							$unsubMsg,
+							$validateAddr,
+							NULL,
+							$author));
 			$queryid = "select max(`nlId`) from `tiki_newsletters` where `created`=?";
-			$nlId = $this->getOne($queryid, array((int)$now));
+			$nlId = $this->getOne($queryid, array((int)$this->now));
 		}
 		return $nlId;
 	}
 
 	function replace_edition($nlId, $subject, $data, $users) {
-		$now = date("U");
 		$query = "insert into `tiki_sent_newsletters`(`nlId`,`subject`,`data`,`sent`,`users`) values(?,?,?,?,?)";
-		$result = $this->query($query,array((int)$nlId,$subject,$data,(int)$now,$users));
+		$result = $this->query($query,array((int)$nlId,$subject,$data,(int)$this->now,$users));
 		$query = "update `tiki_newsletters` set `editions`= `editions`+ 1 where `nlId`=?";
 		$result = $this->query($query,array((int)$nlId));
 	}
@@ -60,7 +82,7 @@ class NlLib extends TikiLib {
 		$ret = array();
 		$groups =array();
 		while ($res = $result->fetchRow()) {
-			$groups = array_merge($groups, array($res["groupName"]), $this->get_groups_all($res["groupName"]));
+			$groups = array_merge($groups, array($res["groupName"]), $this->get_included_groups($res["groupName"]));
 		}
 		 	/* users already in or unsubscribed */
 		$query = "select * from `tiki_newsletter_subscriptions` where `nlId`=? and `isUser`!='g'";
@@ -103,14 +125,25 @@ class NlLib extends TikiLib {
 					if ($genUnsub == "y") {
 						$query = "insert into `tiki_newsletter_subscriptions`(`nlId`,`email`,`code`,`valid`,`subscribed`,`isUser`) values(?,?,?,?,?,?)";
 						$code = $this->genRandomString($res["login"]);
-						$this->query($query,array((int)$nlId,$res["login"],$code,'y',(int)date('U'),'g'));
+						$this->query($query,array((int)$nlId,$res["login"],$code,'y',(int)$this->now,'g'));
 						$res["code"] = $code;
 					}
 					$ret[] = $res;
+					$in[] = $res['login'];
+				}
+			}
+		}
+
+		$incnl = $this->list_newsletter_included($nlId);
+		foreach ($incnl as $incid=>$incname) {
+			$incall = $this->get_all_subscribers($incid,$genUnsub);
+			foreach ($incall as $res) {
+				if (!in_array($res["login"], $in) && !in_array($res["login"], $out) && !in_array($res["email"], $inEmail) && !in_array($res['login'], $unsub_groupusers)) {
+					$ret[] = $res;
 				}
 			}
 		}
-//echo "<pre>Subscribers:";print_r($ret); echo "</pre>";
+//{echo "<pre>Subscribers:$nlId";print_r($ret); echo "</pre>"; }
 		return $ret;
 	}
 
@@ -125,8 +158,13 @@ class NlLib extends TikiLib {
 		$result = $this->query($query, array((int)$nlId,$group), -1, -1, false);
 	}
 
+	function remove_newsletter_included($nlId, $includedId) {
+		$query = "delete from `tiki_newsletter_included` where `nlId`=? and `includedId`=?";
+		$this->query($query, array((int)$nlId,$includedId), -1, -1, false);
+	}
+
 	function newsletter_subscribe($nlId, $add, $isUser='n', $validateAddr='', $addEmail='') {
-		global $smarty, $tikilib, $user, $sender_email,  $userlib;
+		global $smarty, $tikilib, $user, $prefs, $userlib;
 		if (empty($add))
 			return false;
 		if ($isUser == "y" && $addEmail == "y") {
@@ -139,7 +177,6 @@ class NlLib extends TikiLib {
 			return false; /* already subscribed and valid - keep the same valid status */
 			}
 		$code = $this->genRandomString($add);
-		$now = date("U");
 		$info = $this->get_newsletter($nlId);
 		if ($info["validateAddr"] == 'y' && $validateAddr != 'n') {
 			if ($isUser == "y")
@@ -153,10 +190,10 @@ class NlLib extends TikiLib {
 			$foopath = preg_replace('/tiki-admin_newsletter_subscriptions.php/', 'tiki-newsletters.php', $foo["path"]);
 			$url_subscribe = $tikilib->httpPrefix(). $foopath;
 			$query = "insert into `tiki_newsletter_subscriptions`(`nlId`,`email`,`code`,`valid`,`subscribed`,`isUser`) values(?,?,?,?,?,?)";
-			$result = $this->query($query,array((int)$nlId,$add,$code,'n',(int)$now,$isUser));
+			$result = $this->query($query,array((int)$nlId,$add,$code,'n',(int)$this->now,$isUser));
 			// Now send an email to the address with the confirmation instructions
 			$smarty->assign('info', $info);
-			$smarty->assign('mail_date', date("U"));
+			$smarty->assign('mail_date', $this->now);
 			$smarty->assign('mail_user', $user);
 			$smarty->assign('code', $code);
 			$smarty->assign('url_subscribe', $url_subscribe);
@@ -173,18 +210,14 @@ class NlLib extends TikiLib {
 			return true;
 		} else {
 			$query = "insert into `tiki_newsletter_subscriptions`(`nlId`,`email`,`code`,`valid`,`subscribed`,`isUser`) values(?,?,?,?,?,?)";
-			$result = $this->query($query,array((int)$nlId,$add,$code,'y',(int)$now,$isUser));
+			$result = $this->query($query,array((int)$nlId,$add,$code,'y',(int)$this->now,$isUser));
 		}
 		/*$this->update_users($nlId);*/
 		return false;
 	}
 
 	function confirm_subscription($code) {
-		global $smarty;
-		global $tikilib;
-		global $sender_email;
-		global $userlib;
-		global $language;
+		global $smarty, $tikilib, $prefs, $userlib;
 		$foo = parse_url($_SERVER["REQUEST_URI"]);
 		$url_subscribe = $tikilib->httpPrefix(). $foo["path"];
 		$query = "select * from `tiki_newsletter_subscriptions` where `code`=?";
@@ -198,7 +231,7 @@ class NlLib extends TikiLib {
 		$query = "update `tiki_newsletter_subscriptions` set `valid`=? where `code`=?";
 		$result = $this->query($query,array('y',$code));
 		// Now send a welcome email
-		$smarty->assign('mail_date', date("U"));
+		$smarty->assign('mail_date', $this->now);
 		if ($res["isUser"] == "y") {
 			$user = $res["email"];
 			$email = $userlib->get_user_email($user);
@@ -213,7 +246,7 @@ class NlLib extends TikiLib {
 			$_SERVER["SERVER_NAME"] = $_SERVER["HTTP_HOST"];
 		}
 		$mail = new TikiMail($user);
-		$lg = !$user? $language: $this->get_user_preference($user, "language", $language);
+		$lg = ! $user ? $prefs['site_language']: $this->get_user_preference($user, "language", $prefs['site_language']);
 		$mail_data = $smarty->fetchLang($lg, 'mail/newsletter_welcome_subject.tpl');
 		$mail->setSubject(sprintf($mail_data, $info["name"], $_SERVER["SERVER_NAME"]));
 		$mail_data = $smarty->fetchLang($lg, 'mail/newsletter_welcome.tpl');
@@ -224,11 +257,7 @@ class NlLib extends TikiLib {
 	}
 
 	function unsubscribe($code,$mailit=false) {
-		global $smarty;
-		global $sender_email;
-		global $userlib;
-		global $tikilib;
-		global $language;
+		global $smarty, $prefs, $userlib, $tikilib;
 		$foo = parse_url($_SERVER["REQUEST_URI"]);
 		$url_subscribe = $tikilib->httpPrefix(). $foo["path"];
 		$query = "select * from `tiki_newsletter_subscriptions` where `code`=?";
@@ -246,7 +275,7 @@ class NlLib extends TikiLib {
 			$query = "delete from `tiki_newsletter_subscriptions` where `code`=?";
 		$result = $this->query($query,array($code), -1, -1, false);
 		// Now send a bye bye email
-		$smarty->assign('mail_date', date("U"));
+		$smarty->assign('mail_date', $this->now);
 		if ($res["isUser"] == "y") {
 			$user = $res["email"];
 			$email = $userlib->get_user_email($user);
@@ -256,7 +285,7 @@ class NlLib extends TikiLib {
 		}
 		$smarty->assign('mail_user', $user);
 		$smarty->assign('url_subscribe', $url_subscribe);
-		$lg = !$user? $language: $this->get_user_preference($user, "language", $language);
+		$lg = ! $user ? $prefs['site_language'] : $this->get_user_preference($user, "language", $prefs['site_language']);
 		if (!isset($_SERVER["SERVER_NAME"])) {
 			$_SERVER["SERVER_NAME"] = $_SERVER["HTTP_HOST"];
 		}
@@ -297,6 +326,13 @@ class NlLib extends TikiLib {
 		$result = $this->query($query,array((int)$nlId,$group,$code));
 	}
 
+	function add_included($nlId, $includedId) {
+		$query = "delete from `tiki_newsletter_included` where `nlId`=? and `includedId`=?";
+		$this->query($query,array((int)$nlId,(int)$includedId), -1, -1, false);
+		$query = "insert into `tiki_newsletter_included` (`nlId`,`includedId`) values(?,?)";
+		$this->query($query,array((int)$nlId,(int)$includedId));
+	}
+
 	function add_group_users($nlId, $group, $validateAddr='', $addEmail='') {
 		$groups =  array_merge(array($group),$this->get_groups_all($group));
 		$mid = implode(" or ",array_fill(0,count($groups),"`groupName`=?"));
@@ -338,7 +374,7 @@ class NlLib extends TikiLib {
 		$result = $this->query($query,array($users,(int)$nlId));
 	}
 /* perms = a or between perms */
-	function list_newsletters($offset, $maxRecords, $sort_mode, $find, $update='', $perms='') {
+	function list_newsletters($offset, $maxRecords, $sort_mode, $find, $update='', $perms='', $full='y') {
 		global $user, $tikilib;
 		$bindvars = array();
 		if ($find) {
@@ -352,7 +388,8 @@ class NlLib extends TikiLib {
 
 		$query = "select * from `tiki_newsletters` $mid order by ".$this->convert_sortmode("$sort_mode");
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
-		$cant = 0;
+		$query_cant = "select count(*) from  `tiki_newsletters` $mid";
+		$cant = $this->getOne($query_cant,$bindvars);
 		$ret = array();
 
 		while ($res = $result->fetchRow()) {
@@ -374,11 +411,12 @@ class NlLib extends TikiLib {
 				if (!$hasPerm)
 					continue;
 			}
-			++$cant;
-			$ok = count($this->get_all_subscribers($res["nlId"], ""));
-			$notok = $this->getOne("select count(*) from `tiki_newsletter_subscriptions` where `valid`=? and `nlId`=?",array('n',(int)$res["nlId"]));
-			$res["users"] = $ok + $notok;
-			$res["confirmed"] = $ok;
+			if ($full != 'n') {
+				$ok = count($this->get_all_subscribers($res['nlId'], ""));
+				$notok = $this->getOne("select count(*) from `tiki_newsletter_subscriptions` where `valid`=? and `nlId`=?",array('n',(int)$res['nlId']));
+				$res["users"] = $ok + $notok;
+				$res["confirmed"] = $ok;
+			}
 			$ret[] = $res;
 		}
 		$retval = array();
@@ -483,7 +521,7 @@ class NlLib extends TikiLib {
 		}
 
 		$query = "select * from `tiki_newsletter_groups` $mid order by ".$this->convert_sortmode("$sort_mode");
-		$query_cant = "select count(*) from tiki_newsletter_groups $mid";
+		$query_cant = "select count(*) from `tiki_newsletter_groups` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
 		$cant = $this->getOne($query_cant,$bindvars);
 		$ret = array();
@@ -497,8 +535,33 @@ class NlLib extends TikiLib {
 		return $retval;
 	}
 
+	function list_newsletter_included($nlId) {
+		$query = "select a.`includedId`,b.`name` from `tiki_newsletter_included` a left join `tiki_newsletters` b on a.`includedId`=b.`nlId` where a.`nlId`=? ";
+		$result = $this->query($query,array((int)$nlId));
+		$ret = array();
+		while ($res = $result->fetchRow()) {
+			$ret[$res['includedId']] = $res['name'];
+		}
+		return $ret;
+	}
+
+	function list_newsletter_all_included($nlId,$check=array()) {
+		$query = "select a.`includedId`,b.`name` from `tiki_newsletter_included` a left join `tiki_newsletters` b on a.`includedId`=b.`nlId` where a.`nlId`=? ";
+		$result = $this->query($query,array((int)$nlId));
+		$ret = array();
+		while ($res = $result->fetchRow()) {
+			if (!in_array($res['includedId'],$check)) {
+				$check[] = $res['includedId'];
+				$ret[$res['includedId']] = $res['name'];
+				$back = $this->list_newsletter_all_included($res['includedId'],$check);
+				$ret = $back + $check;
+			}
+		}
+		return array_unique($ret);
+	}
+
 	function get_unsub_msg($nlId, $email, $lang, $code='', $user='') {
-		global $smarty, $language,$userlib,$tikilib;
+		global $smarty, $userlib, $tikilib;
 		$pth = $tikilib->httpPrefix(). substr($_SERVER["REQUEST_URI"],0,strpos($_SERVER["REQUEST_URI"],'tiki-'));
 		$foo = parse_url($_SERVER["REQUEST_URI"]);
 		 $smarty->assign('url',$pth);
@@ -513,7 +576,7 @@ class NlLib extends TikiLib {
 		if ($user == '')
 			$user = $userlib->get_user_by_email($email);
 		if ($lang == '')
-			$lang = !$user? $language: $this->get_user_preference($user, "language", $language);
+			$lang = ! $user ? $prefs['site_language'] : $this->get_user_preference($user, "language", $prefs['site_language']);
 
 		$smarty->assign('thisuser',$user);
 		$msg = $smarty->fetchLang($lang, 'mail/newsletter_unsubscribe.tpl');
@@ -561,6 +624,37 @@ class NlLib extends TikiLib {
 		}
 		return $tpls;
 	}
+	function memo_subscribers_edition($editionId, $users) {
+		$query = 'insert into `tiki_sent_newsletters_errors` (`editionId`, `email`, `login`) values(?,?,?)';
+		foreach ($users as $user) {
+			$result = $this->query($query, array((int)$editionId, $user['email'], $user['login']));
+		}
+	}
+	function delete_edition_subscriber($editionId, $user) {
+		$query = 'delete from `tiki_sent_newsletters_errors` where `editionId`=? and `email`=? and `login`=?';
+		$this->query($query, array((int)$editionId, $user['email'], $user['login']));
+	}
+	function mark_edition_subscriber($editionId, $user) {
+		$query = 'update `tiki_sent_newsletters_errors` set `error`= ? where `editionId`=? and `email`=? and `login`=?';
+		$this->query($query, array('y', (int)$editionId, $user['email'], $user['login']));
+	}
+	function get_edition_errors($editionId) {
+		$query = 'select * from `tiki_sent_newsletters_errors` where `editionId`=?';
+		$result = $this->query($query, array((int)$editionId));
+		$ret = array();
+		while ($res = $result->fetchRow()) {
+			$ret[] = $res;
+		}
+		return $ret;
+	}
+	function get_edition_nb_errors($editionId) {
+		$query = 'select count(*) from `tiki_sent_newsletters_errors` where `editionId`=?';
+		return $this->getOne($query, array((int)$editionId));
+	}
+	function remove_edition_errors($editionId) {
+		$query = 'delete from `tiki_sent_newsletters_errors` where `editionId`=?';
+		$this->query($query, array((int)$editionId));
+	}
 }
 global $dbTiki;
 $nllib = new NlLib($dbTiki);
