@@ -18,7 +18,7 @@
  * @author     Adam Ashley <aashley@php.net>
  * @copyright  2001-2006 The PHP Group
  * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
- * @version    CVS: $Id: DB.php,v 1.1.2.2 2006/10/22 04:16:38 cfreeze Exp $
+ * @version    CVS: Id: DB.php,v 1.72 2007/06/12 03:11:26 aashley Exp 
  * @link       http://pear.php.net/package/Auth
  */
 
@@ -43,7 +43,7 @@ require_once 'DB.php';
  * @author     Adam Ashley <aashley@php.net>
  * @copyright  2001-2006 The PHP Group
  * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
- * @version    Release: @package_version@  File: $Revision: 1.1.2.2 $
+ * @version    Release: 1.5.4  File: $Revision: 1.4 $
  * @link       http://pear.php.net/package/Auth
  */
 class Auth_Container_DB extends Auth_Container
@@ -109,6 +109,8 @@ class Auth_Container_DB extends Auth_Container
      */
     function _connect($dsn)
     {
+        $this->log('Auth_Container_DB::_connect() called.', AUTH_LOG_DEBUG);
+
         if (is_string($dsn) || is_array($dsn)) {
             $this->db = DB::Connect($dsn, $this->options['db_options']);
         } elseif (is_subclass_of($dsn, 'db_common')) {
@@ -151,6 +153,15 @@ class Auth_Container_DB extends Auth_Container
                 return $res;
             }
         }
+        if ($this->options['auto_quote'] && $this->db->dsn['phptype'] != 'sqlite') {
+            $this->options['final_table'] = $this->db->quoteIdentifier($this->options['table']);
+            $this->options['final_usernamecol'] = $this->db->quoteIdentifier($this->options['usernamecol']);
+            $this->options['final_passwordcol'] = $this->db->quoteIdentifier($this->options['passwordcol']);
+        } else {
+            $this->options['final_table'] = $this->options['table'];
+            $this->options['final_usernamecol'] = $this->options['usernamecol'];
+            $this->options['final_passwordcol'] = $this->options['passwordcol'];
+        }
         return true;
     }
 
@@ -196,6 +207,8 @@ class Auth_Container_DB extends Auth_Container
         $this->options['db_fields']   = '';
         $this->options['cryptType']   = 'md5';
         $this->options['db_options']  = array();
+        $this->options['db_where']    = '';
+        $this->options['auto_quote']  = true;
     }
 
     // }}}
@@ -230,21 +243,29 @@ class Auth_Container_DB extends Auth_Container
     {
         if (isset($this->options['db_fields'])) {
             if (is_array($this->options['db_fields'])) {
-                $fields = array();
-                foreach ($this->options['db_fields'] as $field) {
-                    $fields[] = $this->db->quoteIdentifier($field);
+                if ($this->options['auto_quote']) {
+                    $fields = array();
+                    foreach ($this->options['db_fields'] as $field) {
+                        $fields[] = $this->db->quoteIdentifier($field);
+                    }
+                    return implode(', ', $fields);
+                } else {
+                    return implode(', ', $this->options['db_fields']);
                 }
-                return implode(', ', $fields);
             } else {
                 if (strlen($this->options['db_fields']) > 0) {
-                    return $this->db->quoteIdentifier($this->options['db_fields']);
+                    if ($this->options['auto_quote']) {
+                        return $this->db->quoteIdentifier($this->options['db_fields']);
+                    } else {
+                        return $this->options['db_fields'];
+                    }
                 }
             }
         }
 
         return '';
     }
-    
+
     // }}}
     // {{{ fetchData()
 
@@ -266,6 +287,7 @@ class Auth_Container_DB extends Auth_Container
      */
     function fetchData($username, $password, $isChallengeResponse=false)
     {
+        $this->log('Auth_Container_DB::fetchData() called.', AUTH_LOG_DEBUG);
         // Prepare for a database query
         $err = $this->_prepare();
         if ($err !== true) {
@@ -277,32 +299,25 @@ class Auth_Container_DB extends Auth_Container
             && strstr($this->options['db_fields'], '*')) {
             $sql_from = "*";
         } else {
-            $sql_from = $this->db->quoteIdentifier($this->options['usernamecol']).
-                ", ".$this->db->quoteIdentifier($this->options['passwordcol']);
+            $sql_from = $this->options['final_usernamecol'].
+                ", ".$this->options['final_passwordcol'];
 
             if (strlen($fields = $this->_quoteDBFields()) > 0) {
                 $sql_from .= ', '.$fields;
             }
         }
 
-        /*
-         Old Style, removed to go around the oci8
-         problem
-         See bug 206
-         http://pear.php.net/bugs/bug.php?id=206
-
-        $query = "SELECT ! FROM ! WHERE ! = ?";
-        $query_params = array(
-                         $sql_from,
-                         $this->options['table'],
-                         $this->options['usernamecol'],
-                         $username
-                         );
-        */
-
         $query = "SELECT ".$sql_from.
-                " FROM ".$this->db->quoteIdentifier($this->options['table']).
-                " WHERE ".$this->db->quoteIdentifier($this->options['usernamecol'])." = ".$this->db->quoteSmart($username);
+                " FROM ".$this->options['final_table'].
+                " WHERE ".$this->options['final_usernamecol']." = ".$this->db->quoteSmart($username);
+
+        // check if there is an optional parameter db_where
+        if ($this->options['db_where'] != '') {
+            // there is one, so add it to the query
+            $query .= " AND ".$this->options['db_where'];
+        }
+
+        $this->log('Running SQL against DB: '.$query, AUTH_LOG_DEBUG);
 
         $res = $this->db->getRow($query, null, DB_FETCHMODE_ASSOC);
 
@@ -323,12 +338,12 @@ class Auth_Container_DB extends Auth_Container
         if ($isChallengeResponse) {
             $res[$this->options['passwordcol']] = md5($res[$this->options['passwordcol']]
                     .$this->_auth_obj->session['loginchallenege']);
-            
+
             // UGLY cannot avoid without modifying verifyPassword
             if ($this->options['cryptType'] == 'md5') {
                 $res[$this->options['passwordcol']] = md5($res[$this->options['passwordcol']]);
             }
-            
+
             //print " Hashed Password [{$res[$this->options['passwordcol']]}]<br/>\n";
         }
 
@@ -341,8 +356,11 @@ class Auth_Container_DB extends Auth_Container
                     $key == $this->options['usernamecol']) {
                     continue;
                 }
+
+                $this->log('Storing additional field: '.$key, AUTH_LOG_DEBUG);
+
                 // Use reference to the auth object if exists
-                // This is because the auth session variable can change so a 
+                // This is because the auth session variable can change so a
                 // static call to setAuthData does not make sence
                 $this->_auth_obj->setAuthData($key, $value);
             }
@@ -363,6 +381,7 @@ class Auth_Container_DB extends Auth_Container
      */
     function listUsers()
     {
+        $this->log('Auth_Container_DB::listUsers() called.', AUTH_LOG_DEBUG);
         $err = $this->_prepare();
         if ($err !== true) {
             return PEAR::raiseError($err->getMessage(), $err->getCode());
@@ -371,11 +390,12 @@ class Auth_Container_DB extends Auth_Container
         $retVal = array();
 
         // Find if db_fields contains a *, if so assume all col are selected
-        if (strstr($this->options['db_fields'], '*')) {
+        if (   is_string($this->options['db_fields'])
+            && strstr($this->options['db_fields'], '*')) {
             $sql_from = "*";
         } else {
-            $sql_from = $this->db->quoteIdentifier($this->options['usernamecol']).
-                ", ".$this->db->quoteIdentifier($this->options['passwordcol']);
+            $sql_from = $this->options['final_usernamecol'].
+                ", ".$this->options['final_passwordcol'];
 
             if (strlen($fields = $this->_quoteDBFields()) > 0) {
                 $sql_from .= ', '.$fields;
@@ -384,8 +404,17 @@ class Auth_Container_DB extends Auth_Container
 
         $query = sprintf("SELECT %s FROM %s",
                          $sql_from,
-                         $this->db->quoteIdentifier($this->options['table'])
+                         $this->options['final_table']
                          );
+
+        // check if there is an optional parameter db_where
+        if ($this->options['db_where'] != '') {
+            // there is one, so add it to the query
+            $query .= " WHERE ".$this->options['db_where'];
+        }
+
+        $this->log('Running SQL against DB: '.$query, AUTH_LOG_DEBUG);
+
         $res = $this->db->getAll($query, null, DB_FETCHMODE_ASSOC);
 
         if (DB::isError($res)) {
@@ -396,6 +425,7 @@ class Auth_Container_DB extends Auth_Container
                 $retVal[] = $user;
             }
         }
+        $this->log('Found '.count($retVal).' users.', AUTH_LOG_DEBUG);
         return $retVal;
     }
 
@@ -414,15 +444,16 @@ class Auth_Container_DB extends Auth_Container
      */
     function addUser($username, $password, $additional = "")
     {
+        $this->log('Auth_Container_DB::addUser() called.', AUTH_LOG_DEBUG);
         $err = $this->_prepare();
         if ($err !== true) {
             return PEAR::raiseError($err->getMessage(), $err->getCode());
         }
 
-        if (   isset($this->options['cryptType']) 
+        if (   isset($this->options['cryptType'])
             && $this->options['cryptType'] == 'none') {
             $cryptFunction = 'strval';
-        } elseif (   isset($this->options['cryptType']) 
+        } elseif (   isset($this->options['cryptType'])
                   && function_exists($this->options['cryptType'])) {
             $cryptFunction = $this->options['cryptType'];
         } else {
@@ -436,21 +467,27 @@ class Auth_Container_DB extends Auth_Container
 
         if (is_array($additional)) {
             foreach ($additional as $key => $value) {
-                $additional_key .= ', ' . $this->db->quoteIdentifier($key);
+                if ($this->options['auto_quote']) {
+                    $additional_key .= ', ' . $this->db->quoteIdentifier($key);
+                } else {
+                    $additional_key .= ', ' . $key;
+                }
                 $additional_value .= ", " . $this->db->quoteSmart($value);
             }
         }
 
         $query = sprintf("INSERT INTO %s (%s, %s%s) VALUES (%s, %s%s)",
-                         $this->db->quoteIdentifier($this->options['table']),
-                         $this->db->quoteIdentifier($this->options['usernamecol']),
-                         $this->db->quoteIdentifier($this->options['passwordcol']),
+                         $this->options['final_table'],
+                         $this->options['final_usernamecol'],
+                         $this->options['final_passwordcol'],
                          $additional_key,
                          $this->db->quoteSmart($username),
                          $this->db->quoteSmart($password),
                          $additional_value
                          );
 
+        $this->log('Running SQL against DB: '.$query, AUTH_LOG_DEBUG);
+
         $res = $this->query($query);
 
         if (DB::isError($res)) {
@@ -473,17 +510,30 @@ class Auth_Container_DB extends Auth_Container
      */
     function removeUser($username)
     {
+        $this->log('Auth_Container_DB::removeUser() called.', AUTH_LOG_DEBUG);
+
         $err = $this->_prepare();
         if ($err !== true) {
             return PEAR::raiseError($err->getMessage(), $err->getCode());
         }
 
-        $query = sprintf("DELETE FROM %s WHERE %s = %s",
-                         $this->db->quoteIdentifier($this->options['table']),
-                         $this->db->quoteIdentifier($this->options['usernamecol']),
-                         $this->db->quoteSmart($username)
+        // check if there is an optional parameter db_where
+        if ($this->options['db_where'] != '') {
+            // there is one, so add it to the query
+            $where = " AND ".$this->options['db_where'];
+        } else {
+            $where = '';
+        }
+
+        $query = sprintf("DELETE FROM %s WHERE %s = %s %s",
+                         $this->options['final_table'],
+                         $this->options['final_usernamecol'],
+                         $this->db->quoteSmart($username),
+                         $where
                          );
 
+        $this->log('Running SQL against DB: '.$query, AUTH_LOG_DEBUG);
+
         $res = $this->query($query);
 
         if (DB::isError($res)) {
@@ -504,15 +554,16 @@ class Auth_Container_DB extends Auth_Container
      */
     function changePassword($username, $password)
     {
+        $this->log('Auth_Container_DB::changePassword() called.', AUTH_LOG_DEBUG);
         $err = $this->_prepare();
         if ($err !== true) {
             return PEAR::raiseError($err->getMessage(), $err->getCode());
         }
 
-        if (   isset($this->options['cryptType']) 
+        if (   isset($this->options['cryptType'])
             && $this->options['cryptType'] == 'none') {
             $cryptFunction = 'strval';
-        } elseif (   isset($this->options['cryptType']) 
+        } elseif (   isset($this->options['cryptType'])
                   && function_exists($this->options['cryptType'])) {
             $cryptFunction = $this->options['cryptType'];
         } else {
@@ -521,14 +572,25 @@ class Auth_Container_DB extends Auth_Container
 
         $password = $cryptFunction($password);
 
-        $query = sprintf("UPDATE %s SET %s = %s WHERE %s = %s",
-                         $this->db->quoteIdentifier($this->options['table']),
-                         $this->db->quoteIdentifier($this->options['passwordcol']),
+        // check if there is an optional parameter db_where
+        if ($this->options['db_where'] != '') {
+            // there is one, so add it to the query
+            $where = " AND ".$this->options['db_where'];
+        } else {
+            $where = '';
+        }
+
+        $query = sprintf("UPDATE %s SET %s = %s WHERE %s = %s %s",
+                         $this->options['final_table'],
+                         $this->options['final_passwordcol'],
                          $this->db->quoteSmart($password),
-                         $this->db->quoteIdentifier($this->options['usernamecol']),
-                         $this->db->quoteSmart($username)
+                         $this->options['final_usernamecol'],
+                         $this->db->quoteSmart($username),
+                         $where
                          );
 
+        $this->log('Running SQL against DB: '.$query, AUTH_LOG_DEBUG);
+
         $res = $this->query($query);
 
         if (DB::isError($res)) {
