@@ -22,12 +22,6 @@
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 /**
 * @const SPREADSHEET_EXCEL_WRITER_ADD token identifier for character "+"
 */
@@ -182,9 +176,9 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         $this->_ext_sheets = array();
         $this->_references = array();
     }
-
+    
     /**
-    * Initialize the ptg and function hashes.
+    * Initialize the ptg and function hashes. 
     *
     * @access private
     */
@@ -288,7 +282,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             'ptgRefErr3dA' => 0x7C,
             'ptgAreaErr3d' => 0x7D
             );
-
+    
         // Thanks to Michael Meeks and Gnumeric for the initial arg values.
         //
         // The following hash was generated by "function_locale.pl" in the distro.
@@ -531,7 +525,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
               'ROMAN'           => array( 354,   -1,    1,    0 )
               );
     }
-
+    
     /**
     * Convert a token to the proper ptg value.
     *
@@ -602,7 +596,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         // TODO: use real error codes
         return $this->raiseError("Unknown token $token");
     }
-
+    
     /**
     * Convert a number token to ptgInt or ptgNum
     *
@@ -623,12 +617,12 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             return pack("Cd", $this->ptg['ptgNum'], $num);
         }
     }
-
+    
     /**
     * Convert a string token to ptgStr
     *
     * @access private
-    * @param string $string A string for conversion to its ptg value.
+    * @param string $string A string for conversion to its ptg value. 
     * @return mixed the converted token on success. PEAR_Error if the string
     *               is longer than 255 characters.
     */
@@ -647,7 +641,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             return pack("CCC", $this->ptg['ptgStr'], strlen($string), $encoding).$string;
         }
     }
-
+ 
     /**
     * Convert a function to a ptgFunc or ptgFuncVarV depending on the number of
     * args that it takes.
@@ -661,7 +655,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     {
         $args     = $this->_functions[$token][1];
         $volatile = $this->_functions[$token][3];
-
+    
         // Fixed number of args eg. TIME($i,$j,$k).
         if ($args >= 0) {
             return pack("Cv", $this->ptg['ptgFuncV'], $this->_functions[$token][0]);
@@ -671,7 +665,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             return pack("CCv", $this->ptg['ptgFuncVarV'], $num_args, $this->_functions[$token][0]);
         }
     }
-
+    
     /**
     * Convert an Excel range such as A1:D4 to a ptgRefV.
     *
@@ -681,20 +675,20 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     function _convertRange2d($range)
     {
         $class = 2; // as far as I know, this is magick.
-
+    
         // Split the range into 2 cell refs
         if (preg_match("/^([A-Ia-i]?[A-Za-z])(\d+)\:([A-Ia-i]?[A-Za-z])(\d+)$/",$range)) {
             list($cell1, $cell2) = split(':', $range);
         }
         elseif (preg_match("/^([A-Ia-i]?[A-Za-z])(\d+)\.\.([A-Ia-i]?[A-Za-z])(\d+)$/",$range)) {
             list($cell1, $cell2) = split('\.\.', $range);
-
+        
         }
         else {
             // TODO: use real error codes
             return $this->raiseError("Unknown range separator", 0, PEAR_ERROR_DIE);
         }
-
+    
         // Convert the cell references
         $cell_array1 = $this->_cellToPackedRowcol($cell1);
         if (PEAR::isError($cell_array1)) {
@@ -706,7 +700,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             return $cell_array2;
         }
         list($row2, $col2) = $cell_array2;
-
+    
         // The ptg value depends on the class of the ptg.
         if ($class == 0) {
             $ptgArea = pack("C", $this->ptg['ptgArea']);
@@ -723,7 +717,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         return $ptgArea . $row1 . $row2 . $col1. $col2;
     }
-
+ 
     /**
     * Convert an Excel 3d range such as "Sheet1!A1:D4" or "Sheet1:Sheet2!A1:D4" to
     * a ptgArea3d.
@@ -735,10 +729,10 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     function _convertRange3d($token)
     {
         $class = 2; // as far as I know, this is magick.
-
+ 
         // Split the ref at the ! symbol
         list($ext_ref, $range) = split('!', $token);
-
+ 
         // Convert the external reference part (different for BIFF8)
         if ($this->_BIFF_version == 0x0500) {
             $ext_ref = $this->_packExtRef($ext_ref);
@@ -755,7 +749,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
 
         // Split the range into 2 cell refs
         list($cell1, $cell2) = split(':', $range);
-
+ 
         // Convert the cell references
         if (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?(\d+)$/", $cell1))
         {
@@ -777,7 +771,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
              }
              list($row1, $col1, $row2, $col2) = $cells_array;
         }
-
+ 
         // The ptg value depends on the class of the ptg.
         if ($class == 0) {
             $ptgArea = pack("C", $this->ptg['ptgArea3d']);
@@ -791,7 +785,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         else {
             return $this->raiseError("Unknown class $class", 0, PEAR_ERROR_DIE);
         }
-
+ 
         return $ptgArea . $ext_ref . $row1 . $row2 . $col1. $col2;
     }
 
@@ -805,14 +799,14 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     function _convertRef2d($cell)
     {
         $class = 2; // as far as I know, this is magick.
-
+    
         // Convert the cell reference
         $cell_array = $this->_cellToPackedRowcol($cell);
         if (PEAR::isError($cell_array)) {
             return $cell_array;
         }
         list($row, $col) = $cell_array;
-
+    
         // The ptg value depends on the class of the ptg.
         if ($class == 0) {
             $ptgRef = pack("C", $this->ptg['ptgRef']);
@@ -829,7 +823,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         return $ptgRef.$row.$col;
     }
-
+    
     /**
     * Convert an Excel 3d reference such as "Sheet1!A1" or "Sheet1:Sheet2!A1" to a
     * ptgRef3d.
@@ -841,10 +835,10 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     function _convertRef3d($cell)
     {
         $class = 2; // as far as I know, this is magick.
-
+ 
         // Split the ref at the ! symbol
         list($ext_ref, $cell) = split('!', $cell);
-
+ 
         // Convert the external reference part (different for BIFF8)
         if ($this->_BIFF_version == 0x0500) {
             $ext_ref = $this->_packExtRef($ext_ref);
@@ -861,7 +855,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
 
         // Convert the cell reference part
         list($row, $col) = $this->_cellToPackedRowcol($cell);
-
+ 
         // The ptg value depends on the class of the ptg.
         if ($class == 0) {
             $ptgRef = pack("C", $this->ptg['ptgRef3d']);
@@ -891,12 +885,12 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     {
         $ext_ref = preg_replace("/^'/", '', $ext_ref); // Remove leading  ' if any.
         $ext_ref = preg_replace("/'$/", '', $ext_ref); // Remove trailing ' if any.
-
+ 
         // Check if there is a sheet range eg., Sheet1:Sheet2.
         if (preg_match("/:/", $ext_ref))
         {
             list($sheet_name1, $sheet_name2) = split(':', $ext_ref);
-
+ 
             $sheet1 = $this->_getSheetIndex($sheet_name1);
             if ($sheet1 == -1) {
                 return $this->raiseError("Unknown sheet name $sheet_name1 in formula");
@@ -905,7 +899,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             if ($sheet2 == -1) {
                 return $this->raiseError("Unknown sheet name $sheet_name2 in formula");
             }
-
+ 
             // Reverse max and min sheet numbers if necessary
             if ($sheet1 > $sheet2) {
                 list($sheet1, $sheet2) = array($sheet2, $sheet1);
@@ -919,7 +913,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $sheet2 = $sheet1;
         }
-
+ 
         // References are stored relative to 0xFFFF.
         $offset = -1 - $sheet1;
 
@@ -927,7 +921,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     }
 
     /**
-    * Look up the REF index that corresponds to an external sheet name
+    * Look up the REF index that corresponds to an external sheet name 
     * (or range). If it doesn't exist yet add it to the workbook's references
     * array. It assumes all sheet names given must exist.
     *
@@ -940,12 +934,12 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     {
         $ext_ref = preg_replace("/^'/", '', $ext_ref); // Remove leading  ' if any.
         $ext_ref = preg_replace("/'$/", '', $ext_ref); // Remove trailing ' if any.
-
+ 
         // Check if there is a sheet range eg., Sheet1:Sheet2.
         if (preg_match("/:/", $ext_ref))
         {
             list($sheet_name1, $sheet_name2) = split(':', $ext_ref);
-
+ 
             $sheet1 = $this->_getSheetIndex($sheet_name1);
             if ($sheet1 == -1) {
                 return $this->raiseError("Unknown sheet name $sheet_name1 in formula");
@@ -954,7 +948,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             if ($sheet2 == -1) {
                 return $this->raiseError("Unknown sheet name $sheet_name2 in formula");
             }
-
+ 
             // Reverse max and min sheet numbers if necessary
             if ($sheet1 > $sheet2) {
                 list($sheet1, $sheet2) = array($sheet2, $sheet1);
@@ -968,7 +962,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $sheet2 = $sheet1;
         }
-
+ 
         // assume all references belong to this document
         $supbook_index = 0x00;
         $ref = pack('vvv', $supbook_index, $sheet1, $sheet2);
@@ -993,7 +987,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
 
     /**
     * Look up the index that corresponds to an external sheet name. The hash of
-    * sheet names is updated by the addworksheet() method of the
+    * sheet names is updated by the addworksheet() method of the 
     * Spreadsheet_Excel_Writer_Workbook class.
     *
     * @access private
@@ -1042,7 +1036,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         if ($row >= 16384) {
             return $this->raiseError("Row in: $cell greater than 16384 ");
         }
-
+    
         // Set the high bits to indicate if row or col are relative.
         if ($this->_BIFF_version == 0x0500) {
             $row    |= $col_rel << 14;
@@ -1055,10 +1049,10 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             $col     = pack('v', $col);
         }
         $row     = pack('v', $row);
-
+    
         return array($row, $col);
     }
-
+    
     /**
     * pack() row range into the required 3 or 4 byte format.
     * Just using maximum col/rows, which is probably not the correct solution
@@ -1086,7 +1080,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         if (($row1 >= 16384) or ($row2 >= 16384)) {
             return $this->raiseError("Row in: $range greater than 16384 ");
         }
-
+    
         // Set the high bits to indicate if rows are relative.
         if ($this->_BIFF_version == 0x0500) {
             $row1    |= $row1_rel << 14; // FIXME: probably a bug
@@ -1102,7 +1096,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         $row1     = pack('v', $row1);
         $row2     = pack('v', $row2);
-
+    
         return array($row1, $col1, $row2, $col2);
     }
 
@@ -1123,7 +1117,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         $col_ref = $match[2];
         $row_rel = empty($match[3]) ? 1 : 0;
         $row     = $match[4];
-
+        
         // Convert base26 column string to a number.
         $expn   = strlen($col_ref) - 1;
         $col    = 0;
@@ -1132,14 +1126,14 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             $col += (ord($col_ref{$i}) - ord('A') + 1) * pow(26, $expn);
             $expn--;
         }
-
+    
         // Convert 1-index to zero-index
         $row--;
         $col--;
-
+    
         return array($row, $col, $row_rel, $col_rel);
     }
-
+    
     /**
     * Advance to the next valid token.
     *
@@ -1188,7 +1182,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         //die("Lexical error ".$this->_current_char);
     }
-
+    
     /**
     * Checks if it's a valid token.
     *
@@ -1252,7 +1246,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             default:
                 // if it's a reference
                 if (preg_match('/^\$?[A-Ia-i]?[A-Za-z]\$?[0-9]+$/',$token) and
-                   !ereg("[0-9]",$this->_lookahead) and
+                   !ereg("[0-9]",$this->_lookahead) and 
                    ($this->_lookahead != ':') and ($this->_lookahead != '.') and
                    ($this->_lookahead != '!'))
                 {
@@ -1273,13 +1267,13 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
                     return $token;
                 }
                 // if it's a range (A1:A2)
-                elseif (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+:(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$token) and
+                elseif (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+:(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$token) and 
                        !ereg("[0-9]",$this->_lookahead))
                 {
                     return $token;
                 }
                 // if it's a range (A1..A2)
-                elseif (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+\.\.(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$token) and
+                elseif (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+\.\.(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$token) and 
                        !ereg("[0-9]",$this->_lookahead))
                 {
                     return $token;
@@ -1297,7 +1291,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
                     return $token;
                 }
                 // If it's a number (check that it's not a sheet name or range)
-                elseif (is_numeric($token) and
+                elseif (is_numeric($token) and 
                         (!is_numeric($token.$this->_lookahead) or ($this->_lookahead == '')) and
                         ($this->_lookahead != '!') and ($this->_lookahead != ':'))
                 {
@@ -1316,7 +1310,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
                 return '';
         }
     }
-
+    
     /**
     * The parsing method. It parses a formula.
     *
@@ -1337,7 +1331,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         return true;
     }
-
+    
     /**
     * It parses a condition. It assumes the following rule:
     * Cond -> Expr [(">" | "<") Expr]
@@ -1360,7 +1354,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $result = $this->_createTree('ptgLT', $result, $result2);
         }
-        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_GT)
+        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_GT) 
         {
             $this->_advance();
             $result2 = $this->_expression();
@@ -1369,7 +1363,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $result = $this->_createTree('ptgGT', $result, $result2);
         }
-        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_LE)
+        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_LE) 
         {
             $this->_advance();
             $result2 = $this->_expression();
@@ -1378,7 +1372,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $result = $this->_createTree('ptgLE', $result, $result2);
         }
-        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_GE)
+        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_GE) 
         {
             $this->_advance();
             $result2 = $this->_expression();
@@ -1387,7 +1381,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $result = $this->_createTree('ptgGE', $result, $result2);
         }
-        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_EQ)
+        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_EQ) 
         {
             $this->_advance();
             $result2 = $this->_expression();
@@ -1396,7 +1390,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             }
             $result = $this->_createTree('ptgEQ', $result, $result2);
         }
-        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_NE)
+        elseif ($this->_current_token == SPREADSHEET_EXCEL_WRITER_NE) 
         {
             $this->_advance();
             $result2 = $this->_expression();
@@ -1436,7 +1430,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         if (PEAR::isError($result)) {
             return $result;
         }
-        while (($this->_current_token == SPREADSHEET_EXCEL_WRITER_ADD) or
+        while (($this->_current_token == SPREADSHEET_EXCEL_WRITER_ADD) or 
                ($this->_current_token == SPREADSHEET_EXCEL_WRITER_SUB))
         {
             if ($this->_current_token == SPREADSHEET_EXCEL_WRITER_ADD)
@@ -1448,7 +1442,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
                 }
                 $result = $this->_createTree('ptgAdd', $result, $result2);
             }
-            else
+            else 
             {
                 $this->_advance();
                 $result2 = $this->_term();
@@ -1460,7 +1454,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         return $result;
     }
-
+    
     /**
     * This function just introduces a ptgParen element in the tree, so that Excel
     * doesn't get confused when working with a parenthesized formula afterwards.
@@ -1474,7 +1468,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         $result = $this->_createTree('ptgParen', $this->_expression(), '');
         return $result;
     }
-
+    
     /**
     * It parses a term. It assumes the following rule:
     * Term -> Fact [("*" | "/") Fact]
@@ -1488,7 +1482,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         if (PEAR::isError($result)) {
             return $result;
         }
-        while (($this->_current_token == SPREADSHEET_EXCEL_WRITER_MUL) or
+        while (($this->_current_token == SPREADSHEET_EXCEL_WRITER_MUL) or 
                ($this->_current_token == SPREADSHEET_EXCEL_WRITER_DIV))
         {
             if ($this->_current_token == SPREADSHEET_EXCEL_WRITER_MUL)
@@ -1500,7 +1494,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
                 }
                 $result = $this->_createTree('ptgMul', $result, $result2);
             }
-            else
+            else 
             {
                 $this->_advance();
                 $result2 = $this->_fact();
@@ -1512,7 +1506,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         }
         return $result;
     }
-
+    
     /**
     * It parses a factor. It assumes the following rule:
     * Fact -> ( Expr )
@@ -1558,7 +1552,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
             return $result;
         }
         // if it's a range
-        elseif (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+:(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$this->_current_token) or
+        elseif (preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+:(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$this->_current_token) or 
                 preg_match("/^(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+\.\.(\$)?[A-Ia-i]?[A-Za-z](\$)?[0-9]+$/",$this->_current_token))
         {
             $result = $this->_current_token;
@@ -1595,7 +1589,7 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
                                  ", lookahead: ".$this->_lookahead.
                                  ", current char: ".$this->_current_char);
     }
-
+    
     /**
     * It parses a function call. It assumes the following rule:
     * Func -> ( Expr [,Expr]* )
@@ -1643,12 +1637,12 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
         if (($args >= 0) and ($args != $num_args)) {
             return $this->raiseError("Incorrect number of arguments in function $function() ");
         }
-
+    
         $result = $this->_createTree($function, $result, $num_args);
         $this->_advance();         // eat the ")"
         return $result;
     }
-
+    
     /**
     * Creates a tree. In fact an array which may have one or two arrays (sub-trees)
     * as elements.
@@ -1663,12 +1657,12 @@ class Spreadsheet_Excel_Writer_Parser extends PEAR
     {
         return array('value' => $value, 'left' => $left, 'right' => $right);
     }
-
+    
     /**
-    * Builds a string containing the tree in reverse polish notation (What you
+    * Builds a string containing the tree in reverse polish notation (What you 
     * would use in a HP calculator stack).
     * The following tree:
-    *
+    * 
     *    +
     *   / \
     *  2   3
