@@ -5,7 +5,7 @@
 *  The majority of this is _NOT_ my code.  I simply ported it from the
 *  PERL Spreadsheet::WriteExcel module.
 *
-*  The author of the Spreadsheet::WriteExcel module is John McNamara
+*  The author of the Spreadsheet::WriteExcel module is John McNamara 
 *  <jmcnamara@cpan.org>
 *
 *  I _DO_ maintain this code, and John McNamara has nothing to do with the
@@ -32,11 +32,6 @@
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
 
 /**
 * Class for generating Excel Spreadsheets
@@ -174,7 +169,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         // It needs to call its parent's constructor explicitly
         $this->Spreadsheet_Excel_Writer_BIFFwriter();
-
+    
         $this->_filename         = $filename;
         $this->_parser           =& new Spreadsheet_Excel_Writer_Parser($this->_byte_order, $this->_BIFF_version);
         $this->_1904             = 0;
@@ -192,7 +187,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $this->_palette          = array();
         $this->_codepage         = 0x04E4; // FIXME: should change for BIFF8
         $this->_country_code     = -1;
-
+    
         // Add the default format for hyperlinks
         $this->_url_format =& $this->addFormat(array('color' => 'blue', 'underline' => 1));
         $this->_str_total       = 0;
@@ -201,7 +196,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $this->_setPaletteXl97();
         $this->_tmp_dir         = '';
     }
-
+    
     /**
     * Calls finalization methods.
     * This method should always be the last one to be called on every workbook
@@ -221,7 +216,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $this->_fileclosed = 1;
         return true;
     }
-
+ 
     /**
     * An accessor for the _worksheets[] array
     * Returns an array of the worksheet objects in a workbook
@@ -235,7 +230,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         return $this->worksheets();
     }
-
+    
     /**
     * An accessor for the _worksheets[] array.
     * Returns an array of the worksheet objects in a workbook
@@ -247,7 +242,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         return $this->_worksheets;
     }
-
+ 
     /**
     * Sets the BIFF version.
     * This method exists just to access experimental functionality
@@ -307,16 +302,16 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $index     = count($this->_worksheets);
         $sheetname = $this->_sheetname;
-
+    
         if ($name == '') {
-            $name = $sheetname.($index+1);
+            $name = $sheetname.($index+1); 
         }
-
+    
         // Check that sheetname is <= 31 chars (Excel limit).
         if (strlen($name) > 31) {
             return $this->raiseError("Sheetname $name must be <= 31 chars");
         }
-
+    
         // Check that the worksheet name doesn't already exist: a fatal Excel error.
         $total_worksheets = count($this->_worksheets);
         for ($i=0; $i < $total_worksheets; $i++)
@@ -325,7 +320,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                 return $this->raiseError("Worksheet '$name' already exists");
             }
         }
-
+    
         $worksheet = new Spreadsheet_Excel_Writer_Worksheet($this->_BIFF_version,
                                    $name, $index,
                                    $this->_activesheet, $this->_firstsheet,
@@ -338,7 +333,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $this->_parser->setExtSheet($name, $index);  // Register worksheet name with parser
         return $worksheet;
     }
-
+    
     /**
     * Add a new format to the Excel workbook.
     * Also, pass any properties to the Format constructor.
@@ -354,7 +349,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $this->_formats[] = &$format;
         return $format;
     }
-
+    
     /**
      * Create new validator.
      *
@@ -385,28 +380,28 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         /*if (defined $_[1] and $_[1] =~ /^#(\w\w)(\w\w)(\w\w)/ ) {
             @_ = ($_[0], hex $1, hex $2, hex $3);
         }*/
-
+    
         // Check that the colour index is the right range
         if ($index < 8 or $index > 64) {
             // TODO: assign real error codes
             return $this->raiseError("Color index $index outside range: 8 <= index <= 64");
         }
-
+    
         // Check that the colour components are in the right range
         if ( ($red   < 0 or $red   > 255) or
              ($green < 0 or $green > 255) or
-             ($blue  < 0 or $blue  > 255) )
+             ($blue  < 0 or $blue  > 255) )  
         {
             return $this->raiseError("Color component outside range: 0 <= color <= 255");
         }
-
+    
         $index -= 8; // Adjust colour index (wingless dragonfly)
-
+        
         // Set the RGB value
         $this->_palette[$index] = array($red, $green, $blue, 0);
         return($index + 8);
     }
-
+    
     /**
     * Sets the colour palette to the Excel 97+ default.
     *
@@ -473,7 +468,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                            array(0x33, 0x33, 0x33, 0x00),   // 63
                          );
     }
-
+    
     /**
     * Assemble worksheets into a workbook and send the BIFF data to an OLE
     * storage.
@@ -487,7 +482,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         if ($this->_activesheet == 0) {
             $this->_worksheets[0]->selected = 1;
         }
-
+    
         // Calculate the number of selected worksheet tabs and call the finalization
         // methods for each worksheet
         $total_worksheets = count($this->_worksheets);
@@ -497,7 +492,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             }
             $this->_worksheets[$i]->close($this->_sheetnames);
         }
-
+    
         // Add Workbook globals
         $this->_storeBof(0x0005);
         if ($this->_BIFF_version == 0x0600) {
@@ -518,19 +513,19 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $this->_storeAllStyles();
         $this->_storePalette();
         $this->_calcSheetOffsets();
-
+    
         // Add BOUNDSHEET records
         for ($i=0; $i < $total_worksheets; $i++) {
             $this->_storeBoundsheet($this->_worksheets[$i]->name,$this->_worksheets[$i]->offset);
         }
-
+ 
         if ($this->_country_code != -1) {
             $this->_storeCountry();
         }
 
         if ($this->_BIFF_version == 0x0600) {
             //$this->_storeSupbookInternal();
-            /* TODO: store external SUPBOOK records and XCT and CRN records
+            /* TODO: store external SUPBOOK records and XCT and CRN records 
             in case of external references for BIFF8 */
             //$this->_storeExternsheetBiff8();
             $this->_storeSharedStringsTable();
@@ -538,7 +533,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
 
         // End Workbook globals
         $this->_storeEof();
-
+    
         // Store the workbook in an OLE container
         $res = $this->_storeOLEFile();
         if ($this->isError($res)) {
@@ -546,7 +541,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         }
         return true;
     }
-
+ 
     /**
     * Sets the temp dir used for storing the OLE file
     *
@@ -597,7 +592,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         }
         return true;
     }
-
+ 
     /**
     * Calculate offsets for Worksheet BOF records.
     *
@@ -625,7 +620,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             //$offset += 8; // FIXME: calculate real value when storing the records
         }
         $total_worksheets = count($this->_worksheets);
-        // add the length of the BOUNDSHEET records
+        // add the length of the BOUNDSHEET records 
         for ($i=0; $i < $total_worksheets; $i++) {
             $offset += $boundsheet_length + strlen($this->_worksheets[$i]->name);
         }
@@ -637,7 +632,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         }
         $this->_biffsize = $offset;
     }
-
+    
     /**
     * Store the Excel FONT records.
     *
@@ -648,20 +643,20 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         // tmp_format is added by the constructor. We use this to write the default XF's
         $format = $this->_tmp_format;
         $font   = $format->getFont();
-
+    
         // Note: Fonts are 0-indexed. According to the SDK there is no index 4,
         // so the following fonts are 0, 1, 2, 3, 5
         //
         for ($i=1; $i <= 5; $i++){
             $this->_append($font);
         }
-
+    
         // Iterate through the XF objects and write a FONT record if it isn't the
         // same as the default FONT and if it hasn't already been used.
         //
         $fonts = array();
         $index = 6;                  // The first user defined FONT
-
+    
         $key = $format->getFontKey(); // The default font from _tmp_format
         $fonts[$key] = 0;             // Index of the default font
 
@@ -683,7 +678,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             }
         }
     }
-
+    
     /**
     * Store user defined numerical formats i.e. FORMAT records
     *
@@ -695,14 +690,14 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $hash_num_formats = array();
         $num_formats      = array();
         $index = 164;
-
+    
         // Iterate through the XF objects and write a FORMAT record if it isn't a
         // built-in format type and if the FORMAT string hasn't already been used.
         $total_formats = count($this->_formats);
         for ($i=0; $i < $total_formats; $i++)
         {
             $num_format = $this->_formats[$i]->_num_format;
-
+    
             // Check if $num_format is an index to a built-in format.
             // Also check for a string of zeros, which is a valid format string
             // but would evaluate to zero.
@@ -713,7 +708,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                     continue;
                 }
             }
-
+    
             if (isset($hash_num_formats[$num_format])) {
                 // FORMAT has already been used
                 $this->_formats[$i]->_num_format = $hash_num_formats[$num_format];
@@ -726,7 +721,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                 $index++;
             }
         }
-
+    
         // Write the new FORMAT records starting from 0xA4
         $index = 164;
         foreach ($num_formats as $num_format) {
@@ -734,7 +729,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             $index++;
         }
     }
-
+    
     /**
     * Write all XF records.
     *
@@ -750,10 +745,10 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             $xf = $format->getXf('style'); // Style XF
             $this->_append($xf);
         }
-
+    
         $xf = $format->getXf('cell');      // Cell XF
         $this->_append($xf);
-
+    
         // User defined XFs
         $total_formats = count($this->_formats);
         for ($i=0; $i < $total_formats; $i++) {
@@ -761,17 +756,17 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             $this->_append($xf);
         }
     }
-
+    
     /**
     * Write all STYLE records.
     *
-    * @access private
+    * @access private 
     */
     function _storeAllStyles()
     {
         $this->_storeStyle();
     }
-
+    
     /**
     * Write the EXTERNCOUNT and EXTERNSHEET records. These are used as indexes for
     * the NAME records.
@@ -782,13 +777,13 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         // Create EXTERNCOUNT with number of worksheets
         $this->_storeExterncount(count($this->_worksheets));
-
+    
         // Create EXTERNSHEET for each worksheet
         foreach ($this->_sheetnames as $sheetname) {
             $this->_storeExternsheet($sheetname);
         }
     }
-
+    
     /**
     * Write the NAME record to define the print area and the repeat rows and cols.
     *
@@ -812,7 +807,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                     );
             }
         }
-
+    
         // Create the print title NAME records
         $total_worksheets = count($this->_worksheets);
         for ($i = 0; $i < $total_worksheets; $i++) {
@@ -820,7 +815,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             $rowmax = $this->_worksheets[$i]->title_rowmax;
             $colmin = $this->_worksheets[$i]->title_colmin;
             $colmax = $this->_worksheets[$i]->title_colmax;
-
+    
             // Determine if row + col, row, col or nothing has been defined
             // and write the appropriate record
             //
@@ -863,16 +858,16 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             }
         }
     }
-
-
-
-
+    
+    
+    
+    
     /******************************************************************************
     *
     * BIFF RECORDS
     *
     */
-
+    
     /**
     * Stores the CODEPAGE biff record.
     *
@@ -883,10 +878,10 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $record          = 0x0042;             // Record identifier
         $length          = 0x0002;             // Number of bytes to follow
         $cv              = $this->_codepage;   // The code page
-
+ 
         $header          = pack('vv', $record, $length);
         $data            = pack('v',  $cv);
-
+ 
         $this->_append($header.$data);
     }
 
@@ -899,19 +894,19 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record    = 0x003D;                 // Record identifier
         $length    = 0x0012;                 // Number of bytes to follow
-
+    
         $xWn       = 0x0000;                 // Horizontal position of window
         $yWn       = 0x0000;                 // Vertical position of window
         $dxWn      = 0x25BC;                 // Width of window
         $dyWn      = 0x1572;                 // Height of window
-
+    
         $grbit     = 0x0038;                 // Option flags
         $ctabsel   = $this->_selected;       // Number of workbook tabs selected
         $wTabRatio = 0x0258;                 // Tab to scrollbar ratio
-
+    
         $itabFirst = $this->_firstsheet;     // 1st displayed worksheet
         $itabCur   = $this->_activesheet;    // Active worksheet
-
+    
         $header    = pack("vv",        $record, $length);
         $data      = pack("vvvvvvvvv", $xWn, $yWn, $dxWn, $dyWn,
                                        $grbit,
@@ -919,7 +914,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                                        $ctabsel, $wTabRatio);
         $this->_append($header.$data);
     }
-
+    
     /**
     * Writes Excel BIFF BOUNDSHEET record.
     * FIXME: inconsistent with BIFF documentation
@@ -937,10 +932,10 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         else {
             $length = 0x07 + strlen($sheetname); // Number of bytes to follow
         }
-
+    
         $grbit     = 0x0000;                    // Visibility and sheet type
         $cch       = strlen($sheetname);        // Length of sheet name
-
+    
         $header    = pack("vv",  $record, $length);
         if ($this->_BIFF_version == 0x0600) {
             $data      = pack("Vvv", $offset, $grbit, $cch);
@@ -950,7 +945,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         }
         $this->_append($header.$data.$sheetname);
     }
-
+ 
     /**
     * Write Internal SUPBOOK record
     *
@@ -960,7 +955,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record    = 0x01AE;   // Record identifier
         $length    = 0x0004;   // Bytes to follow
-
+                               
         $header    = pack("vv", $record, $length);
         $data      = pack("vv", count($this->_worksheets), 0x0104);
         $this->_append($header.$data);
@@ -968,7 +963,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
 
     /**
     * Writes the Excel BIFF EXTERNSHEET record. These references are used by
-    * formulas.
+    * formulas. 
     *
     * @param string $sheetname Worksheet name
     * @access private
@@ -997,17 +992,17 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record    = 0x0293;   // Record identifier
         $length    = 0x0004;   // Bytes to follow
-
+                               
         $ixfe      = 0x8000;   // Index to style XF
         $BuiltIn   = 0x00;     // Built-in style
         $iLevel    = 0xff;     // Outline style level
-
+    
         $header    = pack("vv",  $record, $length);
         $data      = pack("vCC", $ixfe, $BuiltIn, $iLevel);
         $this->_append($header.$data);
     }
-
-
+    
+    
     /**
     * Writes Excel FORMAT record for non "built-in" numerical formats.
     *
@@ -1028,7 +1023,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         }
 
         $cch       = strlen($format);             // Length of format string
-
+    
         $header    = pack("vv", $record, $length);
         if ($this->_BIFF_version == 0x0600) {
             $data      = pack("vvC", $ifmt, $cch, $encoding);
@@ -1038,7 +1033,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         }
         $this->_append($header.$data.$format);
     }
-
+    
     /**
     * Write DATEMODE record to indicate the date system in use (1904 or 1900).
     *
@@ -1048,15 +1043,15 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record    = 0x0022;         // Record identifier
         $length    = 0x0002;         // Bytes to follow
-
+    
         $f1904     = $this->_1904;   // Flag for 1904 date system
-
+    
         $header    = pack("vv", $record, $length);
         $data      = pack("v", $f1904);
         $this->_append($header.$data);
     }
-
-
+    
+    
     /**
     * Write BIFF record EXTERNCOUNT to indicate the number of external sheet
     * references in the workbook.
@@ -1074,13 +1069,13 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record   = 0x0016;          // Record identifier
         $length   = 0x0002;          // Number of bytes to follow
-
+    
         $header   = pack("vv", $record, $length);
         $data     = pack("v",  $cxals);
         $this->_append($header.$data);
     }
-
-
+    
+    
     /**
     * Writes the Excel BIFF EXTERNSHEET record. These references are used by
     * formulas. NAME record is required to define the print area and the repeat
@@ -1095,16 +1090,16 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record      = 0x0017;                     // Record identifier
         $length      = 0x02 + strlen($sheetname);  // Number of bytes to follow
-
+                                                   
         $cch         = strlen($sheetname);         // Length of sheet name
         $rgch        = 0x03;                       // Filename encoding
-
+    
         $header      = pack("vv",  $record, $length);
         $data        = pack("CC", $cch, $rgch);
         $this->_append($header.$data.$sheetname);
     }
-
-
+    
+    
     /**
     * Store the NAME record in the short format that is used for storing the print
     * area, repeat rows only and repeat columns only.
@@ -1121,7 +1116,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     {
         $record          = 0x0018;       // Record identifier
         $length          = 0x0024;       // Number of bytes to follow
-
+    
         $grbit           = 0x0020;       // Option flags
         $chKey           = 0x00;         // Keyboard shortcut
         $cch             = 0x01;         // Length of text name
@@ -1133,14 +1128,14 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $cchHelptopic    = 0x00;         // Length of help topic text
         $cchStatustext   = 0x00;         // Length of status bar text
         $rgch            = $type;        // Built-in name type
-
+    
         $unknown03       = 0x3b;
         $unknown04       = 0xffff-$index;
         $unknown05       = 0x0000;
         $unknown06       = 0x0000;
         $unknown07       = 0x1087;
         $unknown08       = 0x8005;
-
+    
         $header             = pack("vv", $record, $length);
         $data               = pack("v", $grbit);
         $data              .= pack("C", $chKey);
@@ -1167,8 +1162,8 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $data              .= pack("C", $colmax);
         $this->_append($header.$data);
     }
-
-
+    
+    
     /**
     * Store the NAME record in the long format that is used for storing the repeat
     * rows and columns when both are specified. This shares a lot of code with
@@ -1198,7 +1193,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $cchHelptopic    = 0x00;         // Length of help topic text
         $cchStatustext   = 0x00;         // Length of status bar text
         $rgch            = $type;        // Built-in name type
-
+    
         $unknown01       = 0x29;
         $unknown02       = 0x002b;
         $unknown03       = 0x3b;
@@ -1207,7 +1202,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         $unknown06       = 0x0000;
         $unknown07       = 0x1087;
         $unknown08       = 0x8008;
-
+    
         $header             = pack("vv",  $record, $length);
         $data               = pack("v", $grbit);
         $data              .= pack("C", $chKey);
@@ -1277,12 +1272,12 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
     function _storePalette()
     {
         $aref            = $this->_palette;
-
+    
         $record          = 0x0092;                 // Record identifier
         $length          = 2 + 4 * count($aref);   // Number of bytes to follow
         $ccv             =         count($aref);   // Number of RGB values to follow
         $data = '';                                // The RGB data
-
+    
         // Pack the RGB data
         foreach($aref as $color)
         {
@@ -1290,7 +1285,7 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                 $data .= pack("C",$byte);
             }
         }
-
+    
         $header = pack("vvv",  $record, $length, $ccv);
         $this->_append($header.$data);
     }
@@ -1327,44 +1322,44 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
 
         foreach (array_keys($this->_str_table) as $string) {
             $string_length = strlen($string);
-
+ 
             // Block length is the total length of the strings that will be
             // written out in a single SST or CONTINUE block.
             $block_length += $string_length;
-
+ 
             // We can write the string if it doesn't cross a CONTINUE boundary
             if ($block_length < $continue_limit) {
                 $written      += $string_length;
                 $total_offset += $string_length;
                 continue;
             }
-
+ 
             // Deal with the cases where the next string to be written will exceed
             // the CONTINUE boundary. If the string is very long it may need to be
             // written in more than one CONTINUE record.
             while ($block_length >= $continue_limit) {
-
+ 
                 // We need to avoid the case where a string is continued in the first
                 // n bytes that contain the string header information.
                 $header_length   = 3; // Min string + header size -1
                 $space_remaining = $continue_limit - $written - $continue;
-
-
+ 
+ 
                 /* TODO: Unicode data should only be split on char (2 byte)
                 boundaries. Therefore, in some cases we need to reduce the
                 amount of available
                 */
-
+ 
                 if ($space_remaining > $header_length) {
                     // Write as much as possible of the string in the current block
                     $written      += $space_remaining;
-
+ 
                     // Reduce the current block length by the amount written
                     $block_length -= $continue_limit + $continue;
-
+ 
                     // Store the max size for this block
                     $this->_block_sizes[] = $continue_limit;
-
+ 
                     // If the current string was split then the next CONTINUE block
                     // should have the string continue flag (grbit) set unless the
                     // split string fits exactly into the remaining space.
@@ -1374,18 +1369,18 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                     else {
                         $continue = 0;
                     }
-
+ 
                 }
                 else {
                     // Store the max size for this block
                     $this->_block_sizes[] = $written + $continue;
-
+ 
                     // Not enough space to start the string in the current block
                     $block_length -= $continue_limit - $space_remaining - $continue;
                     $continue = 0;
-
+ 
                 }
-
+ 
                 // If the string (or substr) is small enough we can write it in the
                 // new CONTINUE block. Else, go through the loop again to write it in
                 // one or more CONTINUE blocks
@@ -1402,8 +1397,8 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
         if ($written + $continue) {
             $this->_block_sizes[] = $written + $continue;
         }
-
-
+ 
+ 
         /* Calculate the total length of the SST and associated CONTINUEs (if any).
          The SST record will have a length even if it contains no strings.
          This length is required to set the offsets in the BOUNDSHEET records since
@@ -1451,47 +1446,47 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
             $string_length = strlen($string);
             $encoding      = 0; // assume there are no Unicode strings
             $split_string  = 0;
-
+ 
             // Block length is the total length of the strings that will be
             // written out in a single SST or CONTINUE block.
             //
             $block_length += $string_length;
-
-
+ 
+ 
             // We can write the string if it doesn't cross a CONTINUE boundary
             if ($block_length < $continue_limit) {
                 $this->_append($string);
                 $written += $string_length;
                 continue;
             }
-
+ 
             // Deal with the cases where the next string to be written will exceed
             // the CONTINUE boundary. If the string is very long it may need to be
             // written in more than one CONTINUE record.
-            //
+            // 
             while ($block_length >= $continue_limit) {
-
+ 
                 // We need to avoid the case where a string is continued in the first
                 // n bytes that contain the string header information.
                 //
                 $header_length   = 3; // Min string + header size -1
                 $space_remaining = $continue_limit - $written - $continue;
-
-
+ 
+ 
                 // Unicode data should only be split on char (2 byte) boundaries.
                 // Therefore, in some cases we need to reduce the amount of available
-
+ 
                 if ($space_remaining > $header_length) {
                     // Write as much as possible of the string in the current block
                     $tmp = substr($string, 0, $space_remaining);
                     $this->_append($tmp);
-
+ 
                     // The remainder will be written in the next block(s)
                     $string = substr($string, $space_remaining);
-
+ 
                     // Reduce the current block length by the amount written
                     $block_length -= $continue_limit - $continue;
-
+ 
                     // If the current string was split then the next CONTINUE block
                     // should have the string continue flag (grbit) set unless the
                     // split string fits exactly into the remaining space.
@@ -1508,26 +1503,26 @@ class Spreadsheet_Excel_Writer_Workbook extends Spreadsheet_Excel_Writer_BIFFwri
                     $block_length -= $continue_limit - $space_remaining - $continue;
                     $continue = 0;
                 }
-
+ 
                 // Write the CONTINUE block header
                 if (!empty($this->_block_sizes)) {
                     $record  = 0x003C;
                     $length  = array_pop($this->_block_sizes);
-
+ 
                     $header  = pack('vv', $record, $length);
                     if ($continue) {
                         $header .= pack('C', $encoding);
                     }
                     $this->_append($header);
                 }
-
+ 
                 // If the string (or substr) is small enough we can write it in the
                 // new CONTINUE block. Else, go through the loop again to write it in
                 // one or more CONTINUE blocks
                 //
                 if ($block_length < $continue_limit) {
                     $this->_append($string);
-
+ 
                     $written = $block_length;
                 }
                 else {
