@@ -17,13 +17,8 @@
 // | Based on OLE::Storage_Lite by Kawai, Takanori                        |
 // +----------------------------------------------------------------------+
 //
-// $Id: root.php,v 1.1.2.2 2008/02/21 22:31:40 marclaporte Exp $
+// $Id: root.php,v 1.1 2004-05-01 21:44:23 lphuberdeau Exp $
 
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
 
 /**
 * Class for creating Root PPS's for OLE containers
@@ -39,7 +34,7 @@ class OLE_PPS_Root extends OLE_PPS
     * @var string
     */
     var $_tmp_dir;
-
+    
     /**
     * Constructor
     *
@@ -51,7 +46,7 @@ class OLE_PPS_Root extends OLE_PPS
     {
         $this->_tmp_dir = '';
         $this->OLE_PPS(
-           null,
+           null, 
            OLE::Asc2Ucs('Root Entry'),
            OLE_PPS_TYPE_ROOT,
            null,
@@ -93,9 +88,9 @@ class OLE_PPS_Root extends OLE_PPS
         // Initial Setting for saving
         $this->_BIG_BLOCK_SIZE  = pow(2,
                       ((isset($this->_BIG_BLOCK_SIZE))? $this->_adjust2($this->_BIG_BLOCK_SIZE)  : 9));
-        $this->_SMALL_BLOCK_SIZE= pow(2,
+        $this->_SMALL_BLOCK_SIZE= pow(2, 
                       ((isset($this->_SMALL_BLOCK_SIZE))?  $this->_adjust2($this->_SMALL_BLOCK_SIZE): 6));
-
+ 
         // Open temp file if we are sending output to stdout
         if (($filename == '-') or ($filename == ''))
         {
@@ -119,10 +114,10 @@ class OLE_PPS_Root extends OLE_PPS
         list($iSBDcnt, $iBBcnt, $iPPScnt) = $this->_calcSize($aList); //, $rhInfo);
         // Save Header
         $this->_saveHeader($iSBDcnt, $iBBcnt, $iPPScnt);
-
+  
         // Make Small Data string (write SBD)
         $this->_data = $this->_makeSmallData($aList);
-
+  
         // Write BB
         $this->_saveBigData($iSBDcnt, $aList);
         // Write PPS
@@ -151,7 +146,7 @@ class OLE_PPS_Root extends OLE_PPS
     * @param array $raList Reference to an array of PPS's
     * @return array The array of numbers
     */
-    function _calcSize(&$raList)
+    function _calcSize(&$raList) 
     {
         // Calculate Basic Setting
         list($iSBDcnt, $iBBcnt, $iPPScnt) = array(0,0,0);
@@ -178,7 +173,7 @@ class OLE_PPS_Root extends OLE_PPS
         $iCnt = count($raList);
         $iBdCnt = $this->_BIG_BLOCK_SIZE / OLE_PPS_SIZE;
         $iPPScnt = (floor($iCnt/$iBdCnt) + (($iCnt % $iBdCnt)? 1: 0));
-
+   
         return array($iSBDcnt, $iBBcnt, $iPPScnt);
     }
 
@@ -207,17 +202,17 @@ class OLE_PPS_Root extends OLE_PPS
     function _saveHeader($iSBDcnt, $iBBcnt, $iPPScnt)
     {
         $FILE = $this->_FILEH_;
-
+  
         // Calculate Basic Setting
         $iBlCnt = $this->_BIG_BLOCK_SIZE / OLE_LONG_INT_SIZE;
         $i1stBdL = ($this->_BIG_BLOCK_SIZE - 0x4C) / OLE_LONG_INT_SIZE;
-
+  
         $iBdExL = 0;
         $iAll = $iBBcnt + $iPPScnt + $iSBDcnt;
         $iAllW = $iAll;
         $iBdCntW = floor($iAllW / $iBlCnt) + (($iAllW % $iBlCnt)? 1: 0);
         $iBdCnt = floor(($iAll + $iBdCntW) / $iBlCnt) + ((($iAllW+$iBdCntW) % $iBlCnt)? 1: 0);
-
+  
         // Calculate BD count
         if ($iBdCnt >$i1stBdL)
         {
@@ -232,7 +227,7 @@ class OLE_PPS_Root extends OLE_PPS
                 }
             }
         }
-
+  
         // Save Header
         fwrite($FILE,
                   "\xD0\xCF\x11\xE0\xA1\xB1\x1A\xE1"
@@ -248,7 +243,7 @@ class OLE_PPS_Root extends OLE_PPS
                   . pack("v", 0)
                   . "\x00\x00\x00\x00"
                   . "\x00\x00\x00\x00"
-                  . pack("V", $iBdCnt)
+                  . pack("V", $iBdCnt) 
                   . pack("V", $iBBcnt+$iSBDcnt) //ROOT START
                   . pack("V", 0)
                   . pack("V", 0x1000)
@@ -290,7 +285,7 @@ class OLE_PPS_Root extends OLE_PPS
     function _saveBigData($iStBlk, &$raList)
     {
         $FILE = $this->_FILEH_;
-
+   
         // cycle through PPS's
         for ($i = 0; $i < count($raList); $i++)
         {
@@ -314,7 +309,7 @@ class OLE_PPS_Root extends OLE_PPS
                     else {
                         fwrite($FILE, $raList[$i]->_data);
                     }
-
+           
                     if ($raList[$i]->Size % $this->_BIG_BLOCK_SIZE)
                     {
                         for ($j = 0; $j < ($this->_BIG_BLOCK_SIZE - ($raList[$i]->Size % $this->_BIG_BLOCK_SIZE)); $j++) {
@@ -323,7 +318,7 @@ class OLE_PPS_Root extends OLE_PPS
                     }
                     // Set For PPS
                     $raList[$i]->_StartBlock = $iStBlk;
-                    $iStBlk +=
+                    $iStBlk += 
                             (floor($raList[$i]->Size / $this->_BIG_BLOCK_SIZE) +
                                 (($raList[$i]->Size % $this->_BIG_BLOCK_SIZE)? 1: 0));
                 }
@@ -349,7 +344,7 @@ class OLE_PPS_Root extends OLE_PPS
         $sRes = '';
         $FILE = $this->_FILEH_;
         $iSmBlk = 0;
-
+   
         for ($i = 0; $i < count($raList); $i++)
         {
             // Make SBD, small data string
@@ -367,7 +362,7 @@ class OLE_PPS_Root extends OLE_PPS
                         fwrite($FILE, pack("V", $j+$iSmBlk+1));
                     }
                     fwrite($FILE, pack("V", -2));
-
+                   
                     // Add to Data String(this will be written for RootEntry)
                     if ($raList[$i]->_PPS_FILE)
                     {
@@ -407,7 +402,7 @@ class OLE_PPS_Root extends OLE_PPS
     * @access private
     * @param array $raList Reference to an array with all PPS's
     */
-    function _savePps(&$raList)
+    function _savePps(&$raList) 
     {
         // Save each PPS WK
         for ($i = 0; $i < count($raList); $i++) {
@@ -432,13 +427,13 @@ class OLE_PPS_Root extends OLE_PPS
     * @param integer $iBsize
     * @param integer $iPpsCnt
     */
-    function _saveBbd($iSbdSize, $iBsize, $iPpsCnt)
+    function _saveBbd($iSbdSize, $iBsize, $iPpsCnt) 
     {
         $FILE = $this->_FILEH_;
         // Calculate Basic Setting
         $iBbCnt = $this->_BIG_BLOCK_SIZE / OLE_LONG_INT_SIZE;
         $i1stBdL = ($this->_BIG_BLOCK_SIZE - 0x4C) / OLE_LONG_INT_SIZE;
-
+      
         $iBdExL = 0;
         $iAll = $iBsize + $iPpsCnt + $iSbdSize;
         $iAllW = $iAll;
@@ -458,7 +453,7 @@ class OLE_PPS_Root extends OLE_PPS
                 }
             }
         }
-
+      
         // Making BD
         // Set for SBD
         if ($iSbdSize > 0)
@@ -473,7 +468,7 @@ class OLE_PPS_Root extends OLE_PPS
             fwrite($FILE, pack("V", $i+$iSbdSize+1));
         }
         fwrite($FILE, pack("V", -2));
-
+      
         // Set for PPS
         for ($i = 0; $i<($iPpsCnt-1); $i++) {
             fwrite($FILE, pack("V", $i+$iSbdSize+$iBsize+1));
@@ -512,7 +507,7 @@ class OLE_PPS_Root extends OLE_PPS
             if (($iBdCnt-$i1stBdL) % ($iBbCnt-1))
             {
                 for ($i = 0; $i < (($iBbCnt-1) - (($iBdCnt-$i1stBdL) % ($iBbCnt-1))); $i++) {
-                    fwrite($FILE, pack("V", -1));
+                    fwrite($FILE, pack("V", -1)); 
                 }
             }
             fwrite($FILE, pack("V", -2));
