@@ -18,13 +18,6 @@
  * @param Smarty clever method emulation
  * @return string $content stripped of whitespace
  */
-
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 function smarty_block_strip($params, $content, &$smarty)
 {
 	/* Reformat data between 'strip' and '/strip' tags, removing spaces, tabs and newlines. */
@@ -37,6 +30,6 @@ function smarty_block_strip($params, $content, &$smarty)
 	return preg_replace($_strip_search, $_strip_replace, $content);
 }
 
-/* vim: set expandtab: */
+
 
 ?>
