@@ -20,13 +20,6 @@
  * @param Smarty clever simulation of a method
  * @return string string $content re-formatted
  */
-
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
 function smarty_block_translation($params, $content, &$smarty)
 {
     if (isset($content)) {
@@ -39,6 +32,6 @@ function smarty_block_translation($params, $content, &$smarty)
     }
 }
 
-/* vim: set expandtab: */
+
 
 ?>
