@@ -1,5 +1,5 @@
 <?php
-/* $Header: /cvsroot/tikiwiki/tiki/lib/smarty_tiki/function.popup_init.php,v 1.1.2.3 2008/02/21 19:41:17 marclaporte Exp $ */
+/* $Id: /cvsroot/tikiwiki/tiki/lib/smarty_tiki/function.popup_init.php,v 1.4 2006-12-29 11:17:49 mose Exp $ */
 /**
  * Smarty plugin
  * @package Smarty
@@ -23,31 +23,22 @@
  * @param Smarty
  * @return string
  */
-
-
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
-
 function smarty_function_popup_init($params, &$smarty)
 {
-    global $popup_init_cache;
+    global $popup_init_cache; 
     if (!isset($popup_init_cache)) {
         $popup_init_cache = array();
     }
 
-    if (isset($popup_init_cache[$params['src']]))
+    if (isset($popup_init_cache[$params['src']])) 
         return;
 
     $zindex = 1000;
-
+    
     if (!empty($params['zindex'])) {
         $zindex = $params['zindex'];
     }
-
+    
     if (!empty($params['src'])) {
         $popup_init_cache[$params['src']] = 1;
         return '<div id="overDiv" style="position: absolute; visibility: hidden; z-index:'.$zindex.';"></div>' . "\n"
@@ -58,6 +49,6 @@ function smarty_function_popup_init($params, &$smarty)
 
 }
 
-/* vim: set expandtab: */
+
 
 ?>
