@@ -14,16 +14,16 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
  * Purpose:  returns size in Mb, Kb or bytes.
  * -------------------------------------------------------------
  */
-function smarty_modifier_kbsize($string)
+function smarty_modifier_kbsize($string, $bytes = false, $nb_decimals = 2)
 {
-  if($string>1000000) {
-    $string=number_format($string/1000000,2).' Mb';
-  } elseif($string>1000) {
-    $string=number_format($string/1000,2).' Kb';
-  } else {
-    $string=$string.' b';
-  }
-  return $string;	
+  if ( $string == '' ) return '';
+
+  // 1024 x 1024 = 1048576
+  if ( $string > 1048576 ) $string = number_format($string/1048576,$nb_decimals).'&nbsp;M';
+  elseif ( $string > 1024 ) $string = number_format($string/1024,$nb_decimals).'&nbsp;K';
+  else $string = $string.'&nbsp;';
+
+  return $string.(($bytes) ? 'B' : 'b');
 }
 
 ?>
