@@ -2,15 +2,15 @@
 
 function smarty_modifier_star($score)
 {
-    global $feature_score, $tikilib;
+    global $prefs, $tikilib;
 
-    if ($feature_score != 'y') {
+    if ($prefs['feature_score'] != 'y') {
 	return '';
     }
 
     return $tikilib->get_star($score);
 }
 
-/* vim: set expandtab: */
+
 
 ?>
