@@ -7,12 +7,9 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 require_once $smarty->_get_plugin_filepath('modifier','tiki_date_format');
-function smarty_modifier_tiki_short_time($string)
-{
-	global $tikilib;
-	return smarty_modifier_tiki_date_format($string, $tikilib->get_short_time_format(), null, tra("%H:%M %Z"));
+function smarty_modifier_tiki_short_time($string) {
+	global $prefs;
+	return smarty_modifier_tiki_date_format($string, $prefs['short_time_format']);
 }
 
-/* vim: set expandtab: */
-
 ?>
