@@ -1,5 +1,5 @@
 <?php
-// CVS: $Id: modifier.tr_if.php,v 1.1.2.1 2007/01/18 15:09:40 sylvieg Exp $
+// CVS: $Id: modifier.tr_if.php,v 1.3.2.1 2007-11-04 12:39:15 nyloth Exp $
 
 // Translate only if feature_multilingual is on
 
@@ -10,8 +10,8 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 }
 
 function smarty_modifier_tr_if($source) {
-	global $feature_multilingual,$language;
-	if ($feature_multilingual == 'y' && $language != 'en') {
+	global $prefs;
+	if ($prefs['language'] != 'en') {
 		include_once('lib/init/tra.php');
 		return tra($source);
 	} else {
