@@ -24,14 +24,6 @@
  * @param boolean
  * @return string
  */
-
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
-
 function smarty_modifier_truncate($string, $length = 80, $etc = '...',
                                   $break_words = false, $middle = false)
 {
