@@ -33,13 +33,7 @@
 // | Co-Author: Damian Fernandez Sosa <damlists@cnba.uba.ar>               |
 // +-----------------------------------------------------------------------+
 //
-// $Id: net_pop3.php,v 1.1.2.5 2008/02/21 19:06:41 marclaporte Exp $
-
-//this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
+// $Id: net_pop3.php,v 1.4 2005-08-08 22:44:53 rlpowell Exp $
 
 require_once('Net/Socket.php');
 
@@ -196,7 +190,7 @@ class Net_POP3 {
     }
 
 
-
+    
     /*
     * Connects to the given host on the given port.
     * Also looks for the timestamp in the greeting
@@ -251,7 +245,7 @@ class Net_POP3 {
     * @param  string $user Username to use
     * @param  string $pass Password to use
     * @param  mixed $apop Whether to try APOP first, if used as string you can select the auth methd to use ( $pop3->login('validlogin', 'validpass', "CRAM-MD5");
-    *          Valid methods are: 'DIGEST-MD5','CRAM-MD5','LOGIN','PLAIN','APOP','USER'
+    *          Valid methods are: 'DIGEST-MD5','CRAM-MD5','LOGIN','PLAIN','APOP','USER' 
     * @return mixed  true on Success/ PEAR_ERROR on error
     */
     function login($user, $pass, $apop = true)
@@ -348,14 +342,15 @@ class Net_POP3 {
 	$serverMethods = array();
 
        if( isset($this->_capability['sasl']) ){
-           $serverMethods[] = $this->_capability['sasl'][0];
-       }else{
-            $serverMethods=array('USER');
-            // Check for timestamp before attempting APOP
-            if ($this->_timestamp != null)
-            {
-                $serverMethods[] = 'APOP';
-            }
+           $serverMethods[] = $this->_capability['sasl'];
+       }
+
+       $serverMethods[]='USER';
+
+       // Check for timestamp before attempting APOP
+       if ($this->_timestamp != null)
+       {
+	       $serverMethods[] = 'APOP';
        }
 
         if($userMethod !== null && $userMethod !== true ){
@@ -376,6 +371,7 @@ class Net_POP3 {
             }
             $serverMethods=implode(',' , $serverMethods );
             $myMethods=implode(',' ,$this->supportedAuthMethods);
+
             return $this->_raiseError("$method NOT supported authentication method!. This server " .
                 "supports these methods: $serverMethods, but I support $myMethods");
         }else{
@@ -494,7 +490,7 @@ class Net_POP3 {
         if( PEAR::isError($ret=$this->_checkResponse($challenge) )){
             return $ret;
         }
-
+        
         return true;
     }
 
@@ -571,9 +567,9 @@ class Net_POP3 {
         }
 
         // remove '+ '
-
+        
         $challenge=substr($challenge,2);
-
+        
         $challenge = base64_decode( $challenge );
 
         $cram = &Auth_SASL::factory('crammd5');
@@ -641,13 +637,13 @@ class Net_POP3 {
         if ( PEAR::isError( $challenge = $this->_send("\r\n") ) ) {
             return $challenge ;
         }
-
+        
         if ( PEAR::isError( $challenge = $this->_recvLn() ) ) {
             return $challenge;
         }
-
+        
         return $this->_checkResponse($challenge);
-
+        
 
     }
 
@@ -841,10 +837,10 @@ class Net_POP3 {
     */
     function getListing($msg_id = null)
     {
-
+    
         if ($this->_state == NET_POP3_STATE_TRANSACTION) {
             if (!isset($msg_id)){
-
+            
                 $list=array();
                 if ($list = $this->_cmdList()) {
                     if ($uidl = $this->_cmdUidl()) {
@@ -931,7 +927,7 @@ class Net_POP3 {
             if (!isset($msg_id)) {
                 if(!PEAR::isError($data = $this->_sendCmd('LIST') )){
                     $data = $this->_getMultiline();
-                    $data = explode("\r\n", $data);
+                    $data = explode("\r\n", $data);                    
                     foreach ($data as $line) {
                         if($line !=''){
                             sscanf($line, '%s %s', $msg_id, $size);
@@ -950,7 +946,7 @@ class Net_POP3 {
                 }
             }
         }
-
+        
 
         return false;
     }
@@ -1114,12 +1110,12 @@ class Net_POP3 {
         if (PEAR::isError($data = $this->_recvLn() )){
             return $data;
         }
-
+        
         if ( strtoupper(substr($data, 0, 3)) == '+OK') {
             return $data;
         }
-
-
+        
+        
         return $this->_raiseError($data);
     }
 
@@ -1147,7 +1143,7 @@ class Net_POP3 {
    /**
     * Sets the bebug state
     *
-    * @param  bool $debug
+    * @param  bool $debug 
     * @access public
     * @return void
     */
@@ -1226,11 +1222,11 @@ class Net_POP3 {
                     return true;
                 }
             }
-
+    
         }
         return $this->_raiseError("Unknown Response ($response)");
     }
-
+    
 
 
 }
