@@ -1,4 +1,5 @@
 <?php
+// $Id: /cvsroot/tikiwiki/tiki/lib/wiki/wikilib.php,v 1.110.2.11 2008-02-27 15:18:48 nyloth Exp $
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
@@ -9,24 +10,22 @@ if( !defined( 'PLUGINS_DIR' ) ) {
 	define('PLUGINS_DIR', 'lib/wiki-plugins');
 }
 
+
 class WikiLib extends TikiLib {
     function WikiLib($db) {
-	if (!$db) {
-	    die ("Invalid db object passed to WikiLib constructor");
-	}
-
-	$this->db = $db;
+	$this->TikiLib($db);
     }
 
     //Special parsing for multipage articles
     function get_number_of_pages($data) {
+	global $prefs;
 	// Temporary remove <PRE></PRE> secions to protect
 	// from broke <PRE> tags and leave well known <PRE>
 	// behaviour (i.e. type all text inside AS IS w/o
 	// any interpretation)
 	$preparsed = array();
 
-	preg_match_all("/(<[Pp][Rr][Ee]>)((.|\n)*?)(<\/[Pp][Rr][Ee]>)/", $data, $preparse);
+	preg_match_all("/(<[Pp][Rr][Ee]>)(.*?)(<\/[Pp][Rr][Ee]>)/s", $data, $preparse);
 	$idx = 0;
 
 	foreach (array_unique($preparse[2])as $pp) {
@@ -35,37 +34,18 @@ class WikiLib extends TikiLib {
 	    $aux["key"] = $key;
 	    $aux["data"] = $pp;
 	    $preparsed[] = $aux;
-	    $data = str_replace($preparse[1][$idx] . $pp . $preparse[4][$idx], $key, $data);
+	    $data = str_replace($preparse[1][$idx] . $pp . $preparse[3][$idx], $key, $data);
 	    $idx = $idx + 1;
 	}
 
-	$parts = explode("...page...", $data);
+	$parts = explode($prefs['wiki_page_separator'], $data);
 	return count($parts);
     }
 
     function get_page($data, $i) {
-	// Temporary remove <PRE></PRE> secions to protect
-	// from broke <PRE> tags and leave well known <PRE>
-	// behaviour (i.e. type all text inside AS IS w/o
-	// any interpretation)
-	/*
-	$preparsed = array();
-
-	preg_match_all("/(<[Pp][Rr][Ee]>)((.|\n)*?)(<\/[Pp][Rr][Ee]>)/", $data, $preparse);
-	$idx = 0;
-
-	foreach (array_unique($preparse[2])as $pp) {
-	    $key = md5($this->genPass());
-
-	    $aux["key"] = $key;
-	    $aux["data"] = $pp;
-	    $preparsed[] = $aux;
-	    $data = str_replace($preparse[1][$idx] . $pp . $preparse[4][$idx], $key, $data);
-	    $idx = $idx + 1;
-	}
-*/
 	// Get slides
-	$parts = explode("...page...", $data);
+	global $prefs;
+	$parts = explode($prefs['wiki_page_separator'], $data);
 	$ret = $parts[$i - 1];
 
 	if (substr($parts[$i - 1], 1, 5) == "<br/>") $ret = substr($parts[$i - 1], 6);
@@ -80,25 +60,36 @@ class WikiLib extends TikiLib {
 
     /**
      *  Get the contributors for page
-     *  the returned array does not contain the last editor/contributor
+     *  the returned array does not contain the user $last (usually the current or last user)
      */
-    function get_contributors($page, $last) {
-				$notus = "`user` not like 'system' and `user` not like ?";
-        $query = "select `user` from `tiki_history` where ($notus) and `pageName`=? order by `version` desc";
-        $result = $this->query($query,array($last,$page), 10);
-        $ret = array();
-        $seen = array();
-        //$seen = array("system", "admin", $last); // would it be more efficient to put admin and system in here rather than in the where clause, above?
+    function get_contributors($page, $last='') {
+		static $cache_page_contributors;
+		if ($cache_page_contributors['page'] == $page) {
+			if (empty($last)) {
+				return $cache_page_contributors['contributors'];
+			}
+			$ret = array();
+			foreach ($cache_page_contributors['contributors'] as $res) {
+				if ($res['user'] != $last) {
+					$ret[] = $res;
+				}
+			}
+			return $ret;
+		}
+		$query = "select DISTINCT `user` from `tiki_history` where `pageName`=? order by `version` desc";
+		$result = $this->query($query,array($page));
+		$cache_page_contributors = array();
+		$cache_page_contributors['contributors'] = array();
+		$ret = array();
 
-        while ($res = $result->fetchRow()) {
-            if ( isset($seen[$res["user"]] )) {
-                continue;
-            } else {
-                $seen[$res["user"]] = $res["user"];
-            }
-            $ret[] = $res["user"];
-        }
-        return $ret;
+		while ($res = $result->fetchRow()) {
+			if ($res['user'] != $last) {
+				$ret[] = $res['user'];
+			}
+			$cache_page_contributors['contributors'][] = $res['user'];
+		}
+		$cache_page_contributors['page'] = $page;
+		return $ret;
     }
 
     // Returns all pages that links from here or to here, without distinction
@@ -108,7 +99,7 @@ class WikiLib extends TikiLib {
 	   $neighbours = array();
 	   $already = array();
 
-           $query = "select `toPage` from `tiki_links` where `fromPage`=?";
+           $query = "select `toPage` from `tiki_links` where `fromPage`=? and `fromPage` not like 'objectlink:%'";
 	   $result = $this->query($query,array($page));
 	   while ($row = $result->fetchRow(DB_FETCHMODE_ASSOC)) {
 	       $neighbour = $row['toPage'];
@@ -116,7 +107,7 @@ class WikiLib extends TikiLib {
 	       $already[$neighbour] = 1;
 	   }
 
-           $query = "select `fromPage` from `tiki_links` where `toPage`=?";
+           $query = "select `fromPage` from `tiki_links` where `toPage`=? and `fromPage` not like 'objectlink:%'";
 	   $result = $this->query($query,array($page));
 	   while ($row = $result->fetchRow(DB_FETCHMODE_ASSOC)) {
 	       $neighbour = $row['fromPage'];
@@ -133,6 +124,7 @@ class WikiLib extends TikiLib {
 	// This method renames a wiki page
 	// If you think this is easy you are very very wrong
 	function wiki_rename_page($oldName, $newName) {
+		global $prefs, $tikilib;
 		// if page already exists, stop here
 		if ($this->page_exists($newName)) {
 			// if it is a case change of same page: allow it, else stop here
@@ -158,31 +150,51 @@ class WikiLib extends TikiLib {
 
 		$query = "update `tiki_history` set `pageName`=? where `pageName`=?";
 		$this->query($query, array( $newName, $tmpName ) );
-		
+
 		// get pages linking to the old page
 		$query = "select `fromPage` from `tiki_links` where `toPage`=?";
 		$result = $this->query($query, array( $oldName ) );
 
 		$linksToOld=array();
-		while ($res = $result->fetchRow()) {
+		while ($res = $result->fetchRow()) {			
 		    $page = $res['fromPage'];
+		    $is_wiki_page = true;
+		    if (substr($page,0,11) == 'objectlink:') {
+		    	$is_wiki_page = false;
+		    	$objectlinkparts = split(':', $page);
+		    	$type = $objectlinkparts[1];
+		    	$objectId = $objectlinkparts[2];
+		    }
 		    $linksToOld[] = $res['fromPage'];
-		    $info = $this->get_page_info($page);
-		    //$data=addslashes(str_replace($oldName,$newName,$info['data']));
-		    $data = $info['data'];
+		    if ($is_wiki_page) {
+		    	$info = $this->get_page_info($page);
+			    //$data=addslashes(str_replace($oldName,$newName,$info['data']));
+			    $data = $info['data'];
+		    } elseif ($type == 'forum post' || substr($type, -7) == 'comment') {
+		    	include_once ("lib/commentslib.php");
+		    	global $dbTiki;
+				$commentslib = new Comments($dbTiki);
+				$comment_info = $commentslib->get_comment($objectId);
+				$data = $comment_info['data'];
+		    }
 		    $oldName = quotemeta( $oldName );
  		    if (strstr($newName, " "))
 		    	$data = preg_replace("/(?<= |\n|\t|\r|\,|\;|^)$oldName(?= |\n|\t|\r|\,|\;|$)/", "((".$newName."))", $data);
 		    else
 		    	$data = preg_replace("/(?<= |\n|\t|\r|\,|\;|^)$oldName(?= |\n|\t|\r|\,|\;|$)/", $newName, $data);
 		    $data = preg_replace("/(?<=\(\()$oldName(?=\)\)|\|)/", $newName, $data);
-		    $query = "update `tiki_pages` set `data`=?,`page_size`=? where `pageName`=?";
-		    $this->query($query, array( $data,(int) strlen($data), $page));
+		    if ($is_wiki_page) {
+		    	$query = "update `tiki_pages` set `data`=?,`page_size`=? where `pageName`=?";
+		    	$this->query($query, array( $data,(int) strlen($data), $page));
+		    } elseif ($type == 'forum post' || substr($type, -7) == 'comment') {
+		    	$query = "update `tiki_comments` set `data`=? where `threadId`=?";
+		    	$this->query($query, array( $data, $objectId));
+		    }
 		    $this->invalidate_cache($page);
 		}
 
 		// correct toPage and fromPage in tiki_links
-		// before update, manage to avoid duplicating index(es) when B is renamed to C while page(s) points to both C (not created yet) and B 
+		// before update, manage to avoid duplicating index(es) when B is renamed to C while page(s) points to both C (not created yet) and B
 		$query = "select `fromPage` from `tiki_links` where `toPage`=?";
 		$result = $this->query($query, array( $newName ) );
 		$linksToNew = array();
@@ -195,31 +207,31 @@ class WikiLib extends TikiLib {
 		}
 		$query = "update `tiki_links` set `fromPage`=? where `fromPage`=?";
 		$this->query($query, array( $newName, $oldName));
-	
+
 		$query = "update `tiki_links` set `toPage`=? where `toPage`=?";
 		$this->query($query, array( $newName, $oldName));
-	
+
 		// tiki_footnotes change pageName
 		$query = "update `tiki_page_footnotes` set `pageName`=? where `pageName`=?";
 		$this->query($query, array( $newName, $oldName ));
 
 		// in tiki_categorized_objects update objId
 		$newcathref = 'tiki-index.php?page=' . urlencode($newName);
-		$query = "update `tiki_categorized_objects` set `objId`=?,`name`=?,`href`=? where `objId`=?";
-		$this->query($query, array( $newName, $newName, $newcathref, $oldName));
-	
+		$query = "update `tiki_objects` set `itemId`=?,`name`=?,`href`=? where `itemId`=? and `type`=?";
+		$this->query($query, array( $newName, $newName, $newcathref, $oldName, 'wiki page'));
+
 		// old code that doesn't seem to be working
 		//	$query = "update tiki_categorized_objects set objId='$newId' where objId='$oldId'";
-		//    $this->query($query);	  	  	  	
-	
-		// in tiki_comments update object  
+		//    $this->query($query);
+
+		// in tiki_comments update object
 		$query = "update `tiki_comments` set `object`=? where `object`=?";
 		$this->query($query, array( $newName, $oldName ) );
 
 		// Move email notifications
 		$oldId = 'wikipage' . $oldName;
 		$newId = 'wikipage' . $newName;
-		$query = "update `tiki_mail_events` set `object`=? where `object`=?";
+		$query = "update `tiki_user_watches` set `object`=? where `object`=?";
 		$this->query($query, array( $newId, $oldId ) );
 
 		// theme_control_objects(objId,name)
@@ -227,7 +239,7 @@ class WikiLib extends TikiLib {
 		$newId = md5('wiki page' . $newName);
 		$query = "update `tiki_theme_control_objects` set `objId`=?, `name`=? where `objId`=?";
 		$this->query($query, array( $newId, $newName, $oldId ) );
-	
+
 		$query = "update `tiki_wiki_attachments` set `page`=? where `page`=?";
 		$this->query($query, array( $newName, $oldName ) );
 
@@ -247,13 +259,18 @@ class WikiLib extends TikiLib {
 		$query = "update `users_objectpermissions` set `objectId`=? where `objectId`=?";
 		$this->query($query, array( $newId, $oldId ) );
 
-		global $feature_user_watches;
+		global $prefs;
+		if ($prefs['feature_actionlog'] == 'y') {
+			global $logslib; include_once('lib/logs/logslib.php');
+			$logslib->add_action('Renamed', $newName, 'wiki page', 'old='.$oldName.'&new='.$newName, '', '', '', '', '', array(array('rename'=>$oldName)));
+			$logslib->rename('wiki page', $oldName, $newName);
+		}
 		global $user;
 		global $tikilib;
 		global $smarty;
 
 		// first get all watches for this page ...
-		if ($feature_user_watches == 'y') {
+		if ($prefs['feature_user_watches'] == 'y') {
 			$nots = $tikilib->get_event_watches('wiki_page_changed', $oldName);
 		}
 
@@ -263,7 +280,7 @@ class WikiLib extends TikiLib {
 		$this->query($query, array( $newName, $newName, 'tiki-index.php?page='.$newName, $oldName ) );
 
 		// now send notification email to all on the watchlist:
-		if ($feature_user_watches == 'y') {
+		if ($prefs['feature_user_watches'] == 'y') {
 			if (!isset($_SERVER["SERVER_NAME"])) {
 				$_SERVER["SERVER_NAME"] = $_SERVER["HTTP_HOST"];
 			}
@@ -272,7 +289,7 @@ class WikiLib extends TikiLib {
 				$smarty->assign('mail_site', $_SERVER["SERVER_NAME"]);
 				$smarty->assign('mail_oldname', $oldName);
 				$smarty->assign('mail_newname', $newName);
-				$smarty->assign('mail_date', date("U"));
+				$smarty->assign('mail_date', $this->now);
 				$smarty->assign('mail_user', $user);
 				$foo = parse_url($_SERVER["REQUEST_URI"]);
 				$machine = $tikilib->httpPrefix(). $foo["path"];
@@ -284,6 +301,19 @@ class WikiLib extends TikiLib {
 				sendEmailNotification($nots, "watch", "user_watch_wiki_page_renamed_subject.tpl", $_SERVER["SERVER_NAME"], "user_watch_wiki_page_renamed.tpl");
 			}
 		}
+
+		if ( $prefs['feature_search'] == 'y' && $prefs['feature_search_fulltext'] != 'y' && $prefs['search_refresh_index_mode'] == 'normal' ) {
+			require_once('lib/search/refresh-functions.php');
+			refresh_index('pages', $newName);
+		}
+
+		global $menulib; include_once('lib/menubuilder/menulib.php');
+		$menulib->rename_wiki_page($oldName, $newName);
+
+		if ($prefs['wikiHomePage'] == $oldName) {
+			$tikilib->set_preference('wikiHomePage', $newName);
+		}
+
 		return true;
 	}
 
@@ -307,10 +337,9 @@ class WikiLib extends TikiLib {
 	}
 
 	function update_cache($page, $data) {
-		$now = date('U');
 
 		$query = "update `tiki_pages` set `cache`=?, `cache_timestamp`=? where `pageName`=?";
-		$result = $this->query($query, array( $data, $now, $page ) );
+		$result = $this->query($query, array( $data, $this->now, $page ) );
 		return true;
 	}
 
@@ -319,13 +348,13 @@ class WikiLib extends TikiLib {
 	}
 
 	function remove_wiki_attachment($attId) {
-		global $w_use_dir;
+		global $prefs;
 
 		$path = $this->getOne("select `path` from `tiki_wiki_attachments` where `attId`=$attId");
 
 		/* carefull a same file can be attached in different page */
 		if ($path && $this->getOne("select count(*) from `tiki_wiki_attachments` where `path`='$path'") <= 1) {
-			@unlink ($w_use_dir . $path);
+			@unlink ($prefs['w_use_dir'] . $path);
 		}
 
 		$query = "delete from `tiki_wiki_attachments` where `attId`='$attId'";
@@ -334,46 +363,23 @@ class WikiLib extends TikiLib {
 
 	function wiki_attach_file($page, $name, $type, $size, $data, $comment, $user, $fhash) {
 		$comment = strip_tags($comment);
-		$now = date("U");
-		$query = "insert into `tiki_wiki_attachments`(`page`,`filename`,`filesize`,`filetype`,`data`,`created`,`downloads`,`user`,`comment`,`path`) values(?,?,?,?,?,?,0,?,?,?)";
+		$query = "insert into `tiki_wiki_attachments`(`page`,`filename`,`filesize`,`filetype`,`data`,`created`,`hits`,`user`,`comment`,`path`) values(?,?,?,?,?,?,0,?,?,?)";
 		$this->blob_encode($data);
-		$result = $this->query($query,array("$page","$name", (int) $size,"$type","$data", (int) $now,"$user","$comment","$fhash"));
+		$result = $this->query($query,array("$page","$name", (int) $size,"$type","$data", (int) $this->now,"$user","$comment","$fhash"));
 
-		global $feature_score;
-	        if ($feature_score == 'y') {
+		global $prefs;
+	        if ($prefs['feature_score'] == 'y') {
         	    $this->score_event($user, 'wiki_attach_file');
 	        }
-		global $feature_user_watches;
-		if ($feature_user_watches == 'y') {
-			global $user;
-			global $smarty;
-			$nots = $this->get_event_watches('wiki_page_changed', $page);
-			if (!isset($_SERVER["SERVER_NAME"])) {
-				$_SERVER["SERVER_NAME"] = $_SERVER["HTTP_HOST"];
-			}
-			if (count($nots)) {
-				include_once("lib/notifications/notificationemaillib.php");
-				$smarty->assign('mail_site', $_SERVER["SERVER_NAME"]);
-				$smarty->assign('mail_date', date("U"));
-				$smarty->assign('mail_user', $user);
-				$smarty->assign('mail_page', $page);
-				$smarty->assign('mail_att_name', $name);
-				$smarty->assign('mail_att_type', $type);
-				$smarty->assign('mail_att_size', $size);
-				$smarty->assign('mail_att_comment', $comment);
-				$foo = parse_url($_SERVER["REQUEST_URI"]);
-				$machine = $this->httpPrefix(). $foo["path"];
-				$smarty->assign('mail_machine', $machine);
-				$parts = explode('/', $foo['path']);
-				if (count($parts) > 1)
-					unset ($parts[count($parts) - 1]);
-				$smarty->assign('mail_machine_raw', $this->httpPrefix(). implode('/', $parts));
-				sendEmailNotification($nots, "watch", "user_watch_wiki_new_attach_subject.tpl", $_SERVER["SERVER_NAME"], "user_watch_wiki_new_attach.tpl");
-			}
-		}
+	}
+	function get_wiki_attach_file($page, $name, $type, $size) {
+		$query = 'select * from `tiki_wiki_attachments` where `page`=? and `filename`=? and `filetype`=? and `filesize`=?';
+		$result = $this->query($query, array($page, $name, $type, $size));
+		$res = $result->fetchRow();
+		return $res;
 	}
 
-	function list_wiki_attachments($page, $offset, $maxRecords, $sort_mode, $find) {
+	function list_wiki_attachments($page, $offset=0, $maxRecords=-1, $sort_mode='created_desc', $find='') {
 
 	if ($find) {
 	    $mid = " where `page`=? and (`filename` like ?)"; // why braces?
@@ -383,7 +389,7 @@ class WikiLib extends TikiLib {
 	    $bindvars=array($page);
 	}
 
-	$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`downloads`,`created`,`comment` from `tiki_wiki_attachments` $mid order by ".$this->convert_sortmode($sort_mode);
+	$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`hits`,`created`,`comment` from `tiki_wiki_attachments` $mid order by ".$this->convert_sortmode($sort_mode);
 	$query_cant = "select count(*) from `tiki_wiki_attachments` $mid";
 	$result = $this->query($query,$bindvars,$maxRecords,$offset);
 	$cant = $this->getOne($query_cant,$bindvars);
@@ -407,7 +413,7 @@ class WikiLib extends TikiLib {
 			$mid = "";
 			$bindvars=array();
 		}
-		$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`downloads`,`created`,`comment`,`path` ";
+		$query = "select `user`,`attId`,`page`,`filename`,`filesize`,`filetype`,`hits`,`created`,`comment`,`path` ";
 		$query.= " from `tiki_wiki_attachments` $mid order by ".$this->convert_sortmode($sort_mode);
 		$query_cant = "select count(*) from `tiki_wiki_attachments` $mid";
 		$result = $this->query($query,$bindvars,$maxRecords,$offset);
@@ -421,7 +427,7 @@ class WikiLib extends TikiLib {
 		$retval["cant"] = $cant;
 		return $retval;
 	}
-		
+
 	function file_to_db($path,$attId) {
 		if (is_file($path)) {
 			$fp = fopen($path,'rb');
@@ -457,6 +463,13 @@ class WikiLib extends TikiLib {
 		$res = $result->fetchRow();
 		return $res;
 	}
+	function get_item_attachement_data($att_info) {
+		if ($att_info['path']) {
+			return file_get_contents($att_info['filename']);
+		} else {
+			return $att_info['data'];
+		}
+	}
 
 
     // Functions for wiki page footnotes
@@ -530,15 +543,18 @@ class WikiLib extends TikiLib {
 		}
 
 	    $histlib->use_version($res["pageName"], $res["version"]);
-	    $histlib->remove_version($res["pageName"], $res["version"]);
+	    if ($prefs['feature_contribution'] == 'y') {
+		global $contributionlib; include_once('lib/contribution/contributionlib.php');
+		$info = $tikilib->get_page_info($res['pageName']);
+		$contributionlib->change_assigned_contributions($res['historyId'], 'history', $res['pageName'], 'wiki page', $info['description'], $res['pageName'], "tiki-index.php?page".urlencode($res['pageName']));
+	    }
+	    $histlib->remove_version($res['pageName'], $res['version']);
 	} else {
 	    $this->remove_all_versions($page);
 	}
-
-	$action = "Removed last version";
-	$t = date("U");
-	$query = "insert into `tiki_actionlog`( `action`, `pageName`, `lastModif`, `user`, `ip`, `comment`) values( ?, ?, ?, ?, ?, ?)";
-	$result = $this->query($query, array( $action, $page, $t, "admin", $_SERVER["REMOTE_ADDR"], $comment ) );
+	global  $logslib; include_once('lib/logs/logslib.php');
+	$logslib->add_action('Removed last version', $page, 'wiki page', $comment);
+	//get_strings tra("Removed last version");
     }
 
     // Like pages are pages that share a word in common with the current page
@@ -579,44 +595,64 @@ class WikiLib extends TikiLib {
 		$result = $this->query($query, array( $page ) );
 		$info = $result->fetchRow();
 	}
-	return ($info["flag"] == 'L')? $info["user"] : null; 
+	return ($info["flag"] == 'L')? $info["user"] : null;
     }
     function is_editable($page, $user, $info=null) {
-	global $tiki_p_admin, $tiki_p_admin_wiki, $feature_wiki_userpage, $feature_wiki_userpage_prefix;
+	global $tiki_p_admin, $tiki_p_admin_wiki, $prefs;
       if ($tiki_p_admin == 'y' || $tiki_p_admin_wiki == 'y')
             return true;
       else {
-		if ($feature_wiki_userpage == 'y' and strcasecmp(substr($page, 0, strlen($feature_wiki_userpage_prefix)), $feature_wiki_userpage_prefix) == 0 and strcasecmp($page, $feature_wiki_userpage_prefix.$user) != 0)
+		if ($prefs['feature_wiki_userpage'] == 'y' and strcasecmp(substr($page, 0, strlen($prefs['feature_wiki_userpage_prefix'])), $prefs['feature_wiki_userpage_prefix']) == 0 and strcasecmp($page, $prefs['feature_wiki_userpage_prefix'].$user) != 0)
 			return false;
-            return ($this->is_locked($page, $info) == null || $user == $this->is_locked($page, $info))? true : false;
+		if (!$this->user_has_perm_on_object($user,$page,'wiki page','tiki_p_edit'))
+			return false;
+		return ($this->is_locked($page, $info) == null || $user == $this->is_locked($page, $info))? true : false;
 	}
     }
 
     function lock_page($page) {
-	global $user;
+	global $user, $tikilib;
 
-	$query = "update `tiki_pages` set `flag`=? where `pageName`=?";
-	$result = $this->query($query, array( "L",$page ) );
+	$query = "update `tiki_pages` set `flag`=?, `lockedby`=? where `pageName`=?";
+	$result = $this->query($query, array( "L", $user, $page ) );
 
-	if (isset($user)) {
-		$query = "update `tiki_pages` set `user`=?  where `pageName`=?";
-
-		$result = $this->query($query, array( $user, $page ) );
+	if (!empty($user)) {
+	    $info = $tikilib->get_page_info($page);
+	    
+	    $query = "insert into `tiki_history`(`pageName`, `version`, `lastModif`, `user`, `ip`, `comment`, `data`, `description`) values(?,?,?,?,?,?,?,?)";
+	    $result = $this->query($query,array($page,(int) $info['version'],(int) $info['lastModif'],$info['user'],$info['ip'],$info['comment'],$info['data'],$info['description']));
+	    
+	    $query = "update `tiki_pages` set `user`=?, `comment`=?, `version`=? where `pageName`=?";
+	    $result = $this->query($query, array($user, tra('Page locked'), $info['version'] + 1, $page));
 	}
 
 	return true;
     }
 
     function unlock_page($page) {
+	global $user, $tikilib;
+	
 	$query = "update `tiki_pages` set `flag`='' where `pageName`=?";
-	$result = $this->query($query, array( $page ) );
+	$result = $this->query($query, array($page));
+	
+	if (isset($user)) {
+	    $info = $tikilib->get_page_info($page);
+	    
+	    $query = "insert into `tiki_history`(`pageName`, `version`, `lastModif`, `user`, `ip`, `comment`, `data`, `description`) values(?,?,?,?,?,?,?,?)";
+	    $result = $this->query($query,array($page,(int) $info['version'],(int) $info['lastModif'],$info['user'],$info['ip'],$info['comment'],$info['data'],$info['description']));
+	    
+	    $query = "update `tiki_pages` set `user`=?, `comment`=?, `version`=? where `pageName`=?";
+	    $result = $this->query($query, array($user, tra('Page unlocked'), $info['version'] + 1, $page));
+	}
+	
 	return true;
     }
 
     // Returns backlinks for a given page
     function get_backlinks($page) {
 	global $user;
-	$query = "select `fromPage` from `tiki_links` where `toPage` = ? order by `fromPage` asc ";
+	$query = "select `fromPage` from `tiki_links` where `toPage` = ? and `fromPage` not like 'objectlink:%'";
+	// backlinks do not include links from non-page objects TODO: full feature allowing this with options
 	$result = $this->query($query, array( $page ));
 	$ret = array();
 
@@ -630,9 +666,9 @@ class WikiLib extends TikiLib {
 	return $ret;
     }
 
-    function list_plugins() {
+    function list_plugins($with_help = false) {
 	$files = array();
-
+	
 	if (is_dir(PLUGINS_DIR)) {
 	    if ($dh = opendir(PLUGINS_DIR)) {
 		while (($file = readdir($dh)) !== false) {
@@ -643,8 +679,25 @@ class WikiLib extends TikiLib {
 	    }
 	}
 	sort($files);
-	return $files;
+	if ($with_help) {
+		global $cachelib;
+		if (!$cachelib->isCached('plugindesc')) {
+			$plugins = array();
+			foreach ($files as $pfile) {
+					$pinfo['file'] = $pfile;
+				$pinfo["help"] = $this->get_plugin_description($pfile);
+				$pinfo["name"] = strtoupper(str_replace(".php", "", str_replace("wikiplugin_", "", $pfile)));
+				$plugins[] = $pinfo;
+			}
+			$cachelib->cacheItem("plugindesc",serialize($plugins));
+		} else {
+			$plugins = unserialize($cachelib->getCached("plugindesc"));
+		}
+		return $plugins;
+	} else {
+		return $files;
     }
+	}
 
     //
     // Call 'wikiplugin_.*_description()' from given file
@@ -671,7 +724,7 @@ class WikiLib extends TikiLib {
 
 	// get all modified pages for a user (if actionlog is not clean
 	function get_user_all_pages($user, $sort_mode) {
-		$query = "select  distinct(p.`pageName`), p.`user` as lastEditor, p.`creator`, max(a.`lastModif`) as date from `tiki_actionlog` as a, `tiki_pages` as p where a.`pageName`= p.`pageName` and a.`user`= ? group by p.`pageName` order by ".$this->convert_sortmode($sort_mode);
+		$query = "select  distinct(p.`pageName`), p.`user` as lastEditor, p.`creator`, max(a.`lastModif`) as date from `tiki_actionlog` as a, `tiki_pages` as p where a.`object`= p.`pageName` and a.`user`= ? group by p.`pagename` order by ".$this->convert_sortmode($sort_mode);
 		$result = $this->query($query, array($user));
 		$ret = array();
 		while ($res = $result->fetchRow()) {
@@ -679,17 +732,48 @@ class WikiLib extends TikiLib {
 		}
 		return $ret;
 	}
+
 	function get_default_wiki_page() {
-		global $user, $wikiHomePage, $useGroupHome;
-	 	if ($useGroupHome == 'y') {
+		global $user, $prefs;
+	 	if ($prefs['useGroupHome'] == 'y') {
 			global $user;
 			global $userlib; include_once('lib/userslib.php');
 			if ($groupHome = $userlib->get_user_default_homepage($user))
 				return $groupHome;
 			else
- 				return $wikiHomePage;
+ 				return $prefs['wikiHomePage'];
 		}
-		return $wikiHomePage;
+		return $prefs['wikiHomePage'];
+	}
+
+	function save_draft($pageName, $pageDesc, $pageData, $pageComment) {
+	    global $user;
+
+	    if (!$user) return false;
+
+	    $query = "delete from `tiki_page_drafts` where `user`=? and `pageName`=?";
+	    $this->query($query, array($user, $pageName));
+
+	    $query = "insert into `tiki_page_drafts` (`user`,`pageName`,`data`,`description`,`comment`,`lastModif`) values (?,?,?,?,?,?)";
+	    $bindvals = array($user, $pageName, $pageData, $pageDesc, $pageComment, time());
+
+	    return $this->query($query, $bindvals) ? true : false;
+	}
+	function sefurl($page) {
+		global $prefs;
+		if ($prefs['feature_sefurl'] == 'y') {
+			return urlencode($page);
+		} else {
+			return 'tiki-index.php?page='.urlencode($page);
+		}
+	}
+	function move_attachments($old, $new) {
+		$query = 'update `tiki_wiki_attachments` set `page`=? where `page`=?';
+		$this->query($query, array($new, $old));
+	}
+	function duplicate_page($old, $new) {
+		$query = 'insert into `tiki_pages` (`pageName`,`hits`,`data`,`lastModif`,`comment`,`version`,`user`,`ip`,`description`,`creator`,`page_size`,`is_html`,`created`, `flag`,`points`,`votes`,`pageRank`,`lang`,`lockedby`) select ?,`hits`,`data`,`lastModif`,`comment`,`version`,`user`,`ip`,`description`,`creator`,`page_size`,`is_html`,`created`, `flag`,`points`,`votes`,`pageRank`,`lang`,`lockedby` from `tiki_pages` where `pageName`=?';
+		$this->query($query, array($new, $old));
 	}
 
 }
