@@ -1,10 +1,10 @@
 <?php
-
 //this script may only be included - so its better to die if called directly.
 if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
   exit;
 }
+global $smarty, $tikilib, $user;
 
 $smarty->assign('module_title', isset($module_params["title"]) ? $module_params["title"] : tra("Articles"));
 
@@ -28,6 +28,11 @@ if (isset($module_params["start"])) {
 } else {
 	$start = isset($start) ? $start : 0;
 }
+if (isset($module_params['sort'])) {
+	$sort = $module_params['sort'];
+} else {
+	$sort = 'publishDate_desc';
+}
 if (isset($module_params['lang'])) {
 	$lang = $module_params['lang'];
 } else {
@@ -39,7 +44,7 @@ if (isset($module_params['categId'])) {
 	$categId = '';
 }
 
-$ranking = $tikilib->list_articles($start, $module_rows, 'publishDate_desc', '', '', $user, $type, $topicId, 'y', $topic, $categId, $lang);
+$ranking = $tikilib->list_articles($start, $module_rows, 'publishDate_desc', '', '', $user, $type, $topicId, 'y', $topic, $categId, '', '', $lang);
 
 $smarty->assign('modArticles', $ranking["data"]);
 
