@@ -7,7 +7,8 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
   exit;
 }
-$ranking = $tikilib->list_visible_galleries(0, $module_rows, 'lastModif_desc', $user, '');
+if (empty($imagegallib) or !is_object($imagegallib)) include_once 'lib/imagegals/imagegallib.php';
+$ranking = $imagegallib->list_visible_galleries(0, $module_rows, 'lastModif_desc', $user, '');
 
 $smarty->assign('modLastGalleries', $ranking["data"]);
 $smarty->assign('nonums', isset($module_params["nonums"]) ? $module_params["nonums"] : 'n');
