@@ -16,12 +16,16 @@ if (isset($_REQUEST["textareasetup"])) {
 ask_ticket('admin-inc-textarea');
 
     $pref_toggles = array(
+	"feature_hotwords",
+	"feature_hotwords_nw",
+	"feature_dynamic_content",
+	"feature_filegals_manager",
+	"feature_use_quoteplugin",
+	"feature_comments_post_as_anonymous",
 	"feature_smileys",
 	"popupLinks",
-	"feature_antibot",
 	"feature_autolinks",
-	"cachepages",
-	"cacheimages"
+        "quicktags_over_textarea",
     );
 
 
@@ -29,6 +33,16 @@ ask_ticket('admin-inc-textarea');
         simple_set_toggle ($toggle);
     }
 
+    $pref_simple_values = array(
+        "default_rows_textarea_wiki",
+        "default_rows_textarea_comment",
+        "default_rows_textarea_forum",
+        "default_rows_textarea_forumthread",
+    );
+
+    foreach ($pref_simple_values as $svitem) {
+        simple_set_value ($svitem);
+    }
 
 }
 
