@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-admin_include_webmail.php,v 1.7.2.3 2007/03/02 12:23:28 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-admin_include_webmail.php,v 1.12 2007-10-12 07:55:24 nyloth Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -19,16 +19,11 @@ if (isset($_REQUEST["webmail"])) {
 	check_ticket('admin-inc-webmail');
 	if (isset($_REQUEST["webmail_view_html"]) && $_REQUEST["webmail_view_html"] == "on") {
 		$tikilib->set_preference("webmail_view_html", 'y');
-
-		$smarty->assign('webmail_view_html', 'y');
 	} else {
 		$tikilib->set_preference("webmail_view_html", 'n');
-
-		$smarty->assign('webmail_view_html', 'n');
 	}
 
 	$tikilib->set_preference('webmail_max_attachment', $_REQUEST["webmail_max_attachment"]);
-	$smarty->assign('webmail_max_attachment', $_REQUEST["webmail_max_attachment"]);
 }
 ask_ticket('admin-inc-webmail');
 ?>
