@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-adminusers.php,v 1.34.2.41 2008/01/30 22:37:47 sylvieg Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-adminusers.php,v 1.76.2.6 2008-03-13 16:54:36 sylvieg Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -11,6 +11,7 @@ $tikifeedback = array();
 require_once ('tiki-setup.php');
 
 if (!($user == 'admin' || $tiki_p_admin == 'y' || $tiki_p_admin_users == 'y')) { // temporary patch: tiki_p_admin includes tiki_p_admin_users but if you don't clean the temp/cache each time you sqlupgrade the perms setting is not synchornous with the cache
+	$smarty->assign('errortype', 401);
 	$smarty->assign('msg', tra("You do not have permission to use this feature"));
 	$smarty->display("error.tpl");
 	die;
@@ -23,7 +24,7 @@ function discardUser($u, $reason) {
 
 function batchImportUsers() {
 	$patterns['login'] = "/^[-_a-zA-Z0-9@\.]*$/";
-	global $userlib, $smarty, $logslib, $tiki_p_admin, $user;
+	global $userlib, $smarty, $logslib, $tiki_p_admin, $user, $prefs;
 
 	$fname = $_FILES['csvlist']['tmp_name'];
 	$fhandle = fopen($fname, "r");
@@ -33,13 +34,15 @@ function batchImportUsers() {
 		$smarty->display("error.tpl");
 		die;
 	}
-	if ($fields[0]!="login" && $fields[0]!="password" && $fields[0]!="email" && $fields[0]!="realname" && $fields[0]!="groups") {
-		$smarty->assign('msg', tra("The file does not have the required header:")." login, password, email, groups");
+	if ($fields[0]!="login" && $fields[0]!="password" && $fields[0]!="email" && $fields[0]!="groups") {
+		$smarty->assign('msg', tra("The file does not have the required header:")." login, email, password, groups");
 		$smarty->display("error.tpl");
 		die;	
 	}	
 	while (!feof($fhandle)) {
-		$data = fgetcsv($fhandle, 1000);	
+		$data = fgetcsv($fhandle, 1000);
+		if (empty($data))
+			continue;
 		$temp_max = count($fields);
 		for ($i = 0; $i < $temp_max; $i++) {
 			if ($fields[$i] == "login" && function_exists("mb_detect_encoding") && mb_detect_encoding($data[$i], "ASCII, UTF-8, ISO-8859-1") ==  "ISO-8859-1") {
@@ -57,26 +60,56 @@ function batchImportUsers() {
 	}
 	$added = 0;
 	$errors = array();
+	$discarded = array();
 	if ($tiki_p_admin != 'y')
 		$userGroups = $userlib->get_user_groups_inclusion($user);
 	foreach ($userrecs as $u) {
-		if (empty($u['login'])) {
-			$discarded[] = discardUser($u, tra("User login is required"));
-		} elseif (empty($u['password'])) {
-			$discarded[] = discardUser($u, tra("Password is required"));
-		} elseif (empty($u['email'])) {
-			$discarded[] = discardUser($u, tra("Email is required"));
-		} elseif (!preg_match($patterns['login'],$u['login'])) {
-			$discarded[] = discardUser($u, tra("Login contains invalid characters"));
-		} elseif ($userlib->user_exists($u['login'])and (!isset($_REQUEST['overwrite']))) {
-			$discarded[] = discardUser($u, tra("User is duplicated"));
-		} else {
-			if (!$userlib->user_exists($u['login'])) {
-				$userlib->add_user($u['login'], $u['password'], $u['email'], '', NULL, $u['realname']);
-				$logslib->add_log('users',sprintf(tra("Created account %s <%s> for %s."),$u["login"], $u["email"], $u["realname"]));				
+		$local = array();
+		$exist = false;
+		if ($prefs['feature_intertiki'] == 'y' && !empty($prefs['feature_intertiki_mymaster'])) {
+			if (empty($u['login']) && empty($u['email'])) {
+				$local[] = discardUser($u, tra("User login or email is required"));
+			} else { // pick up the info on the master
+				$info = $userlib->interGetUserInfo($prefs['interlist'][$prefs['feature_intertiki_mymaster']], empty($u['login'])?'':$u['login'], empty($u['email'])?'':$u['email']);
+				if (empty($info)) {
+					$local[] = discardUser($u, tra("User does not exist on master"));
+				} else {
+					$u['login'] = $info['login'];
+					$u['email'] = $info['email'];
+				}
 			}
+		} else {
+			if (empty($u['login'])) {
+				$local[] = discardUser($u, tra("User login is required"));
+			}
+			if (empty($u['password'])) {
+				$local[] = discardUser($u, tra("Password is required"));
+			}
+			if (empty($u['email'])) {
+				$local[] = discardUser($u, tra("Email is required"));
+			}
+		}
+		if (!empty($local)) {
+			$discarded = array_merge($discarded, $local);
+			continue;
+		}
+		if ($userlib->user_exists($u['login'])) { // exist on local
+			$exist = true;
+		}
+		if ($exist && $_REQUEST['overwrite'] == 'n') {
+			$discarded[] = discardUser($u, tra("User is duplicated"));
+			continue;
+		}
+		if (!$exist) {
+			$pass_first_login = (isset($_REQUEST['pass_first_login']) && $_REQUEST['pass_first_login'] == 'on') ? true: false;
+			$userlib->add_user($u['login'], $u['password'], $u['email'], '', $pass_first_login);
+			$logslib->add_log('users',sprintf(tra("Created account %s <%s>"),$u['login'], $u['email']));
+		}
+		$userlib->set_user_fields($u);
 
-			$userlib->set_user_fields($u);
+		if ($exist && isset($_REQUEST['overwriteGroup'])) {
+			$userlib->remove_user_from_all_groups($u['login']);
+		}
 
 			if (@$u['groups']) {
 				$grps = explode(",", $u['groups']);
@@ -88,6 +121,7 @@ function batchImportUsers() {
 						if (!in_array($err, $errors))
 								$errors[] = $err;
 					} elseif ($tiki_p_admin != 'y' &&  !array_key_exists($grp, $userGroups)) {
+						$smarty->assign('errortype', 401);
 						$err = tra("Permission denied").": $grp";
 						if (!in_array($err, $errors))
 								$errors[] = $err;
@@ -97,21 +131,20 @@ function batchImportUsers() {
 					}
 				}
 			}
-			$added++;
-		}
+		$added++;
 	}
 	$smarty->assign('added', $added);
-	if (@is_array($discarded)) {
+	if (count($discarded)) {
 		$smarty->assign('discarded', count($discarded));
+		$smarty->assign_by_ref('discardlist', $discarded);
 	}
-	@$smarty->assign('discardlist', $discarded);
 	if (count($errors)) {
 		array_unique($errors);
 		$smarty->assign_by_ref('errors', $errors);
 	}
 }
-
 $cookietab = "1";
+
 // Process the form to add a user here
 if (isset($_REQUEST["newuser"])) {
 	check_ticket('admin-users');
@@ -121,15 +154,27 @@ if (isset($_REQUEST["newuser"])) {
 	} else {
 		// Check if the user already exists
 		if ($_REQUEST["pass"] != $_REQUEST["pass2"]) {
-			$tikifeedback[] = array('num'=>1,'mes'=>tra("The passwords don't match"));
+			$tikifeedback[] = array('num'=>1,'mes'=>tra("The passwords do not match"));
 		} else {
 			if ($userlib->user_exists($_REQUEST["name"])) {
 				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("User %s already exists"),$_REQUEST["name"]));
+			} elseif ($prefs['login_is_email'] == 'y' && !validate_email($_REQUEST['name'])) {
+				$tikifeedback[] = array('num'=>1,'mes'=>tra("Invalid email").' '.$_REQUEST['name']);
 			} elseif (!preg_match($patterns['login'],$_REQUEST['name'])) {
 				$tikifeedback[] = array('num'=>1,'mes'=>tra("User login contains invalid characters"));
 			} else {
-				if ($userlib->add_user($_REQUEST["name"], $_REQUEST["pass"], $_REQUEST["email"], '', NULL, $_REQUEST['realname'])) {
-					$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("New %s created with %s %s (%s)."),tra("user"),tra("username"),$_REQUEST["name"], $_REQUEST["realname"]));
+				$pass_first_login = (isset($_REQUEST['pass_first_login']) && $_REQUEST['pass_first_login'] == 'on') ? true: false;
+
+				$polerr = $userlib->check_password_policy($_POST["pass"]);
+				if ( strlen($polerr)>0 ) {
+					$smarty->assign('msg',$polerr);
+				    $smarty->display("error.tpl");
+				    die;
+				}
+				if ($prefs['login_is_email'] == 'y' and empty($_REQUEST['email']))
+					$_REQUEST['email'] = $_REQUEST['name'];
+				if ($userlib->add_user($_REQUEST["name"], $_REQUEST["pass"], $_REQUEST["email"], '', $pass_first_login)) {
+					$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("New %s created with %s %s."),tra("user"),tra("username"),$_REQUEST["name"]));
 					$cookietab = '1';
 					$_REQUEST['find'] = $_REQUEST["name"];
 				} else {
@@ -142,19 +187,20 @@ if (isset($_REQUEST["newuser"])) {
 		}
 	}
 } elseif (isset($_REQUEST["action"])) {
-	if ($_REQUEST["action"] == 'delete') {
+	if ($_REQUEST["action"] == 'delete' && $_REQUEST["user"] != 'admin') {
 		$area = 'deluser';
-		if ($feature_ticketlib2 != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+		if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
 			key_check($area);
 			$userlib->remove_user($_REQUEST["user"]);
 			$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s %s successfully deleted."),tra("user"),$_REQUEST["user"]));
+			$logslib->add_log('users',sprintf(tra("Deleted account %s"),$_REQUEST['user']));
 		} else {
 			key_get($area);
 		}
 	}
 	if ($_REQUEST["action"] == 'removegroup') {
 		$area = 'deluserfromgroup';
-		if ($feature_ticketlib2 != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+		if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
 			key_check($area);
 			$userlib->remove_user_from_group($_REQUEST["user"], $_REQUEST["group"]);
 			$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s %s removed from %s %s."),tra("user"),$_REQUEST["user"],tra("group"),$_REQUEST["group"]));
@@ -169,15 +215,16 @@ if (isset($_REQUEST["newuser"])) {
 } elseif (!empty($_REQUEST["submit_mult"]) && !empty($_REQUEST["checked"])) {
 	if ($_REQUEST['submit_mult'] == 'remove_users' || $_REQUEST['submit_mult'] == 'remove_users_with_page') {
 		$area = 'batchdeluser';
-		if ($feature_ticketlib2 == 'n' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+		if ($prefs['feature_ticketlib2'] == 'n' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
 			key_check($area);
-			foreach ($_REQUEST["checked"] as $deleteuser) {
+			foreach ($_REQUEST["checked"] as $deleteuser) if ( $deleteuser != 'admin' ) {
 				$userlib->remove_user($deleteuser);
+				$logslib->add_log('users',sprintf(tra("Deleted account %s"),$deleteuser));
 				if ($_REQUEST['submit_mult'] == 'remove_users_with_page')
-					$tikilib->remove_all_versions($feature_wiki_userpage_prefix.$deleteuser);
+					$tikilib->remove_all_versions($prefs['feature_wiki_userpage_prefix'].$deleteuser);
 				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s <b>%s</b> successfully deleted."),tra("user"),$deleteuser));
 			}
-		} elseif ( $feature_ticketlib2 == 'y') {
+		} elseif ( $prefs['feature_ticketlib2'] == 'y') {
 			$ch = "";
 			foreach ($_REQUEST['checked'] as $c) {
 				$ch .= "&amp;checked[]=".urlencode($c);
@@ -218,11 +265,11 @@ if (isset($_REQUEST["newuser"])) {
 	if (!empty($_REQUEST["checked_groups"]) && !empty($_REQUEST["checked"])) {
 		if ($tiki_p_admin != 'y')
 			$userGroups = $userlib->get_user_groups_inclusion($user);
-		foreach ($_REQUEST['checked'] as $user) {
+		foreach ($_REQUEST['checked'] as $assign_user) {
 			foreach ($_REQUEST["checked_groups"] as $group) {
-				if ($tiki_p_admin == 'y' || array_key_exists($group, $userGroups)) {
-					$userlib->assign_user_to_group($user, $group);
-					$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s <b>%s</b> assigned to %s <b>%s</b>."),tra("user"),$user,tra("group"),$group));
+				if ($tiki_p_admin == 'y' || array_key_exists($group, $userGroups)) {					
+					$userlib->assign_user_to_group($assign_user, $group);
+					$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s <b>%s</b> assigned to %s <b>%s</b>."),tra("user"),$assign_user,tra("group"),$group));
 				}
 			}
 		}
@@ -232,10 +279,10 @@ if (isset($_REQUEST["newuser"])) {
 	}					
 } elseif (!empty($_REQUEST['group_management']) && $_REQUEST['group_management'] == 'remove') {
 	if (!empty($_REQUEST["checked_groups"]) && !empty($_REQUEST["checked"])) {
-		foreach ($_REQUEST['checked'] as $user) {
+		foreach ($_REQUEST['checked'] as $assign_user) {
 			foreach ($_REQUEST["checked_groups"] as $group) {
-				$userlib->remove_user_from_group($user, $group);
-				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s <b>%s</b> removed from %s <b>%s</b>."),tra("user"),$user,tra("group"),$group));
+				$userlib->remove_user_from_group($assign_user, $group);
+				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s <b>%s</b> removed from %s <b>%s</b>."),tra("user"),$assign_user,tra("group"),$group));
 			}
 		}
 	}
@@ -244,10 +291,10 @@ if (isset($_REQUEST["newuser"])) {
 	}					
 } elseif (!empty($_REQUEST['set_default_groups']) && $_REQUEST['set_default_groups'] == 'y') {
 	if (!empty($_REQUEST["checked_group"]) && !empty($_REQUEST["checked"])) {
-		foreach ($_REQUEST['checked'] as $user) {
+		foreach ($_REQUEST['checked'] as $assign_user) {
 			$group = $_REQUEST["checked_group"];
-			$userlib->set_default_group($user, $group);
-			$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("group <b>%s</b> set as the default group of user <b>%s</b>."),$group,$user));
+			$userlib->set_default_group($assign_user, $group);
+			$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("group <b>%s</b> set as the default group of user <b>%s</b>."),$group,$assign_user));
 		}
 	}
 	if (isset($tikifeedback[0]['msg'])) {
@@ -292,16 +339,31 @@ if (isset($_REQUEST["find"])) {
 }
 $smarty->assign('find', $find);
 
-$users = $userlib->get_users($offset, $numrows, $sort_mode, $find, $initial, true);
+if (isset($_REQUEST["filterGroup"])) {
+	$filterGroup = $_REQUEST["filterGroup"];
+} else {
+	$filterGroup = '';
+}
+$smarty->assign('filterGroup', $filterGroup);
 
-$arraylen = count($users['data']);
-for ($i=0; $i<$arraylen; $i++) {
-	if (!empty($group_management_mode) || !empty($set_default_groups_mode)) {
+if (isset($_REQUEST["filterEmail"])) {
+	$filterEmail = $_REQUEST["filterEmail"];
+} else {
+	$filterEmail = '';
+}
+$smarty->assign('filterEmail', $filterEmail);
+
+
+//$users = $userlib->get_users($offset, $numrows, $sort_mode, $find, $initial, true);
+$users = $userlib->get_users($offset, $numrows, $sort_mode, $find, $initial, true, $filterGroup, $filterEmail);
+
+if (!empty($group_management_mode) || !empty($set_default_groups_mode)) {
+	$arraylen = count($users['data']);
+	for ($i=0; $i<$arraylen; $i++) {
 		if (in_array($users['data'][$i]['user'], $_REQUEST["checked"])) {
 			$users['data'][$i]['checked'] = 'y';
 		}
 	}
-	$users['data'][$i]['realName'] = $userlib->get_user_name($users['data'][$i]['user']);
 }
 
 $smarty->assign_by_ref('users', $users["data"]);
@@ -326,11 +388,14 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 		$_REQUEST["user"] = $userlib->get_user_id($_REQUEST["user"]);
 	}
 	$userinfo = $userlib->get_userid_info($_REQUEST["user"]);
-	$userinfo['realName'] = $userlib->get_user_name($userinfo['login']);
-	if (isset($_POST["edituser"]) and isset($_POST['name']) and isset($_POST['email']) and isset($_POST['realname'])) {
+
+	// If login is e-mail, email field needs to be the same as name (and is generally not send)
+	if ( $prefs['login_is_email'] == 'y' && isset($_POST['name']) ) $_POST['email'] = $_POST['name'];
+
+	if (isset($_POST["edituser"]) and isset($_POST['name']) and isset($_POST['email'])) {
 		//var_dump($_POST);die;
 		if ($_POST['name']) {
-			if ($userinfo['login'] != $_POST['name']) {
+			if ( $userinfo['login'] != $_POST['name'] && $userinfo['login'] != 'admin' ) {
 				if ($userlib->user_exists($_POST['name'])) {
 					$smarty->assign('msg', tra("User already exists"));
 			  	$smarty->display("error.tpl");
@@ -341,25 +406,19 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 		}
 		if (isset($_POST['pass']) &&  $_POST["pass"]) {
 			if ($_POST["pass"] != $_POST["pass2"]) {
-				$smarty->assign('msg', tra("The passwords dont match"));
+				$smarty->assign('msg', tra("The passwords do not match"));
 				$smarty->display("error.tpl");
 				die;
 			} 
-			if (strlen($_POST["pass"])<$min_pass_length) {
-				$smarty->assign('msg',tra("Password should be at least").' '.$min_pass_length.' '.tra("characters long"));
-				$smarty->display("error.tpl");
-				die; 	
-			} 
-			if ($pass_chr_num == 'y') {
-				if (!preg_match_all("/[0-9]+/",$_POST["pass"],$foo) || !preg_match_all("/[A-Za-z]+/",$_POST["pass"],$foo)) {
-					$smarty->assign('msg',tra("Password must contain both letters and numbers"));
-					$smarty->display("error.tpl");
-					die; 	
-				}
+			$polerr = $userlib->check_password_policy($_POST["pass"]);
+			if ( strlen($polerr)>0 ) {
+				$smarty->assign('msg',$polerr);
+			    $smarty->display("error.tpl");
+			    die;
 			}
 			if ($userlib->change_user_password($_POST['name'],$_POST["pass"])) {
 				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s modified successfully."),tra("password")));
-				$logslib->add_log('adminusers','','changed password for '.$_POST['name']);
+				$logslib->add_log('adminusers','changed password for '.$_POST['name']);
 			} else {
 				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s modification failed."),tra("password")));
 			}
@@ -367,27 +426,18 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 		if ($userinfo['email'] != $_POST['email']) {
 			if ($userlib->change_user_email($_POST['name'],$_POST['email'],'')) {
 				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s changed from %s to %s"),tra("email"),$userinfo['email'],$_POST["email"]));
-				$logslib->add_log('adminusers','','changed email for '.$_POST['name'].' from '.$userinfo['email'].' to '.$_POST["email"]);
+				$logslib->add_log('adminusers','changed email for '.$_POST['name'].' from '.$userinfo['email'].' to '.$_POST["email"]);
 				$userinfo['email'] = $_POST['email'];
 			} else {
 				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("Impossible to change %s from %s to %s"),tra("email"),$userinfo['email'],$_POST["email"]));
 			}
 		}
-		if ($userinfo['realName'] != $_POST['realname']) {
-			if ($userlib->change_user_name($userinfo['login'],$_POST['realname'])) {
-				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s changed from %s to %s"),tra("real name"),$userinfo['realName'],$_POST["realname"]));
-				$logslib->add_log('adminusers','','changed realName for '.$_POST['name'].' from '.$userinfo['realName'].' to '.$_POST["realname"]);
-				$userinfo['realName'] = $_POST['realname'];
-			} else {
-				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("Impossible to change %s from %s to %s"),tra("real name"),$userinfo['realName'],$_POST["realname"]));
-			}
-		}
 		if ($chlogin) {
 			if (!preg_match($patterns['login'],$_POST['name'])) {
 				$tikifeedback[] = array('num'=>1,'mes'=>tra("Login contains invalid characters"));
 			} elseif ($userlib->change_login($userinfo['login'],$_POST['name'])) {
 				$tikifeedback[] = array('num'=>0,'mes'=>sprintf(tra("%s changed from %s to %s"),tra("login"),$userinfo['login'],$_POST["name"]));
-				$logslib->add_log('adminusers','','changed login for '.$_POST['name'].' from '.$userinfo['login'].' to '.$_POST["name"]);
+				$logslib->add_log('adminusers','changed login for '.$_POST['name'].' from '.$userinfo['login'].' to '.$_POST["name"]);
 				$userinfo['login'] = $_POST['name'];
 			} else {
 				$tikifeedback[] = array('num'=>1,'mes'=>sprintf(tra("Impossible to change %s from %s to %s"),tra("login"),$userinfo['email'],$_POST["email"]));
@@ -395,7 +445,7 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 		}
 		setcookie("activeTabs".urlencode(substr($_SERVER["REQUEST_URI"],1)),"tab1");
 	}
-	if ($userTracker == 'y') {
+	if ($prefs['userTracker'] == 'y') {
 		$re = $userlib->get_usertracker($_REQUEST["user"]);
 		if ($re['usersTrackerId']) {
 			include_once('lib/trackers/trackerlib.php');
@@ -415,7 +465,7 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 } else {
 	$userinfo['login'] = '';
 	$userinfo['email'] = '';
-	$userinfo['created'] = date('U');
+	$userinfo['created'] = $tikilib->now;
 	$userinfo['registrationDate'] = '';
 	$userinfo['age'] = '';
 	$userinfo['currentLogin'] = '';
@@ -425,6 +475,8 @@ if (isset($_REQUEST["user"]) and $_REQUEST["user"]) {
 if (isset($_REQUEST['add'])) {
 	$cookietab = "2";
 }
+$all_groups = $userlib->get_groups();
+$smarty->assign_by_ref('all_groups', $all_groups['data']);
 
 $smarty->assign('userinfo', $userinfo);
 $smarty->assign('userId', $_REQUEST["user"]);
