@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-custom_home.php,v 1.13.2.2 2007/03/02 12:23:27 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-custom_home.php,v 1.17 2007-10-12 07:55:25 nyloth Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -25,7 +25,7 @@ print_r($h);
 $b = $nntp->getBody(1);
 print_r($b);
 */
-if ($feature_custom_home != 'y') {
+if ($prefs['feature_custom_home'] != 'y') {
 	$smarty->assign('msg', tra("This feature has been disabled"));
 
 	$smarty->display("error.tpl");
