@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-handlers.php,v 1.6.2.4 2008/02/21 20:28:17 lphuberdeau Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-handlers.php,v 1.9 2007-03-06 19:29:49 sylvieg Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -18,9 +18,4 @@
 //$tikilib->add_pos_handler("foo");
 //$tikilib->add_postedit_handler("foo");
 
-if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
-  header("location: index.php");
-  exit;
-}
-
-?>
+?>
\ No newline at end of file
