@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-pv_chart.php,v 1.7.2.6 2007/03/02 12:23:17 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-pv_chart.php,v 1.13 2007-10-12 07:55:29 nyloth Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -12,7 +12,7 @@ require_once ('tiki-setup.php');
 require_once ("graph-engine/graph.multiline.php");
 require_once ("graph-engine/gd.php");
 
-if ($feature_stats != 'y') {
+if ($prefs['feature_stats'] != 'y') {
 	die;
 }
 
