@@ -1,20 +1,17 @@
 <?php
 
-
 require_once('tiki-setup.php');
 
-
-if ($feature_quizzes != 'y') {
+if ($prefs['feature_quizzes'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_quizzes");
 
 	$smarty->display("error.tpl");
 	die;
 }
 
-
 require_once('lib/quizzes/quizlib.php');
 
 if (isset($_REQUEST['answerUploadId'])) {
-	$quizlib->download_answer($_REQUEST['answerUploadId']);
+	$quizlib->download_answer($_REQUEST['answerUploadId']);	
 }
 ?>
