@@ -3,6 +3,7 @@
 require_once('tiki-setup.php');
 
 if ($tiki_p_admin != 'y') {
+	$smarty->assign('errortype', 401);
 	$smarty->assign('msg', tra("You do not have permission to use this feature"));
 
 	$smarty->display("error.tpl");
@@ -19,22 +20,14 @@ $tmp2 = isset($_SERVER["PHP_SELF"]) ? $_SERVER["PHP_SELF"] : "";
 $url = $tmp1.dirname($tmp2);
 
 $info = Array();
-$info["name"] = $tikilib->get_preference( "siteTitle", "" );
+$info["name"] = $prefs['siteTitle'];
 $info["description"] = '';
 $info["url"] = $url;
 $info["country"] = 'None';
 $info["isValid"] = 'n';
 $smarty->assign_by_ref('info',$info);
 
-$countries=Array();
-$h=opendir("img/flags");
-while($file=readdir($h)) {
-  if(is_file('img/flags/'.$file)) {
-    $name=explode('.',$file);
-    $countries[]=$name[0];
-  }
-}
-closedir($h);
+$countries = $tikilib->get_flags();
 $smarty->assign_by_ref('countries',$countries);
 
 // Display the template
