@@ -1,21 +1,17 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/tiki-replicate.php,v 1.1.4.1 2005/01/05 19:45:28 jburleyebuilt Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-replicate.php,v 1.4 2007-10-12 07:55:32 nyloth Exp $
 
 require_once ('tiki-setup.php');
 include_once 'lib/logs/logslib.php';
 
 if ($tiki_p_admin != 'y') {
-	if (!$user) {
-		$smarty->assign('msg',$smarty->fetch('modules/mod-login_box.tpl'));
-		$smarty->assign('errortitle',tra("Please login"));
-	} else {
-		$smarty->assign('msg', tra("You do not have permission to use this feature"));
-	}
+	$smarty->assign('errortype', 401);
+	$smarty->assign('msg', tra("You do not have permission to use this feature"));
 	$smarty->display("error.tpl");
 	die;
 }
 
-$master = $tikilib->get_preference('replimaster','');
+$master = $prefs['replimaster'];
 
 if (isset($_POST['action']) and $_POST['action']  == 'save') {
 	if ($master != $newmaster) {
