@@ -1,16 +1,12 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/tiki-replicate_console.php,v 1.2.2.1 2005/01/05 19:45:28 jburleyebuilt Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-replicate_console.php,v 1.4 2005-05-18 10:58:59 mose Exp $
 
 require_once ('tiki-setup.php');
 include_once 'lib/logs/logslib.php';
 
 if ($tiki_p_admin != 'y') {
-	if (!$user) {
-		$smarty->assign('msg',$smarty->fetch('modules/mod-login_box.tpl'));
-		$smarty->assign('errortitle',tra("Please login"));
-	} else {
-		$smarty->assign('msg', tra("You do not have permission to use this feature"));
-	}
+	$smarty->assign('errortype', 401);
+	$smarty->assign('msg', tra("You do not have permission to use this feature"));
 	$smarty->display("error.tpl");
 	die;
 }
