@@ -7,15 +7,17 @@ include_once('lib/tikilib.php');
 if (isset($_SERVER['HTTP_REFERER'])) {
 	$orig_url = $_SERVER['HTTP_REFERER'];
 } else {
-	$orig_url = $tikiIndex;
+	$orig_url = $prefs['tikiIndex'];
 }
 
 if (isset($_GET['theme'])){
 	$new_theme = $_GET['theme'];
-	if($feature_userPreferences == 'y' && $user && $change_theme == 'y') {  
+	if ($prefs['feature_userPreferences'] == 'y' && $user && $prefs['change_theme'] == 'y') {  
 		$tikilib->set_user_preference($user,'theme',$new_theme);
-	} elseif ($change_theme == 'y') {
-		$a = setcookie('tiki-theme', $new_theme, time()+3600*24*30*12);
+		$prefs['style'] = $new_theme;
+	} elseif ($prefs['change_theme'] == 'y') {
+		$prefs['style'] = $new_theme;
+		$_SESSION['s_prefs']['style'] = $new_theme;
 	}
 }
 
