@@ -1,12 +1,13 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-user_cached_bookmark.php,v 1.7.2.2 2007/03/02 12:23:29 luciash Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-user_cached_bookmark.php,v 1.12 2007-10-12 07:55:32 nyloth Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 // Initialization
+$section = 'mytiki';
 require_once ('tiki-setup.php');
 
 include_once ('lib/bookmarks/bookmarklib.php');
@@ -18,7 +19,7 @@ if (!$user) {
 	die;
 }
 
-if ($feature_user_bookmarks != 'y') {
+if ($prefs['feature_user_bookmarks'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_user_bookmarks");
 
 	$smarty->display("error.tpl");
