@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_minical_topic.php,v 1.4.2.3 2008/02/21 19:35:58 lphuberdeau Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-view_minical_topic.php,v 1.7.2.1 2008-03-01 16:07:36 lphuberdeau Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -11,20 +11,22 @@ require_once ('tiki-setup.php');
 
 include_once ('lib/minical/minicallib.php');
 
-if ($feature_minical != 'y') {
+if ($prefs['feature_minical'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_minical");
 
 	$smarty->display("error.tpl");
 	die;
 }
 
-if ($tiki_p_minical != 'y') {
+if ($prefs['tiki_p_minical'] != 'y') {
+	$smarty->assign('errortype', 401);
 	$smarty->assign('msg', tra("Permission denied"));
 
 	$smarty->display("error.tpl");
 	die;
 }
 
+
 if (!$user)
 	die;
 
