@@ -1,30 +1,35 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker.php,v 1.72.2.82 2007/12/10 04:28:34 kerrnel22 Exp $
+// $Id: /cvsroot/tikiwiki/tiki/tiki-view_tracker.php,v 1.141.2.19 2008-03-21 21:50:39 sylvieg Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 // Initialization
+$section = 'trackers';
 require_once('tiki-setup.php');
 
 include_once('lib/trackers/trackerlib.php');
 global $notificationlib; include_once('lib/notifications/notificationlib.php');
 
-if ($feature_categories == 'y') {
+$auto_query_args = array('offset','trackerId','reloff','itemId','maxRecords','status','sort_mode','initial','filterfield','filtervalue');
+
+if ($prefs['feature_categories'] == 'y') {
 	global $categlib;
 	if (!is_object($categlib)) {
 		include_once('lib/categories/categlib.php');
 	}
 }
 
-if ($feature_trackers != 'y') {
+if ($prefs['feature_trackers'] != 'y') {
 	$smarty->assign('msg', tra("This feature is disabled").": feature_trackers");
 	$smarty->display("error.tpl");
 	die;
 }
 
+if (!empty($_REQUEST['itemId']))
+	$ratedItemId = $_REQUEST['itemId'];
 $_REQUEST["itemId"] = 0;
 $smarty->assign('itemId', $_REQUEST["itemId"]);
 
@@ -34,67 +39,26 @@ if (!isset($_REQUEST["trackerId"])) {
 	die;
 }
 
-$smarty->assign('individual', 'n');
+$tracker_info = $trklib->get_tracker($_REQUEST["trackerId"]);
+if (empty($tracker_info)) {
+	$smarty->assign('msg', tra("No tracker indicated"));
+	$smarty->display("error.tpl");
+	die;
+}
+if ($t = $trklib->get_tracker_options($_REQUEST["trackerId"])) {
+	$tracker_info = array_merge($tracker_info,$t);
+ }
 
-if ($userlib->object_has_one_permission($_REQUEST["trackerId"], 'tracker')) {
-	$smarty->assign('individual', 'y');
-	if ($tiki_p_admin != 'y') {
-		$perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'trackers');
-		foreach ($perms["data"] as $perm) {
-			$permName = $perm["permName"];
-			if ($userlib->object_has_permission($user, $_REQUEST["trackerId"], 'tracker', $permName)) {
-				$$permName = 'y';
-				$smarty->assign("$permName", 'y');
-				if ($permName == 'tiki_p_admin_trackers') {
-					$propagate = true;
-				}
-			} else {
-				$$permName = 'n';
-				$smarty->assign("$permName", 'n');
-			}
-		}
-	}
-} elseif ($tiki_p_admin != 'y' && $feature_categories == 'y') {
-	$perms_array = $categlib->get_object_categories_perms($user, 'tracker', $_REQUEST['trackerId']);
-   	if ($perms_array) {
-   		$is_categorized = TRUE;
-    	foreach ($perms_array as $perm => $value) {
-    		$$perm = $value;
-    	}
-		if ($tiki_p_view_categories == 'y' || $tiki_p_admin_categories == 'y') {
-			$tiki_p_view_categories = 'y';
-			$tiki_p_view_trackers = 'y';
-			$smarty->assign('tiki_p_view_trackers', 'y');
-		}
-   	} else {
-   		$is_categorized = FALSE;
-   	}
-	if ($is_categorized && isset($tiki_p_view_categories) && $tiki_p_view_categories != 'y') {
-		if (!isset($user)){
-			$smarty->assign('msg',$smarty->fetch('modules/mod-login_box.tpl'));
-			$smarty->assign('errortitle',tra("Please login"));
-		} else {
-			$smarty->assign('msg',tra("Permission denied you cannot view this page"));
-    	}
-	    $smarty->display("error.tpl");
-		die;
-	}
-}
-if (!empty($propagate) && $propagate) { // if local set of tiki_p_admin_trackers, need to other perm
-    $perms = $userlib->get_permissions(0, -1, 'permName_desc', '', 'trackers');
-    foreach ($perms['data'] as $perm) {
-        $perm = $perm['permName'];
-        $smarty->assign("$perm", 'y');
-        $$perm = 'y';
-    }
-}
+$tikilib->get_perm_object($_REQUEST['trackerId'], 'tracker', $tracker_info);
 
 if (!empty($_REQUEST['show']) && $_REQUEST['show'] == 'view') {
 	$cookietab = '1';
 } elseif (!empty($_REQUEST['show']) && $_REQUEST['show'] == 'mod') {
 	$cookietab = '2';
 } elseif (empty($_REQUEST['cookietab'])) {
-	if (!($tiki_p_view_trackers == 'y' || $tiki_p_admin == 'y' || $tiki_p_admin_trackers == 'y') && $tiki_p_create_tracker_items  == 'y')
+	if ($tracker_info['writerCanModify'] == 'y' && $user)
+		$cookietab = '1';
+	elseif (!($tiki_p_view_trackers == 'y' || $tiki_p_admin == 'y' || $tiki_p_admin_trackers == 'y') && $tiki_p_create_tracker_items  == 'y')
 		$cookietab = "2";
 	else
 		$cookietab = "1";
@@ -127,14 +91,18 @@ if (isset($_REQUEST['my'])) {
 	}
 }
 
-$tracker_info = $trklib->get_tracker($_REQUEST["trackerId"]);
-if (empty($tracker_info)) {
-	$smarty->assign('msg', tra("No tracker indicated"));
-	$smarty->display("error.tpl");
-	die;
+if ($tiki_p_create_tracker_items == 'y' && !empty($t['start'])) {
+	if ($tikilib->now < $t['start']) {
+		$tiki_p_create_tracker_items = 'n';
+		$smarty->assign('tiki_p_create_tracker_items', 'n');
+	}
+}
+if ($tiki_p_create_tracker_items == 'y' && !empty($t['end'])) {
+	if ($tikilib->now > $t['end']) {
+		$tiki_p_create_tracker_items = 'n';
+		$smarty->assign('tiki_p_create_tracker_items', 'n');
+	}
 }
-if ($t = $trklib->get_tracker_options($_REQUEST["trackerId"]))
-	$tracker_info = array_merge($tracker_info,$t);
 
 if ($tiki_p_view_trackers != 'y') {
 	if (!$my and isset($tracker_info['writerCanModify']) and $tracker_info['writerCanModify'] == 'y') {
@@ -142,12 +110,8 @@ if ($tiki_p_view_trackers != 'y') {
 	} elseif (!$ours and isset($tracker_info['writergroupCanModify']) and $tracker_info['writergroupCanModify'] == 'y') {
 		$ours = $group;
 	} elseif ($tiki_p_create_tracker_items != 'y') {
-		if (!isset($user)){
-			$smarty->assign('msg',$smarty->fetch('modules/mod-login_box.tpl'));
-			$smarty->assign('errortitle',tra("Please login"));
-		} else {
-			$smarty->assign('msg', tra("You do not have permission to use this feature"));
-		}
+		$smarty->assign('errortype', 401);
+		$smarty->assign('msg', tra("You do not have permission to use this feature"));
 		$smarty->display("error.tpl");
 		die;
 	}
@@ -222,43 +186,50 @@ for ($i = 0; $i < $temp_max; $i++) {
 	if (!empty($tracker_info['defaultOrderKey']) and $tracker_info['defaultOrderKey'] == $xfields["data"][$i]['fieldId']) {
 		$orderkey = true;
 	}
+	if (($xfields['data'][$i]['type'] == 'u' || $xfields['data'][$i]['type'] == 'g' || $xfields['data'][$i]['type'] == 'I') && isset($xfields['data'][$i]['options_array'][0]) && $xfields['data'][$i]['options_array'][0] == 1) {
+		$creatorSelector = true;
+	} else {
+		$creatorSelector = false;
+	}
 	if (($xfields["data"][$i]['isTblVisible'] == 'y' or $xfields["data"][$i]['isSearchable'] == 'y' or in_array($fid, $popupFields)) 
-//		and ($xfields["data"][$i]['isPublic'] == 'y' or $tiki_p_admin_trackers == 'y') ispublic is for tracker plugin not normal view
-		and ($xfields["data"][$i]['isHidden'] == 'n' or $xfields["data"][$i]['isHidden'] == '-' or $tiki_p_admin_trackers == 'y')
+		and ($xfields["data"][$i]['isHidden'] == 'n' or $xfields["data"][$i]['isHidden'] == 'p' or $tiki_p_admin_trackers == 'y' or ($xfields["data"][$i]['type'] == 's' and $xfields['data'][$i]['name'] == 'Rating' and $tiki_p_tracker_view_ratings == 'y'))
 		) {
 		
 		$listfields[$fid]['type'] = $xfields["data"][$i]["type"];
 		$listfields[$fid]['name'] = $xfields["data"][$i]["name"];
 		$listfields[$fid]['options'] = $xfields["data"][$i]["options"];
-		$listfields[$fid]['options_array'] = split(',',$xfields["data"][$i]["options"]);
+		$listfields[$fid]['options_array'] = $xfields["data"][$i]['options_array'];
 		$listfields[$fid]['isMain'] = $xfields["data"][$i]["isMain"];
 		$listfields[$fid]['isTblVisible'] = $xfields["data"][$i]["isTblVisible"];
 		$listfields[$fid]['isHidden'] = $xfields["data"][$i]["isHidden"];
 		$listfields[$fid]['isSearchable'] = $xfields["data"][$i]["isSearchable"];
+		$listfields[$fid]['isMandatory'] = $xfields["data"][$i]["isMandatory"];
+		$listfields[$fid]['description'] = $xfields["data"][$i]["description"];
+		$listfields[$fid]['visibleBy'] = $xfields['data'][$i]['visibleBy'];
+		$listfields[$fid]['editableBy'] = $xfields['data'][$i]['editableBy'];
 
-		if ($listfields[$fid]['type'] == 'e') { //category
-		    $parentId = $listfields[$fid]["options"];
+		if ($listfields[$fid]['type'] == 'e' && $prefs['feature_categories'] == 'y') { //category
+			$parentId = $listfields[$fid]['options_array'][0];
 		    $listfields[$fid]['categories'] = $categlib->get_child_categories($parentId);
 		}
+		if (isset($xfields['data'][$i]['otherField']))
+			$listfields[$fid]['otherField'] = $xfields['data'][$i]['otherField'];
+	} 
 
-	}
-
-	if (($xfields["data"][$i]['isHidden'] == 'n' or $xfields["data"][$i]['isHidden'] == '-') or $tiki_p_admin_trackers == 'y') {
+	if ($creatorSelector or $xfields["data"][$i]['isHidden'] == 'n' or $xfields["data"][$i]['isHidden'] == 'c' or $xfields["data"][$i]['isHidden'] == 'p' or $tiki_p_admin_trackers == 'y' or ($xfields["data"][$i]['type'] == 's' and $xfields['data'][$i]['name'] == 'Rating' and $tiki_p_tracker_view_ratings == 'y')) {
 		$ins_fields["data"][$i] = $xfields["data"][$i];
 		$fields["data"][$i] = $xfields["data"][$i];
 		if ($fields["data"][$i]["type"] == 'f') { // date and time
 			$fields["data"][$i]["value"] = '';
 			$ins_fields["data"][$i]["value"] = '';
 			if (isset($_REQUEST["$ins_id" . "Day"])) {
-				$dc = $tikilib->get_date_converter($user);
-				$ins_fields["data"][$i]["value"] = $dc->getServerDateFromDisplayDate(mktime($_REQUEST["$ins_id" . "Hour"], $_REQUEST["$ins_id" . "Minute"],
-				0, $_REQUEST["$ins_id" . "Month"], $_REQUEST["$ins_id" . "Day"], $_REQUEST["$ins_id" . "Year"]));
+				$ins_fields["data"][$i]["value"] = $tikilib->make_time($_REQUEST["$ins_id" . "Hour"], $_REQUEST["$ins_id" . "Minute"],
+				0, $_REQUEST["$ins_id" . "Month"], $_REQUEST["$ins_id" . "Day"], $_REQUEST["$ins_id" . "Year"]);
 			} else {
-				$ins_fields["data"][$i]["value"] = date("U");
+				$ins_fields["data"][$i]["value"] = $tikilib->now;
 			}
-		} elseif ($fields["data"][$i]["type"] == 'e') { // category
-			include_once('lib/categories/categlib.php');
-			$parentId = $fields["data"][$i]["options"];
+		} elseif ($fields["data"][$i]["type"] == 'e' && $prefs['feature_categories'] == 'y') { // category
+			$parentId = $fields["data"][$i]['options_array'][0];
 			$fields["data"][$i]['categories'] = $categlib->get_child_categories($parentId);
 			$categId = "ins_cat_$fid";
 			if (isset($_REQUEST[$categId])) {
@@ -274,16 +245,34 @@ for ($i = 0; $i < $temp_max; $i++) {
 			$ins_fields["data"][$i]["value"] = '';
 
 		} elseif ($fields["data"][$i]["type"] == 'u') { // user selection
-			if (isset($_REQUEST["$ins_id"]) and $_REQUEST["$ins_id"] and (!$fields["data"][$i]["options"] or $tiki_p_admin_trackers == 'y')) {
+			if (isset($_REQUEST["$ins_id"]) and $_REQUEST["$ins_id"] and (!$fields["data"][$i]['options_array'][0] or $tiki_p_admin_trackers == 'y')) {
 				$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
 			} else {
-				if ($fields["data"][$i]["options"] == 1 and $user) {
+				if ($fields["data"][$i]['options_array'][0] == 1 and $user) {
 					$ins_fields["data"][$i]["value"] = $user;
 				} else {
 					$ins_fields["data"][$i]["value"] = '';
 				}
 			}
-			if ($fields["data"][$i]["options"] == 1 and !$writerfield) {
+			if ($fields["data"][$i]['options_array'][0] == 1 and !$writerfield) {
+				$writerfield = $fid;
+			} elseif (isset($_REQUEST["$filter_id"])) {
+				$fields["data"][$i]["value"] = $_REQUEST["$filter_id"];
+			} else {
+				$fields["data"][$i]["value"] = '';
+			}
+
+		} elseif ($fields["data"][$i]["type"] == 'I') { // IP selection
+			if (isset($_REQUEST["$ins_id"]) and $_REQUEST["$ins_id"] and (!$fields["data"][$i]['options_array'][0] or $tiki_p_admin_trackers == 'y')) {
+				$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
+			} else {
+				if ($fields["data"][$i]['options_array'][0] == 1 and $_SERVER['REMOTE_ADDR']) {
+					$ins_fields["data"][$i]["value"] = $_SERVER['REMOTE_ADDR'];
+				} else {
+					$ins_fields["data"][$i]["value"] = '';
+				}
+			}
+			if ($fields["data"][$i]['options_array'][0] == 1 and !$writerfield) {
 				$writerfield = $fid;
 			} elseif (isset($_REQUEST["$filter_id"])) {
 				$fields["data"][$i]["value"] = $_REQUEST["$filter_id"];
@@ -292,16 +281,16 @@ for ($i = 0; $i < $temp_max; $i++) {
 			}
 
 		} elseif ($fields["data"][$i]["type"] == 'g') { // group selection
-			if (isset($_REQUEST["$ins_id"]) and $_REQUEST["$ins_id"] and (!$fields["data"][$i]["options"] or $tiki_p_admin_trackers == 'y')) {
+			if (isset($_REQUEST["$ins_id"]) and $_REQUEST["$ins_id"] and (!$fields["data"][$i]['options_array'][0] or $tiki_p_admin_trackers == 'y')) {
 				$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
 			} else {
-				if ( $fields["data"][$i]["options"] == 1 and $group) {
+				if ( $fields["data"][$i]['options_array'][0] == 1 and $group) {
 					$ins_fields["data"][$i]["value"] = $group;
 				} else {
 					$ins_fields["data"][$i]["value"] = '';
 				}
 			}
-			if ($fields["data"][$i]["options"] == 1 and !$writergroupfield) {
+			if ($fields["data"][$i]['options_array'][0] == 1 and !$writergroupfield) {
 				$writergroupfield = $fid;
 			} elseif (isset($_REQUEST["$filter_id"])) {
 				$fields["data"][$i]["value"] = $_REQUEST["$filter_id"];
@@ -323,15 +312,7 @@ for ($i = 0; $i < $temp_max; $i++) {
 
 		} elseif ($fields["data"][$i]["type"] == 'a') { // textarea
 			if (isset($_REQUEST["$ins_id"])) {
-				if (isset($fields["data"][$i]["options_array"][3]) and $fields["data"][$i]["options_array"][3] > 0 and strlen($_REQUEST["$ins_id"]) > $fields["data"][$i]["options_array"][3]) {
-					if (function_exists('mb_substr')) {
-						$ins_fields["data"][$i]["value"] = mb_substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
-					} else {
-						$ins_fields["data"][$i]["value"] = substr($_REQUEST["$ins_id"],0,$fields["data"][$i]["options_array"][3])." (...)";
-					}
-				} else {
 					$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
-				}
 			} else {
 				$ins_fields["data"][$i]["value"] = '';
 			}
@@ -343,45 +324,58 @@ for ($i = 0; $i < $temp_max; $i++) {
 			if ($fields["data"][$i]["options_array"][0])	{
 				$textarea_options = true;
 			} 
-			
-		} elseif($fields["data"][$i]["type"] == 's') { // system - special
-			if ($fields["data"][$i]["name"] == "Rating") { // Rating
-				if (isset($_REQUEST["$ins_id"])) {
-					$newItemRate = $_REQUEST["$ins_id"];
-					$newItemRateField = $fields["data"]["$i"]["fieldId"];
-				} else {
-					$newItemRate = NULL;
-				}
-			} // Do nothing for "ItemID" here.
-		
+			 if ($fields["data"][$i]["isMultilingual"]=='y') {
+		        
+                                  global $multilinguallib;
+                                  include_once('lib/multilingual/multilinguallib.php');
+                                  $multi_languages=$prefs['available_languages'];
+                                  $smarty->assign('multi_languages',$multi_languages);
+                                  
+                                  $ins_fields["data"][$i]['isMultilingual']='y';
+				            $compteur=0;
+				            foreach ($multi_languages as $num=>$tmplang){
+				            //Case convert normal -> multilingual
+				            if (!isset($_REQUEST[$ins_id."_".$tmplang]) && isset($_REQUEST["$ins_id"]))
+				                $_REQUEST[$ins_id."_".$tmplang]=$_REQUEST["$ins_id"];
+				            $fields["data"][$i]["lingualvalue"][$num]["lang"] = $tmplang;
+				            if (isset($_REQUEST[$ins_id."_".$tmplang]))
+				                $fields["data"][$i]["lingualvalue"][$num]["value"] =     $_REQUEST[$ins_id."_".$tmplang];
+				            $fields["data"][$i]["lingualpvalue"][$num]["lang"] = $tmplang;
+				            if (isset($_REQUEST[$ins_id."_".$tmplang]))
+				                $fields["data"][$i]["lingualpvalue"][$num]["value"] =     $tikilib->parse_data(htmlspecialchars($_REQUEST[$ins_id."_".$tmplang]));
+					    }
+					 $ins_fields["data"][$i]["lingualpvalue"]=$fields["data"][$i]["lingualpvalue"];
+					     $ins_fields["data"][$i]["lingualvalue"]=$fields["data"][$i]["lingualvalue"];
+				        } 
+
+		} elseif($fields["data"][$i]["type"] == 's' and $xfields['data'][$i]['name'] == 'Rating') { // rating
+			if (isset($_REQUEST["$ins_id"])) {
+				$newItemRate = $_REQUEST["$ins_id"];
+				$newItemRateField = $fields["data"]["$i"]["fieldId"];
+			} else {
+				$newItemRate = NULL;
+			}
+
 		} elseif(  $fields["data"][$i]["type"] == 'y' ) { // country list
 			if (isset($_REQUEST["$ins_id"])) {		
 				$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];	
 			}
 			// Get flags here
-			$flags = array();
-			$h = opendir("img/flags/");
-			
-			while ($file = readdir($h)) {
-				if (strstr($file, ".gif")) {
-					$parts = explode('.', $file);
-					$flags[] = $parts[0];
-				}
+			if (isset($fields["data"][$i]["options_array"][1]) && $fields["data"][$i]["options_array"][1] == 1)	{
+				$fields["data"][$i]['flags'] = $trklib->get_flags(true,true,false); // Sort in english names order
+			} else {
+				$fields["data"][$i]['flags'] = $trklib->get_flags(true,true,true); // Sort in translated names order (default)
 			}
-			
-			closedir ($h);
-			sort($flags, SORT_STRING);
-			$fields["data"][$i]['flags'] = $flags;
 			$fields["data"][$i]['defaultvalue'] = 'None';
-			
+
 		} else {
 			if (isset($_REQUEST["$ins_id"])) {
 				$ins_fields["data"][$i]["value"] = $_REQUEST["$ins_id"];
 			} else {
 				$ins_fields["data"][$i]["value"] = '';
 			}
-			if ($fields['data'][$i]['type'] == 'D' && !empty($_REQUEST[$ins_id.'_other'])) { // drop down with other
-				$ins_fields['data'][$i]['value'] = $_REQUEST[$ins_id.'_other'];
+			if ($fields['data'][$i]['type'] == 'D' && !empty($_REQUEST['other_'.$ins_id])) { // drop down with other
+				$ins_fields['data'][$i]['value'] = $_REQUEST['other_'.$ins_id];
 			}
 			if (isset($_REQUEST["$filter_id"])) {
 				$fields["data"][$i]["value"] = $_REQUEST["$filter_id"];
@@ -390,22 +384,40 @@ for ($i = 0; $i < $temp_max; $i++) {
 			}
 			if ($fields["data"][$i]["type"] == 'r')	{ // item link
 				if ($tiki_p_admin_trackers == 'y') {
-					$stt = 'opc';
+					$stt = 'poc';
 				} else {
 					$stt = 'o';
 				}
-				$fields["data"][$i]["list"] = $trklib->get_all_items($fields["data"][$i]["options_array"][0],$fields["data"][$i]["options_array"][1],$stt);
-			} elseif ($fields["data"][$i]["type"] == 'i')	{ // image
+				$fields["data"][$i]["list"] = array_unique($trklib->get_all_items($fields["data"][$i]["options_array"][0],$fields["data"][$i]["options_array"][1],$stt));
+				
+				if (isset($fields["data"][$i]["options_array"][3]))
+					$fields["data"][$i]["listdisplay"] = array_unique($trklib->concat_all_items_from_fieldslist($fields["data"][$i]["options_array"][0],$fields["data"][$i]["options_array"][3]));
+			}	
+			elseif (($fields["data"][$i]["type"] == 'M') && ($fields["data"][$i]["options_array"][0] >= '3' ) )	{
+				if (isset($_FILES["$ins_id"]) &&  is_uploaded_file($_FILES["$ins_id"]['tmp_name'])) {	
+					$fp = fopen( $_FILES["$ins_id"]['tmp_name'], 'rb' );
+					$data = '';
+					while (!feof($fp)) {
+						$data .= fread($fp, 8192 * 16);
+					}
+					fclose ($fp);
+					$ins_fields["data"][$i]["value"] = $data;					
+					$ins_fields["data"][$i]["file_type"] = $_FILES["$ins_id"]['type'];
+					$ins_fields["data"][$i]["file_size"] = $_FILES["$ins_id"]['size'];
+					$ins_fields["data"][$i]["file_name"] = $_FILES["$ins_id"]['name'];
+				}
+
+			} elseif ($fields["data"][$i]["type"] == 'i' || $fields['data'][$i]['type'] == 'A')	{ // image or file
 				if (isset($_FILES["$ins_id"]) && is_uploaded_file($_FILES["$ins_id"]['tmp_name'])) {
-					if (!empty($gal_match_regex)) {
-						if (!preg_match("/$gal_match_regex/", $_FILES["$ins_id"]['name'], $reqs)) {
+					if ($fields['data'][$i]['type'] == 'i' && !empty($prefs['gal_match_regex'])) {
+						if (!preg_match('/'.$prefs['gal_match_regex'].'/', $_FILES["$ins_id"]['name'], $reqs)) {
 							$smarty->assign('msg', tra('Invalid imagename (using filters for filenames)'));
 							$smarty->display("error.tpl");
 							die;
 						}
 					}
-					if (!empty($gal_nmatch_regex)) {
-						if (preg_match("/$gal_nmatch_regex/", $_FILES["$ins_id"]['name'], $reqs)) {
+					if ($fields['data'][$i]['type'] == 'i' && !empty($prefs['gal_nmatch_regex'])) {
+						if (preg_match('/'.$prefs['gal_nmatch_regex'].'/', $_FILES["$ins_id"]['name'], $reqs)) {
 							$smarty->assign('msg', tra('Invalid imagename (using filters for filenames)'));
 							$smarty->display("error.tpl");
 							die;
@@ -424,7 +436,31 @@ for ($i = 0; $i < $temp_max; $i++) {
 					$ins_fields["data"][$i]["file_size"] = $_FILES["$ins_id"]['size'];
 					$ins_fields["data"][$i]["file_name"] = $_FILES["$ins_id"]['name'];
 				}
+
+			} elseif (($fields["data"][$i]["type"] == 't')&& ($fields["data"][$i]["isMultilingual"]=='y')) {
+			          global $multilinguallib;
+                                  include_once('lib/multilingual/multilinguallib.php');
+                                  $multi_languages=$multilinguallib->getSystemLanguage();
+                                  $smarty->assign('multi_languages',$multi_languages);
+                                  
+                                  $ins_fields["data"][$i]['isMultilingual']='y';
+				            $compteur=0;
+				            foreach ($multi_languages as $num=>$lang){
+				            //Case convert normal -> multilingual
+				            if (!isset($_REQUEST[$ins_id."_".$lang]) && isset($_REQUEST["$ins_id"]))
+				                $_REQUEST[$ins_id."_".$lang]=$_REQUEST["$ins_id"];
+				            $fields["data"][$i]["lingualvalue"][$num]["lang"] = $lang;
+				            if (isset($_REQUEST[$ins_id."_".$lang]))
+				                $fields["data"][$i]["lingualvalue"][$num]["value"] =     $_REQUEST[$ins_id."_".$lang];
+				            $fields["data"][$i]["lingualpvalue"][$num]["lang"] = $lang;
+				            if (isset($_REQUEST[$ins_id."_".$lang]))
+				                $fields["data"][$i]["lingualpvalue"][$num]["value"] =     $tikilib->parse_data(htmlspecialchars($_REQUEST[$ins_id."_".$lang]));
+				                
+					    }
+					    $ins_fields["data"][$i]["lingualpvalue"]=$fields["data"][$i]["lingualpvalue"];
+					     $ins_fields["data"][$i]["lingualvalue"]=$fields["data"][$i]["lingualvalue"];
 			}
+			
 		}
 	}
 	// store values to have them available when there is 
@@ -438,46 +474,57 @@ for ($i = 0; $i < $temp_max; $i++) {
 	
 }
 if ($textarea_options) {
-	include_once ('lib/quicktags/quicktagslib.php');
-	$quicktags = $quicktagslib->list_quicktags(0,-1,'taglabel_desc','','wiki');
+	global $quicktagslib; include_once ('lib/quicktags/quicktagslib.php');
+	$quicktags = $quicktagslib->list_quicktags(0,-1,'taglabel_desc','','trackers');
 	$smarty->assign_by_ref('quicktags', $quicktags["data"]);
 }
 
-if ($tiki_p_admin_trackers == 'y' and isset($_REQUEST["remove"])) {
+if (($tiki_p_admin_trackers == 'y' or $tiki_p_modify_tracker_items == 'y') and isset($_REQUEST["remove"])) {
   $area = 'deltrackeritem';
-  if ($feature_ticketlib2 != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
+  if ($prefs['feature_ticketlib2'] != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
     key_check($area);
 		$trklib->remove_tracker_item($_REQUEST["remove"]);
   } else {
     key_get($area);
   }
+} elseif (($tiki_p_admin_trackers == 'y' or $tiki_p_modify_tracker_items == 'y') and isset($_REQUEST["batchaction"]) and $_REQUEST["batchaction"] == 'delete') {
+	foreach ($_REQUEST['action'] as $batchid) {
+		$trklib->remove_tracker_item($batchid);
+	}
 }
 
 
 $smarty->assign('mail_msg', '');
 $smarty->assign('email_mon', '');
 
-if ($user) {
-	if (isset($_REQUEST["monitor"])) {
+if ($prefs['feature_user_watches'] == 'y' and $tiki_p_watch_trackers == 'y') {
+	if ($user and isset($_REQUEST['watch'])) {
 		check_ticket('view-trackers');
-		$user_email = $userlib->get_user_email($user);
-		$emails = $notificationlib->get_mail_events('tracker_modified', $_REQUEST["trackerId"]);
-		if (in_array($user_email, $emails)) {
-			$notificationlib->remove_mail_event('tracker_modified', $_REQUEST["trackerId"], $user_email);
-			$mail_msg = tra('Your email address has been removed from the list of addresses monitoring this tracker');
+		if ($_REQUEST['watch'] == 'add') {
+			$tikilib->add_user_watch($user, 'tracker_modified', $_REQUEST["trackerId"], 'tracker', $tracker_info['name'],"tiki-view_tracker.php?trackerId=".$_REQUEST["trackerId"]); 
 		} else {
-			$notificationlib->add_mail_event('tracker_modified', $_REQUEST["trackerId"], $user_email);
-			$mail_msg = tra('Your email address has been added to the list of addresses monitoring this tracker');
+			$tikilib->remove_user_watch($user, 'tracker_modified', $_REQUEST["trackerId"]);
 		}
-		$smarty->assign('mail_msg', $mail_msg);
 	}
-	$user_email = $userlib->get_user_email($user);
-	$emails = $notificationlib->get_mail_events('tracker_modified', $_REQUEST["trackerId"]);
-	if (in_array($user_email, $emails)) {
-		$smarty->assign('email_mon', 'Cancel monitoring');
-	} else {
-		$smarty->assign('email_mon', 'Monitor');
+	$smarty->assign('user_watching_tracker', 'n');
+	$it = $tikilib->user_watches($user, 'tracker_modified', $_REQUEST['trackerId'], 'tracker');
+	if ($user and $tikilib->user_watches($user, 'tracker_modified', $_REQUEST['trackerId'], 'tracker')) {
+		$smarty->assign('user_watching_tracker', 'y');
 	}
+
+    // Check, if the user is watching this tracker by a category.    
+	if ($prefs['feature_categories'] == 'y') {
+	    $watching_categories_temp=$categlib->get_watching_categories($_REQUEST["trackerId"],'tracker',$user);	    
+	    $smarty->assign('category_watched','n');
+	 	if (count($watching_categories_temp) > 0) {
+	 		$smarty->assign('category_watched','y');
+	 		$watching_categories=array();	 			 	
+	 		foreach ($watching_categories_temp as $wct ) {
+	 			$watching_categories[]=array("categId"=>$wct,"name"=>$categlib->get_category_name($wct));
+	 		}		 		 	
+	 		$smarty->assign('watching_categories', $watching_categories);
+	 	}    
+	} 		
 }
 
 if (isset($_REQUEST['import'])) {
@@ -512,14 +559,12 @@ if (isset($_REQUEST['import'])) {
 			$smarty->assign('input_err', '0'); // no warning to display
 
 			check_ticket('view-trackers');
-			if (empty($user) && $feature_antibot == 'y' && (!isset($_SESSION['random_number']) || $_SESSION['random_number'] != $_REQUEST['antibotcode'])) {
-				$smarty->assign('msg',tra("You have mistyped the anti-bot verification code; please try again."));
-				$smarty->display("error.tpl");
-				die;
-			}
 			if (!isset($_REQUEST["status"]) or ($tracker_info["showStatus"] != 'y' and $tiki_p_admin_trackers != 'y')) {
 				$_REQUEST["status"] = '';
 			}
+			if (empty($_REQUEST["itemId"])) { // test if one item per user
+				$_REQUEST['itemId'] = $trklib->get_user_item($_REQUEST['trackerId'], $tracker_info);
+			}
 			$itemid = $trklib->replace_item($_REQUEST["trackerId"], $_REQUEST["itemId"], $ins_fields, $_REQUEST['status'], $ins_categs);
 			$cookietab = "1";
 			$smarty->assign('itemId', '');
@@ -529,17 +574,20 @@ if (isset($_REQUEST['import'])) {
 				$trklib->replace_rating($trackerId,$itemid,$newItemRateField,$user,$newItemRate);
 			}
 			if(isset($_REQUEST["viewitem"])) {
-				header("location: tiki-view_tracker_item.php?trackerId=".$_REQUEST["trackerId"]."&itemId=".$itemid);
+				header('location: '.preg_replace('#[\r\n]+#', '',"tiki-view_tracker_item.php?trackerId=".$_REQUEST["trackerId"]."&itemId=".$itemid));
 				die;
 			}
 			if (isset($tracker_info["defaultStatus"])) {
 				$_REQUEST['status'] = $tracker_info["defaultStatus"];
 			}
-		}
-		else {
+		} else {
 			$cookietab = "2";
 			$smarty->assign('input_err', '1'); // warning to display
 		}
+		if (isset($newItemRate)) {
+			$trackerId = $_REQUEST["trackerId"];
+			$trklib->replace_rating($trackerId,$itemid,$newItemRateField,$user,$newItemRate);
+		}
 	}
 }
 
@@ -549,19 +597,17 @@ if (!isset($_REQUEST["sort_mode"])) {
 			$sort_mode = 'lastModif';
 		elseif ($tracker_info['defaultOrderKey'] == -2)
 			$sort_mode = 'created';
+		elseif ($tracker_info['defaultOrderKey'] == -3)
+			$sort_mode = 'itemId';
 		elseif ($orderkey) {
 			$sort_mode = 'f_'.$tracker_info['defaultOrderKey'];
 		} else {
 			$sort_mode = 'lastModif';
 		}
-		if (!empty($sort_mode)) {
-			if (isset($tracker_info['defaultOrderDir'])) {
-				$sort_mode.= "_".$tracker_info['defaultOrderDir'];
-			} else {
-				$sort_mode.= "_asc";
-			}
+		if (isset($tracker_info['defaultOrderDir'])) {
+			$sort_mode.= "_".$tracker_info['defaultOrderDir'];
 		} else {
-			$sort_mode = '';
+			$sort_mode.= "_asc";
 		}
 	} else {
 		$sort_mode = '';
@@ -569,12 +615,7 @@ if (!isset($_REQUEST["sort_mode"])) {
 } else {
 	$sort_mode = $_REQUEST["sort_mode"];
 }
-$sorts = split('_',$sort_mode);
-if (is_array($sorts) and isset($sorts[1]) and isset($listfields["{$sorts[1]}"]['type']) and ($listfields["{$sorts[1]}"]['type'] == 'n' or $listfields["{$sorts[1]}"]['type'] == 'q')) {
-	$numsort = true;
-} else {
-	$numsort = false;
-}
+
 $smarty->assign_by_ref('sort_mode', $sort_mode);
 
 if (!isset($_REQUEST["offset"])) {
@@ -586,7 +627,6 @@ $smarty->assign_by_ref('offset', $offset);
 
 if (!empty($_REQUEST["maxRecords"])) {
 	$maxRecords = $_REQUEST['maxRecords'];
-	$smarty->assign('maxRecords', $maxRecords);
 }
 
 if (isset($_REQUEST["initial"])) {
@@ -595,11 +635,6 @@ if (isset($_REQUEST["initial"])) {
 	$initial = '';
 }
 $smarty->assign('initial', $initial);
-$smarty->assign('initials', split(' ','a b c d e f g h i j k l m n o p q r s t u v w x y z'));
-if (empty($_REQUEST['initialFieldId'])) {
-	$_REQUEST['initialFieldId'] = $trklib->get_initial_field($listfields, $sort_mode);
-}
-$smarty->assign('initialFieldId', $_REQUEST['initialFieldId']);
 
 if ($my and $writerfield) {
 	$filterfield = $writerfield;
@@ -630,7 +665,7 @@ if ($my and $writerfield) {
 	} else {
 		$filtervalue = '';
 	}
-	if (isset($_REQUEST['filtervalue_other'])) {
+	if (!empty($_REQUEST['filtervalue_other'])) {
 		$filtervalue = $_REQUEST['filtervalue_other'];
 	}
 	$exactvalue = '';
@@ -640,22 +675,18 @@ $smarty->assign('filtervalue', $filtervalue);
 
 $smarty->assign('status', $_REQUEST["status"]);
 
-// this isn't too beautiful, but works and doesn't break anything existing - amette
 if (isset($_REQUEST["trackerId"])) $trackerId = $_REQUEST["trackerId"];
-if (isset($_REQUEST["rateitemId"])) $rate_itemId = $_REQUEST["rateitemId"];
-if (isset($tracker_info['useRatings']) and $tracker_info['useRatings'] == 'y' 
-		and $user and isset($_REQUEST['rateitemId']) and isset($_REQUEST["rate_$trackerId"])
-		and isset($_REQUEST['fieldId']) and isset($_REQUEST["trackerId"])
-		and in_array($_REQUEST["rate_$trackerId"],split(',',$tracker_info['ratingOptions']))) {
-	if ($_REQUEST["rate_$trackerId"] == 'NULL') $_REQUEST["rate_$trackerId"] = NULL;
-	$trklib->replace_rating($trackerId,$rate_itemId,$_REQUEST['fieldId'],$user,$_REQUEST["rate_$trackerId"]);
+
+if ( isset($tracker_info['useRatings'])	and $tracker_info['useRatings'] == 'y'
+	and $user and $tiki_p_tracker_vote_ratings == 'y'
+	and !empty($_REQUEST['trackerId']) and !empty($ratedItemId)
+	and isset($newItemRate) and ( $newItemRate == 'NULL' || in_array($newItemRate, split(',',$tracker_info['ratingOptions'])) )) {
+	$trklib->replace_rating($_REQUEST['trackerId'], $ratedItemId, $newItemRateField, $user, $newItemRate);
 }
 
-$items = $trklib->list_items($_REQUEST["trackerId"], $offset, $maxRecords, $sort_mode, $listfields, $filterfield, $filtervalue, $_REQUEST["status"],$initial,$exactvalue,$numsort, $_REQUEST['initialFieldId']);
-//var_dump($_REQUEST["trackerId"], $offset, $maxRecords, $sort_mode, $listfields, $filterfield, $filtervalue, $_REQUEST["status"],$initial,$exactvalue,$numsort);
-//die;
-//var_dump($items);die();
-$urlquery['status'] = $_REQUEST["status"];
+$items = $trklib->list_items($_REQUEST["trackerId"], $offset, $maxRecords, $sort_mode, $listfields, $filterfield, $filtervalue, $_REQUEST["status"],$initial,$exactvalue);
+
+$urlquery['status'] = $_REQUEST['status'];
 $urlquery['initial'] = $initial;
 $urlquery['trackerId'] = $_REQUEST["trackerId"];
 $urlquery['sort_mode'] = $sort_mode;
@@ -670,7 +701,7 @@ if (is_array($filtervalue)) {
 	$urlquery["filtervalue[".$filterfield."]"] = $filtervalue;
 }
 $smarty->assign_by_ref('urlquery', $urlquery);
-$cant = $items['cant'];
+$cant = $items["cant"];
 include "tiki-pagination.php";
 
 if ($tracker_info['useComments'] == 'y' && $tracker_info['showComments'] == 'y') {
@@ -682,42 +713,61 @@ if ($tracker_info['useAttachments'] == 'y' && $tracker_info['showAttachments'] =
 	foreach ($items["data"] as $itkey=>$oneitem) {
 		$res = $trklib->get_item_nb_attachments($items["data"][$itkey]['itemId']);
 		$items["data"][$itkey]['attachments']  = $res['attachments'];
-		$items["data"][$itkey]['downloads'] = $res['downloads'];
+		$items["data"][$itkey]['hits'] = $res['hits'];
 	}
 }
 
-// If the special system ItemID field is set, then
-// generate static item ID's
+/* ************** not merge needed from 1.8
 foreach ($items["data"] as $itkey=>$oneitem) {
     foreach ($oneitem['field_values'] as $ifld=>$valfld) {
-        if ($valfld['type'] == 's' && $valfld['name'] == "ItemID") {
-            $items["data"][$itkey]['field_values'][$ifld]['value'] = $oneitem['itemId'];
+        if ($valfld['type'] == 'f') {
+            $items["data"][$itkey]['field_values'][$ifld]['value'] =
+                smarty_make_timestamp($valfld['value']);
         }
     }
 }
+******************** */
+
+// dynamic list process
+foreach ($listfields as $sfid => $oneitem) {
+	if ($listfields[$sfid]['type'] == 'w') {
+		if ( ! isset($listfields[$listfields[$sfid]['options_array'][2]]['http_request']))
+			$listfields[$listfields[$sfid]['options_array'][2]]['http_request'] = array('','','','','','','','','');
+		for($i = 0; $i < 5; $i++)
+		{
+			$listfields[$listfields[$sfid]['options_array'][2]]['http_request'][$i] .=
+				($listfields[$listfields[$sfid]['options_array'][2]]['http_request'][$i] ? "," : "") .
+				 $listfields[$sfid]['options_array'][$i];
+		}
+		$listfields[$listfields[$sfid]['options_array'][2]]['http_request'][5] .=
+			($listfields[$listfields[$sfid]['options_array'][2]]['http_request'][5] ? "," : "") .
+			 $sfid;
+		$listfields[$listfields[$sfid]['options_array'][2]]['http_request'][6] .=
+			($listfields[$listfields[$sfid]['options_array'][2]]['http_request'][6] ? "," : "") .
+			 $listfields[$sfid]['isMandatory'];
+	}
+}
 
 $smarty->assign('trackerId', $_REQUEST["trackerId"]);
 $smarty->assign('tracker_info', $tracker_info);
-if (isset($fields['data']))
-	$smarty->assign('fields', $fields['data']);
+$smarty->assign('fields', $fields['data']);
 $smarty->assign_by_ref('items', $items["data"]);
 $smarty->assign_by_ref('item_count', $items['cant']);
 $smarty->assign_by_ref('listfields', $listfields);
 
 $users = $userlib->list_all_users();
 $groups = $userlib->list_all_groups();
-$smarty->assign('users', $users);
-$smarty->assign('groups', $groups);
+$smarty->assign_by_ref('users', $users);
+$smarty->assign_by_ref('groups', $groups);
 
-$section = 'trackers';
 include_once('tiki-section_options.php');
 
 $smarty->assign('uses_tabs', 'y');
-if ($feature_jscalendar) {
+if ($prefs['feature_jscalendar']) {
 	$smarty->assign('uses_jscalendar', 'y');
 }
 $smarty->assign('show_filters', 'n');
-if (isset($fields['data']) && count($fields['data'])>0) {
+if(count($fields['data'])>0) {
 foreach ($fields['data'] as $it) {
 	if ($it['isSearchable'] == 'y' and $it['isTblVisible'] == 'y'){
 		$smarty->assign('show_filters', 'y');
@@ -726,11 +776,9 @@ foreach ($fields['data'] as $it) {
 }
 }
 
-// Set special system field vars
 if ($items['data']) {
 	foreach ($items['data'] as $f=>$v) {
 		$items['data'][$f]['my_rate'] = $tikilib->get_user_vote("tracker.".$_REQUEST["trackerId"].'.'.$items['data'][$f]['itemId'],$user);
-		$items['data'][$f]['ItemID']['value'] = $f;
 	}
 }
 
